﻿---------------------------------------------------------------------------------------
-- NxMapData - Map code
-- Copyright 2007-2012 Carbon Based Creations, LLC
---------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------
-- Carbonite - Addon for World of Warcraft(tm)
-- Copyright 2007-2012 Carbon Based Creations, LLC
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
---------------------------------------------------------------------------------------

local Map = Nx.Map
local L = LibStub("AceLocale-3.0"):GetLocale("Carbonite")

-- X and Y are the absolute position (lower-left corner) on the overall
-- super-zoomed-out continent image (https://github.com/dratr/Carbonite/commits/map-zonesdocs)
Map.MapInfo = {
	[0] = {		-- Dummy
		Name = "Instance",
		X = 0,
		Y = 0,
	},
	[1] = {
		Name = L["Kalimdor"],
		FileName = "Kalimdor",
		X = -3500,
		Y = 200,
--		TileX = 15,
--		TileY = 10,
	},
	[2] = {
		Name = L["Eastern Kingdoms"],
		FileName = "Azeroth",
		X = 3500,
		Y = -200,
--		TileX = 15,
--		TileY = 10,
	},
	[3] = {
		Name = L["Outland"],
		FileName = "Expansion01",
		X = 1100,
		Y = 4200,
	},
	[4] = {
		Name = L["Northrend"],
		FileName = "Northrend",
		X = 300,
		Y = -2600,
	},
	[5] = {
		Name = L["The Maelstrom"],
		FileName = "TheMaelstromContinent",
		X = -700,
		Y = -500,
	},
	[90] = {
		Name = "BG",
		X = 2000,
		Y = 200,
	},
	[100] = {
		Name = "Instance",
		X = 2000,
		Y = 100,
	},
}

Map.BloodelfXO = -503
Map.BloodelfYO = 516
Map.DraeneiXO = -3500
Map.DraeneiYO = -2010

-- UIMapAssignment
Map.MapWorldInfo = {

	-- Dummy if we get a zero on startup
	[-1] = {
		1.0,
		0,0,
	},
	[0] = {
		10,
		0, 0,
		0, 0,		-- Index 4,5 XY world position created for zones in continents 1-5, 9
		Overlay = "barrens",
	},
	[1411] = {
		Scale = 10.574999267578,
		X = 392.49997558594,
		Y = -361.66665039063,
		Overlay = "durotar",
		Name = L["Durotar"],
	},
	[1412] = {
		Scale = 10.899999511719,
		X = -440.83330078125,
		Y = 33.75,
		Overlay = "mulgore",
		Name = L["Mulgore"],
	},
	[1413] = {
		Scale = 11.491666656494,
		X = -40.416665649414,
		Y = -362.08332519531,
		Overlay = "barrens",
		Name = L["Northern Barrens"],
		QAchievementIdH = 4933,
	},
	[12] = {
		Scale = 73.5996,
		X = -3413.32,
		Y = -2459.98,
	},
	[13] = {
		Scale = 81.48236,
		X = -3634.394,
		Y = -2235.268,
	},
	[14] = {
		Scale = 6.9541665039062,
		X = 225.41665039063,
		Y = 28.333331298828,
		Overlay = "arathi",
		Name = L["Arathi Highlands"],
		QAchievementId = 4896,
	},
	[1417] = {
		Scale = 6.9541665039062,
		X = 225.41665039063,
		Y = 28.333331298828,
		Overlay = "arathi",
		Name = L["Arathi Highlands"],
		QAchievementId = 4896,
	},
	[1418] = {
		Scale = 6.1416665039062,
		X = 380.41665039063,
		Y = 1170.8333007813,
		Overlay = "badlands",
		Name = L["Badlands"],
		QAchievementId = 4900,
	},
	[1419] = {
		Scale = 7.325,
		X = 238.75,
		Y = 2116.6666015625,
		Overlay = "blastedlands",
		Name = L["Blasted Lands"],
		QAchievementId = 4909,
	},
	[1420] = {
		Scale = 9.0374997558594,
		X = -606.66665039063,
		Y = -767.49995117188,
		Overlay = "tirisfal",
		Name = L["Tirisfal Glades"],
	},
	[1421] = {
		Scale = 8.3999995117188,
		X = -689.99995117188,
		Y = -333.33332519531,
		Overlay = "silverpine",
		Name = L["Silverpine Forest"],
		QAchievementIdH = 4894,
	},
	[1422] = {
		Scale = 8.5999998168945,
		X = -83.333331298828,
		Y = -673.33330078125,
		Overlay = "westernplaguelands",
		Name = L["Western Plaguelands"],
		QAchievementId = 4893,
	},
	[1423] = {
		Scale = 8.0625,
		X = 457.5,
		Y = -740.83330078125,
		Overlay = "easternplaguelands",
		Name = L["Eastern Plaguelands"],
		QAchievementId = 4892,
	},
	[1424] = {
		Scale = 9.7249997558594,
		X = -369.99997558594,
		Y = -296.25,
		Overlay = "hillsbradfoothills",
		Name = L["Hillsbrad Foothills"],
		QAchievementIdH = 4895,
	},
	[1425] = {
		Scale = 7.7,
		X = 315,
		Y = -293.33332519531,
		Overlay = "hinterlands",
		Name = L["The Hinterlands"],
		QAchievementId = 4897,
	},
	[1426] = {
		Scale = 9.7958330078125,
		X = -427.5,
		Y = 788.33330078125,
		Overlay = "dunmorogh",
		Name = L["Dun Morogh"],
	},
	[1427] = {
		Scale = 4.4624996948242,
		X = 64.583331298828,
		Y = 1220,
		Overlay = "searinggorge",
		Name = L["Searing Gorge"],
		QAchievementId = 4910,
	},
	[1428] = {
		Scale = 6.3041663818359,
		X = 92.916662597656,
		Y = 1397.0833007813,
		Overlay = "burningsteppes",
		Name = L["Burning Steppes"],
		QAchievementId = 4901,
	},
	[1429] = {
		Scale = 6.9416665039062,
		X = -307.08332519531,
		Y = 1587.9166015625,
		Overlay = "elwynn",
		Name = L["Elwynn Forest"],
	},
	[1430] = {
		Scale = 4.9999998779297,
		X = 166.66666259766,
		Y = 1973.333203125,
		Overlay = "deadwindpass",
		Name = L["Deadwind Pass"],
	},
	[1431] = {
		Scale = 5.3999998779297,
		X = -166.66666259766,
		Y = 1943.333203125,
		Overlay = "duskwood",
		Name = L["Duskwood"],
		QAchievementIdA = 4907,
	},
	[1432] = {
		Scale = 5.5166662597656,
		X = 398.74997558594,
		Y = 897.5,
		Overlay = "lochmodan",
		Name = L["Loch Modan"],
		QAchievementIdA = 4899,
	},
	[1433] = {
		Scale = 5.1374997558594,
		X = 295.83332519531,
		Y = 1702.9166015625,
		Overlay = "redridge",
		Name = L["Redridge Mountains"],
		QAchievementIdA = 4902,
	},
	[1434] = {
		Scale = 12.7625,
		X = -444.1666,
		Y = 2233.75,		
		Overlay = "stranglethornjungle",
		Name = L["Northern Stranglethorn"],
		QAchievementId = 4906,
	},
	[1435] = {
		Scale = 5.016666015625,
		X = 416.25,
		Y = 1907.083203125,
		Overlay = "swampofsorrows",
		Name = L["Swamp of Sorrows"],
		QAchievementId = 4904,
	},
	[1436] = {
		Scale = 6.9999996337891,
		X = -603.33330078125,
		Y = 1880,
		Overlay = "westfall",
		Name = L["Westfall"],
		QAchievementIdA = 4903,
	},
	[1437] = {
		Scale = 8.2708333740234,
		X = 77.916662597656,
		Y = 429.58330078125,
		Overlay = "wetlands",
		Name = L["Wetlands"],
		QAchievementIdA = 4898,
	},
	[1438] = {
		Scale = 11.749999511719,
		X = -847.08330078125,
		Y = -2369.583203125,
		Overlay = "teldrassil",
		Name = L["Teldrassil"],
	},
	[1439] = {
		Scale = 12.929166015625,
		X = -603.33330078125,
		Y = -1644.583203125,
		Overlay = "darkshore",
		Name = L["Darkshore"],
		QAchievementIdA = 4928,
	},
	[1440] = {
		Scale = 11.533332763672,
		X = -339.99997558594,
		Y = -934.58330078125,
		Overlay = "ashenvale",
		Name = L["Ashenvale"],
		QAchievementId = 4925,
		QAchievementIdH = 4976,
	},
	[1441] = {
		Scale = 8.7999993896484,
		X = 86.666662597656,
		Y = 793.33330078125,
		Overlay = "thousandneedles",
		Name = L["Thousand Needles"],
		QAchievementId = 4938,
	},
	[1442] = {
		Scale = 11.799999755859,
		X = -780.41665039063,
		Y = -680.83330078125,
		Overlay = "stonetalonmountains",
		Name = L["Stonetalon Mountains"],
		QAchievementId = 4936,
		QAchievementIdH = 4980,
	},
	[1443] = {
		Scale = 8.991666015625,
		X = -846.6666015625,
		Y = -90.416662597656,
		Overlay = "desolace",
		Name = L["Desolace"],
		QAchievementId = 4930,
	},
	[1444] = {
		Scale = 13.899999511719,
		X = -1088.3333007813,
		Y = 473.33330078125,
		Overlay = "feralas",
		Name = L["Feralas"],
		QAchievementId = 4932,
		QAchievementIdH = 4979,
	},
	[1445] = {
		Scale = 10.5,
		X = 195,
		Y = 406.666796875,
		Overlay = "dustwallow",
		Name = L["Dustwallow Marsh"],
		QAchievementId = 4929,
		QAchievementIdH = 4978,
	},
	[1446] = {
		Scale = 14.424999031067,
		X = 12.499999237061,
		Y = 1154.1666015625,
		Overlay = "tanaris",
		Name = L["Tanaris"],
		QAchievementId = 4935,
	},
	[1447] = {
		Scale = 11.029166992188,
		X = 674.58330078125,
		Y = -1076.25,
		Overlay = "aszhara",
		Name = L["Azshara"],
		QAchievementIdH = 4927,
	},
	[1448] = {
		Scale = 12.124999267578,
		X = -359.58332519531,
		Y = -1447.4999023437,
		Overlay = "felwood",
		Name = L["Felwood"],
		QAchievementId = 4931,
	},
	[1449] = {
		Scale = 7.3999996337891,
		X = -106.66666259766,
		Y = 1193.3333007813,
		Overlay = "ungorocrater",
		Name = L["Un'Goro Crater"],
		QAchievementId = 4939,
	},
	[1450] = {
		Scale = 4.6166665039063,
		X = 276.25,
		Y = -1698.333203125,
		Overlay = "moonglade",
		Name = L["Moonglade"],
	},
	[1451] = {
		Scale = 8.1166665039063,
		X = -596.66665039063,
		Y = 1174.5833007813,
		Overlay = "silithus",
		Name = L["Silithus"],
		QAchievementIdA = 4934,
	},
	[1452] = {
		Scale = 12.299999755859,
		X = 198.33332519531,
		Y = -1758.75,
		Overlay = "winterspring",
		Name = L["Winterspring"],
		QAchievementId = 4940,
	},
	[1453] = {
		Scale = 3.474999917984,
		X = -344.58332519531,
		Y = 1599.1666015625,
		Overlay = "stormwindcity",
		Name = L["Stormwind City"],
		City = true,
		MMOutside = true,
	},
	[1454] = {
		Scale = 3.47875,
		X = 701.27080078125,
		Y = -497.33334960938,
		Overlay = "orgrimmar",
		Name = L["Orgrimmar"],
		City = true,
		MMOutside = true,
	},
	[1455] = {
		Scale = 1.5812501220703,
		X = 142.71827392578,
		Y = 913.8482421875,
		Overlay = "ironforge",
		Name = L["Ironforge"],
		City = true,
	},
	[1456] = {
		Scale = 2.0874998779297,
		X = -103.33332519531,
		Y = 169.99998779297,
		Overlay = "thunderbluff",
		Name = L["Thunder Bluff"],
		City = true,
		MMOutside = true,
	},
	[1457] = {
		Scale = 3.0791667480469,
		X = -637.5,
		Y = -2092.9166015625,
		Overlay = "darnassus",
		Name = L["Darnassus"],
		City = true,
		MMOutside = true,
	},
	[1458] = {
		Scale = 1.9187500610352,
		X = -174.63852539063,
		Y = -375.5890625,
		Overlay = "undercity",
		Name = L["Undercity"],
		City = true,
	},
	[1459] = {
		Name = L["Alterac Valley"],
		Scale = 8.4749997558594,
		X = 16000,
		Y = 2000,
		Short = "AV",
	},
	[1460] = {
		Name = L["Warsong Gulch"],
		Scale = 2.2916666259766,
		X = -16000,
		Y = 1000,
		Short = "WG",
	},
	[1461] = {
		Name = L["Arathi Basin"],
		Scale = 3.5124998474121,
		X = -16000,
		Y = 0,
		Short = "AB",
	},
	[1941] = {
		Scale = 9.85,
		X = 897.5,
		Y = -2208.333203125,
		Overlay = "eversongwoods",
		Name = L["Eversong Woods"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
	},
	[1942] = {
		Scale = 6.6,
		X = 1056.6666015625,
		Y = -1653.333203125,
		Overlay = "ghostlands",
		Name = L["Ghostlands"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
		QAchievementIdH = 4908,
	},
	[1943] = {
		Scale = 8.141666015625,
		X = 2100,
		Y = 558.75,
		Overlay = "azuremystisle",
		Name = L["Azuremyst Isle"],
		XOff = Map.DraeneiXO,
		YOff = Map.DraeneiYO,
		MId = 97,
	},
	[1944] = {
		Scale = 10.329166015625,
		X = -1107.9166015625,
		Y = -296.25,
		Overlay = "hellfire",
		Name = L["Hellfire Peninsula"],
		QAchievementId = 1189,
		QAchievementIdH = 1271,
	},
	[1945] = {
		Scale = 34.92815625,
		X = -2599.2078125,
		Y = -1164.271875,
	},
	[1946] = {
		Scale = 10.054166992188,
		X = -1895,
		Y = -387.08332519531,
		Overlay = "zangarmarsh",
		Name = L["Zangarmarsh"],
		QAchievementId = 1190,
	},
	[1947] = {
		Scale = 2.113541015625,
		X = 2213.2734375,
		Y = 721.93666992188,
		Overlay = "theexodar",
		Name = L["The Exodar"],
		XOff = Map.DraeneiXO,
		YOff = Map.DraeneiYO,
		City = true,
		MId = 97,
	},
	[1948] = {
		Scale = 11,
		X = -845,
		Y = 389.58332519531,
		Overlay = "shadowmoonvalley",
		Name = L["Shadowmoon Valley"],
		QAchievementId = 1195,
	},
	[1949] = {
		Scale = 10.849999511719,
		X = -1769.1666015625,
		Y = -881.6666015625,
		Overlay = "bladesedgemountains",
		Name = L["Blade's Edge Mountains"],
		QAchievementId = 1193,
	},
	[1950] = {
		Scale = 6.524998046875,
		X = 2015,
		Y = 151.66666259766,
		Overlay = "bloodmystisle",
		Name = L["Bloodmyst Isle"],
		XOff = Map.DraeneiXO,
		YOff = Map.DraeneiYO,
		MId = 97,
		QAchievementIdA = 4926,
	},
	[1951] = {
		Scale = 11.05,
		X = -2059.1666015625,
		Y = -8.333332824707,
		Overlay = "nagrand",
		Name = L["Nagrand"],
		QAchievementId = 1192,
		QAchievementIdH = 1273,
	},
	[1952] = {
		Scale = 10.799999511719,
		X = -1416.6666015625,
		Y = 199.99998779297,
		Overlay = "terokkarforest",
		Name = L["Terokkar Forest"],
		QAchievementId = 1191,
		QAchievementIdH = 1272,
	},
	[1953] = {
		Scale = 11.149999343872,
		X = -1096.6666015625,
		Y = -1091.25,
		Overlay = "netherstorm",
		Name = L["Netherstorm"],
		QAchievementId = 1194,
	},
	[1954] = {
		Scale = 2.4229169921875,
		X = 1280.15,
		Y = -2030.741796875,
		Overlay = "silvermooncity",
		Name = L["Silvermoon City"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		City = true,
		MId = 94,
	},
	[1955] = {
		Scale = 2.6125,
		X = -1227.0517578125,
		Y = 294.79089355469,
		Overlay = "shattrathcity",
		Name = L["Shattrath City"],
		MMOutside = true,
	},
	[1956] = {
		Name = L["Eye of the Storm"],
		Scale = 4.5416663818359,
		X = -16000,
		Y = 3000,
		Short = "EOS",
	},
	[1957] = {
		Scale = 6.654166015625,
		X = 1060.4166015625,
		Y = -2713.7498046875,
		Overlay = "sunwell",
		Name = L["Isle of Quel'Danas"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
	},
	[113] = {
		Scale = 35.502796875,
		X = -1843.43046875,
		Y = -2118.675,
	},
	[114] = {
		Scale = 11.529166015625,
		X = -1714.1666015625,
		Y = -979.58330078125,
		Overlay = "boreantundra",
		Name = L["Borean Tundra"],
		QAchievementId = 33,
		QAchievementIdH = 1358,
	},
	[115] = {
		Scale = 11.216666259766,
		X = -725.41665039063,
		Y = -1115,
		Overlay = "dragonblight",
		Name = L["Dragonblight"],
		QAchievementId = 35,
		QAchievementIdH = 1359,
	},
	[116] = {
		Scale = 10.499999755859,
		X = 222.08332519531,
		Y = -1103.3333007813,
		Overlay = "grizzlyhills",
		Name = L["Grizzly Hills"],
		QAchievementId = 37,
		QAchievementIdH = 1357,
	},
	[117] = {
		Scale = 12.091665771484,
		X = 279.58332519531,
		Y = -623.33330078125,
		Overlay = "howlingfjord",
		Name = L["Howling Fjord"],
		QAchievementId = 34,
		QAchievementIdH = 1356,
	},
	[118] = {
		Scale = 12.541666625977,
		X = -1088.75,
		Y = -1885.4166015625,
		Overlay = "icecrownglacier",
		Name = L["Icecrown"],
		QAchievementId = 40,
	},
	[119] = {
		Scale = 8.7125,
		X = -1385.8333007813,
		Y = -1457.4999023437,
		Overlay = "sholazarbasin",
		Name = L["Sholazar Basin"],
		QAchievementId = 39,
	},
	[120] = {
		Scale = 14.224999267578,
		X = -368.33332519531,
		Y = -2039.583203125,
		Overlay = "thestormpeaks",
		Name = L["The Storm Peaks"],
		QAchievementId = 38,
	},
	[121] = {
		Scale = 9.9875,
		X = 120,
		Y = -1533.7499023437,
		Overlay = "zuldrak",
		Name = L["Zul'Drak"],	-- [11]
		QAchievementId = 36,
	},
	[122] = {
		Scale = 6.654166015625,
		X = 1060.4166015625,
		Y = -2713.7498046875,
		Overlay = "sunwell",
		Name = L["Isle of Quel'Danas"],
		XOff = Map.BloodelfXO,
		YOff = Map.BloodelfYO,
		MId = 94,
	},
	[123] = {
		Scale = 5.9499997558594,
		X = -865.83330078125,
		Y = -1143.3333007813,
		Overlay = "lakewintergrasp",
		Name = L["Wintergrasp"],
		Explored = true,
	},
	[124] = {
		Scale = 6.325,
		X = 809.58330078125,
		Y = -617.5,
		Overlay = "scarletenclave",
		Name = L["Plaguelands: The Scarlet Enclave"],
		XOff = 400,
		YOff = -33,
		City = true,
	},
	[125] = {
		Name = L["Dalaran"],
		Scale = 1.6589 / 1.3,
		X = -200.95,
		Y = -1199.17260156,
		Overlay = "dalaran",
		MapBaseName = "dalaran1_",
		City = true,
		Alpha = .85,
		ScaleAdjust = 1.3,
		--MapLevel = 1,
	},
	[127] = {
		Scale = 5.4458332519531,
		X = -288.75,
		Y = -1300.4166015625,
		Overlay = "crystalsongforest",
		Name = L["Crystalsong Forest"],
	},
	[128] = {
		Name = L["Strand of the Ancients"],
		Scale = 3.4874998779297,
		X = -14500,
		Y = 0,
		Short = "SoA",
	},
	[169] = {
		Name = L["Isle of Conquest"],
		Scale = 5.3,
		X = -14500,
		Y = 1000,
		Short = "IC",
	},
	[170] = {
		Scale = 7.3541662597656,
		X = -559.58330078125,
		Y = -2156.25,
		Overlay = "hrothgarslanding",
		Name = L["Hrothgar's Landing"],
		Explored = true,
	},
	[174] = {
		Scale = 9.029166015625,
		X = -876.6666015625,
		Y = -576.25,
		Overlay = "thelostisles_terrain2",
		Name = L["The Lost Isles"],
		XOff = 470,
		YOff = 980,
	},
	[179] = {
		Scale = 6.2916665039063,
		X = -687.91665039063,
		Y = 106.66666259766,
		Overlay = "gilneas",
		Name = L["Gilneas"],
	},
	[194] = {
		Scale = 2.7041663818359,
		X = -425.83330078125,
		Y = 1546.2499023437,
		Overlay = "kezan",
		Name = L["Kezan"],
		XOff = 946,
		YOff = -832,
		MId = 194,
	},
	[198] = {
		Scale = 8.4916667480469,
		X = 185.83332519531,
		Y = -1239.1666015625,
		Overlay = "hyjal",
		Name = L["Mount Hyjal"],
		QAchievementId = 4870,
	},
	[199] = {
		Scale = 14.825,
		X = -271.25,
		Y = -40.833331298828,
		Overlay = "southernbarrens",
		Name = L["Southern Barrens"],
		QAchievementId = 4937,
		QAchievementIdH = 4981,
	},
	[201] = {
		Scale = 5.604166015625,
		X = -1014.1666015625,
		Y = 803.74995117188,
		Overlay = "vashjirkelpforest",
		Name = L["Kelp'thar Forest"],
		QAchievementId = 4869,
		QAchievementIdH = 4982,
	},
	[202] = {
		Scale = 1.7791665039063,
		X = -386.66665039063,
		Y = 261.25,
		Overlay = "gilneascity",
		Name = L["Gilneas City"],
	},
	[203] = {
		Scale = 13.891665527344,
		X = -1750.833203125,
		Y = 744.16665039063,
		Overlay = "vashjir",
		Name = L["Vashj'ir"],
	},
	[204] = {
		Scale = 8.15,
		X = -1646.6666015625,
		Y = 981.25,
		Overlay = "vashjirdepths",
		Name = L["Abyssal Depths"],
		QAchievementId = 4869,
		QAchievementIdH = 4982,
	},
	[205] = {
		Scale = 9.6999992675781,
		X = -1336.2499023437,
		Y = 951.25,
		Overlay = "vashjirruins",
		Name = L["Shimmering Expanse"],
		QAchievementId = 4869,
		QAchievementIdH = 4982,
	},
	[206] = {
		Name = L["Twin Peaks"],
		Scale = 2.4291665039062,
		X = -14500,
		Y = 3000,
		Short = "TP",
	},
	[207] = {
		Scale = 10.199999755859,
		X = -610.41665039063,
		Y = -559.16665039063,
		Overlay = "deepholm",
		Name = L["Deepholm"],
		XOff = 1580,
		YOff = 700,
		QAchievementId = 4871,
		MId = 207,
	},
	[210] = {
		Scale = 7.8916662597656,
		X = -421.66665039063,
		Y = 2503.333203125,
		Overlay = "thecapeofstranglethorn",
		Name = L["The Cape of Stranglethorn"],
		QAchievementId = 4905,
	},
	[217] = {
		Scale = 6.2916665039063,
		X = -687.91665039063,
		Y = 106.66666259766,
		Overlay = "ruinsofgilneas",
		Name = L["Ruins of Gilneas"],
		Explored = true,
	},
	[218] = {
		Scale = 1.7791665039063,
		X = -386.66665039063,
		Y = 261.25,
		Overlay = "ruinsofgilneascity",
		Name = L["Ruins of Gilneas City"],
		City = true,
		StartZone = true,
	},
	[224] = {
		Scale = 13.104166015625,
		X = -595.41665039063,
		Y = 2192.9166015625,
		Overlay = "stranglethornvale",
		Name = L["Stranglethorn Vale"],
	},
	[241] = {
		Scale = 10.541666015625,
		X = 487.5,
		Y = 431.25,
		Overlay = "twilighthighlands_terrain1",
		Name = L["Twilight Highlands"],
		QAchievementId = 4873,
		QAchievementIdH = 5501,
	},
	[244] = {
		Scale = 4.0291665849686,
		X = -402.08332519531,
		Y = 112.08332519531,
		Overlay = "tolbarad",
		Name = L["Tol Barad"],
		XOff = -600,
		YOff = 320,
		MId = 244,
		Explored = true,
	},
	[245] = {
		Scale = 3.675,
		X = -482.5,
		Y = -75.416662597656,
		Overlay = "tolbaraddailyarea",
		Name = L["Tol Barad Peninsula"],
		XOff = -600,
		YOff = 320,
		MId = 244,
		Explored = true,
	},
	[249] = {
		Scale = 12.387499511719,
		X = -488.33330078125,
		Y = 1605.8333007813,
		Overlay = "uldum",
		Name = L["Uldum"],
		QAchievementId = 4872,
	},
	[275] = {
		Name = L["The Battle for Gilneas"],
		Scale = 2.6041665649414,
		X = -14500,
		Y = 2000,
		Short = "TBG",
	},
	[276] = {
		Scale = 3.1,
		X = -311.25,
		Y = -274.16665039063,
		Overlay = "themaelstrom",
		Name = L["The Maelstrom"],
		XOff = 1000,
		YOff = 600,
		City = true,
		Explored = true,
	},
	[327] = {
		Scale = 8.0999996643066,
		X = -778.33330078125,
		Y = 1606.6666015625,
		Overlay = "ahnqirajthefallenkingdom",
		Name = L["Ahn'Qiraj: The Fallen Kingdom"],
	},
	[338] = {
		Scale = 2.3791666259766,
		X = -186.66666259766,
		Y = -340.41665039063,
		Overlay = "moltenfront",
		Name = L["Molten Front"],
		MId = 338,
		UseAId = true,
		Explored = true,
	},
	[407] = {
		Scale = 3.716666015625,
		X = -953.7499023437,
		Y = 664.58330078125,
		Overlay = "darkmoonfaireisland",
		Name = L["Darkmoon Island"],
		Explored = true,
		MMOutside = true,
		MId=407,
	},
	[948] = {
		Scale = 26,
		X = -311.25,
		Y = -274.16665039063,
	},	
}

--------

Map.InstanceInfo = {		-- Blizzard instance maps (SetInstanceMap uses size of 3 for table entries)
}

-- UIMapXMapArt -> WorldMapOverlay -> WorldMapOverlayTitle
Map.ZoneOverlays = {
	-- Kalimdor
		["moonglade"] = {
			["shrineofremulos"] = "209,91,271,296",
			["lakeeluneara"] = "219,273,431,319",
			["stormragebarrowdens"] = "542,210,275,346",
			["nighthaven"] = "370,135,346,244",
		},
		["barrens"] = {
			["dreadmistpeak"] = "290,104,241,195",
			["thornhill"] = "481,254,239,231",
			["thestagnantoasis"] = "344,379,336,289",
			["farwatchpost"] = "555,129,207,332",
			["thesludgefen"] = "403,6,257,249",
			["thewailingcaverns"] = "152,318,377,325",
			["thedryhills"] = "116,57,283,270",
			["themerchantcoast"] = "556,456,315,212",
			["boulderlodemine"] = "511,7,278,209",
			["theforgottenpools"] = "100,208,446,256",
			["morshanrampart"] = "258,6,261,216",
			["ratchet"] = "547,379,219,175",
			["thecrossroads"] = "362,275,233,193",
			["groldomfarm"] = "448,127,243,217",
		},
		["winterspring"] = {
			["icethistlehills"] = "581,314,249,217",
			["lakekeltheril"] = "372,268,271,258",
			["starfallvillage"] = "229,33,367,340",
			["mazthoril"] = "399,340,257,238",
			["frostsaberrock"] = "304,0,332,268",
			["timbermawpost"] = "92,302,362,252",
			["thehiddengrove"] = "500,17,333,255",
			["frostwhispergorge"] = "424,474,317,183",
			["everlook"] = "482,195,194,229",
			["owlwingthicket"] = "556,439,254,150",
			["winterfallvillage"] = "588,181,221,209",
			["frostfirehotsprings"] = "93,118,376,289",
		},
		["uldum_terrain1"] = {
			["thegateofunendingcycles"] = "647,15,161,236",
			["thecursedlanding"] = "752,170,237,316",
			["ruinsofammon"] = "217,289,203,249",
			["akhenetfields"] = "471,277,164,185",
			["orsis"] = "264,136,249,243",
			["nahom"] = "583,162,237,194",
			["ramkahen"] = "411,67,228,227",
			["obeliskofthemoon"] = "110,0,400,224",
			["obeliskofthesun"] = "340,282,269,203",
			["thetrailofdevestation"] = "657,349,206,204",
			["cradeloftheancient"] = "341,402,202,169",
			["schnottzslanding"] = "28,221,312,289",
			["marat"] = "406,174,160,193",
			["virnaaldam"] = "479,215,151,144",
			["throneofthefourwinds"] = "229,433,270,229",
			["thevortexpinnacle"] = "656,473,213,195",
			["hallsoforigination"] = "599,184,269,242",
			["templeofuldum"] = "132,127,296,209",
			["obeliskofthestars"] = "551,121,196,170",
			["ruinsofahmtul"] = "365,0,278,173",
			["khartutstomb"] = "542,0,203,215",
			["neferset"] = "407,384,209,254",
			["tahretgrounds"] = "545,193,150,159",
			["lostcityofthetolvir"] = "527,291,233,321",
		},
		["ashenvale"] = {
			["theshrineofassenia"] = "40,275,306,283",
			["nightrun"] = "595,253,221,257",
			["fallenskylake"] = "529,385,287,276",
			["warsonglumbercamp"] = "771,265,231,223",
			["lakefalathim"] = "112,148,184,232",
			["satyrnaar"] = "696,154,235,236",
			["thehowlingvale"] = "473,97,325,239",
			["raynewoodretreat"] = "481,221,231,256",
			["thezoramstrand"] = "0,0,262,390",
			["felfirehill"] = "714,317,277,333",
			["maelstraspost"] = "188,0,246,361",
			["thunderpeak"] = "377,121,203,310",
			["theruinsofstardust"] = "210,331,236,271",
			["orendilsretreat"] = "143,0,244,251",
			["astranaar"] = "255,164,251,271",
			["thistlefurvillage"] = "255,78,314,241",
			["silverwindrefuge"] = "338,335,347,308",
			["boughshadow"] = "836,148,166,211",
		},
		["teldrassil"] = {
			["banethilhollow"] = "374,221,175,235",
			["shadowglen"] = "481,104,241,217",
			["gnarlpinehold"] = "347,355,198,181",
			["thecleft"] = "432,109,144,226",
			["theoracleglade"] = "276,90,194,244",
			["rutheranvillage"] = "329,448,317,220",
			["lakealameth"] = "422,310,289,202",
			["wellspringlake"] = "382,83,165,249",
			["starbreezevillage"] = "544,217,187,196",
			["galardellvalley"] = "466,237,178,186",
			["poolsofarlithrien"] = "345,243,140,210",
			["darnassus"] = "149,181,298,337",
		},
		["mulgore"] = {
			["baeldundigsite"] = "226,220,218,192",
			["winterhoofwaterwell"] = "449,340,174,185",
			["redcloudmesa"] = "286,401,446,264",
			["redrocks"] = "514,43,186,185",
			["ravagedcaravan"] = "435,224,187,165",
			["thunderhornwaterwell"] = "333,202,201,167",
			["theventurecomine"] = "530,138,208,300",
			["wildmanewaterwell"] = "331,0,190,172",
			["thunderbluff"] = "208,62,373,259",
			["windfuryridge"] = "400,0,222,202",
			["bloodhoofvillage"] = "319,273,302,223",
			["stonetalonpass"] = "201,0,237,184",
			["therollingplains"] = "527,291,260,243",
			["palemanerock"] = "248,321,172,205",
			["thegoldenplains"] = "448,101,186,216",
		},
		["hyjal"] = {
			["archimondesvengeance"] = "320,5,270,300",
			["shrineofgoldrinn"] = "116,17,291,321",
			["nordrassil"] = "392,0,537,323",
			["gatesofsothann"] = "622,320,272,334",
			["sethriasroost"] = "139,436,277,232",
			["theregrowth"] = "52,253,441,319",
			["direforgehill"] = "303,197,270,173",
			["ashenlake"] = "6,78,282,418",
			["thescorchedplain"] = "411,216,365,264",
			["thethroneofflame"] = "318,378,419,290",
			["darkwhispergorge"] = "682,128,320,471",
		},
		["felwood"] = {
			["irontreewoods"] = "406,55,261,273",
			["morlosaran"] = "476,484,187,176",
			["bloodvenomfalls"] = "220,231,345,192",
			["jaedenar"] = "234,317,319,176",
			["felpawvillage"] = "471,0,307,161",
			["jadefirerun"] = "303,9,263,199",
			["ruinsofconstellas"] = "278,359,268,214",
			["deadwoodvillage"] = "410,505,173,163",
			["emeraldsanctuary"] = "394,382,274,212",
			["shatterscarvale"] = "243,107,343,250",
			["talonbranchglade"] = "531,57,209,226",
			["jadefireglen"] = "288,458,229,210",
		},
		["darkshore"] = {
			["lordanel"] = "391,54,277,281",
			["eyeofthevortex"] = "300,239,330,192",
			["nazjvel"] = "207,467,244,201",
			["wildbendriver"] = "280,378,314,193",
			["ruinsofauberdine"] = "280,182,203,194",
			["witheringthicket"] = "305,118,328,250",
			["shatterspearvale"] = "596,16,250,241",
			["shatterspearwarcamp"] = "565,0,245,147",
			["ametharan"] = "294,330,326,145",
			["ruinsofmathystra"] = "517,28,200,263",
			["themastersglaive"] = "277,483,303,185",
		},
		["aszhara"] = {
			["bearshead"] = "113,141,256,224",
			["thesecretlab"] = "353,396,184,213",
			["ruinsofarkkoran"] = "575,121,219,193",
			["darnassianbasecamp"] = "343,3,243,262",
			["lakemennar"] = "245,377,210,232",
			["ravencrestmonument"] = "476,401,295,267",
			["stormcliffs"] = "407,403,207,232",
			["theshatteredstrand"] = "316,168,206,329",
			["gallywixpleasurepalace"] = "70,222,250,230",
			["blackmawhold"] = "204,53,260,267",
			["bilgewaterharbor"] = "395,127,587,381",
			["towerofeldara"] = "684,22,306,337",
			["orgimmarreargate"] = "22,344,352,274",
			["bitterreaches"] = "477,0,321,247",
			["ruinsofeldarath"] = "228,229,218,237",
		},
		["ungorocrater"] = {
			["lakkaritarpits"] = "305,0,432,294",
			["ironstoneplateau"] = "706,201,197,222",
			["therollinggarden"] = "565,39,337,321",
			["golakkahotsprings"] = "145,226,309,277",
			["theslitheringscar"] = "335,384,381,274",
			["thescreamingreaches"] = "157,0,332,332",
			["mossypile"] = "328,179,186,185",
			["themarshlands"] = "573,256,263,412",
			["fireplumeridge"] = "356,192,321,288",
			["terrorrun"] = "162,357,316,293",
			["fungalrock"] = "557,0,224,191",
			["marshalsstand"] = "462,330,204,170",
		},
		["desolace"] = {
			["valleyofspears"] = "170,196,321,275",
			["gelkisvillage"] = "207,472,274,196",
			["mannoroccoven"] = "381,357,326,311",
			["thunderaxefortress"] = "440,49,220,205",
			["shokthokar"] = "589,319,309,349",
			["cenarionwildlands"] = "415,156,312,285",
			["sargeron"] = "655,0,317,293",
			["nijelspoint"] = "573,0,231,257",
			["magramterritory"] = "613,170,289,244",
			["thargadscamp"] = "275,376,212,186",
			["tethrisaran"] = "399,0,274,145",
			["kodograveyard"] = "360,273,250,215",
			["ranzjarisle"] = "210,0,161,141",
			["shadowbreakravine"] = "637,402,292,266",
			["shadowpreyvillage"] = "142,369,222,299",
			["slitherbladeshore"] = "208,24,338,342",
		},
		["tanaris"] = {
			["landsendbeach"] = "431,452,224,216",
			["southbreakshore"] = "437,289,274,186",
			["zulfarrak"] = "184,0,315,190",
			["valleryofthewatchers"] = "255,431,269,190",
			["southmoonruins"] = "301,349,232,211",
			["brokenpillar"] = "413,211,195,163",
			["thegapingchasm"] = "448,364,225,187",
			["cavernsoftime"] = "507,238,213,173",
			["gadgetzan"] = "412,92,189,180",
			["dunemaulcompound"] = "305,257,231,177",
			["gadgetzanbay"] = "479,9,254,341",
			["lostriggercover"] = "615,201,178,243",
			["eastmoonruins"] = "380,341,173,163",
			["abyssalsands"] = "297,148,255,194",
			["thistleshrubvalley"] = "185,280,221,293",
			["thenoxiouslair"] = "258,211,179,190",
			["sandsorrowwatch"] = "293,99,214,149",
		},
		["uldum"] = {
			["thegateofunendingcycles"] = "647,15,161,236",
			["thecursedlanding"] = "752,170,237,316",
			["ruinsofammon"] = "217,289,203,249",
			["akhenetfields"] = "471,277,164,185",
			["orsis"] = "264,136,249,243",
			["nahom"] = "583,162,237,194",
			["ramkahen"] = "411,67,228,227",
			["obeliskofthemoon"] = "110,0,400,224",
			["obeliskofthesun"] = "340,282,269,203",
			["thetrailofdevestation"] = "657,349,206,204",
			["cradeloftheancient"] = "341,402,202,169",
			["schnottzslanding"] = "28,221,312,289",
			["marat"] = "406,174,160,193",
			["virnaaldam"] = "479,215,151,144",
			["throneofthefourwinds"] = "229,433,270,229",
			["thevortexpinnacle"] = "656,473,213,195",
			["hallsoforigination"] = "599,184,269,242",
			["templeofuldum"] = "132,127,296,209",
			["obeliskofthestars"] = "551,121,196,170",
			["ruinsofahmtul"] = "365,0,278,173",
			["khartutstomb"] = "542,0,203,215",
			["neferset"] = "407,384,209,254",
			["tahretgrounds"] = "545,193,150,159",
			["lostcityofthetolvir"] = "527,291,233,321",
		},
		["ahnqirajthefallenkingdom"] = {
			["aqkingdom"] = "115,0,887,668",
		},
		["durotar"] = {
			["razormanegrounds"] = "302,264,248,158",
			["echoisles"] = "429,413,330,255",
			["thunderridge"] = "295,48,220,218",
			["skullrock"] = "438,0,208,157",
			["tiragardekeep"] = "462,298,210,200",
			["valleyoftrials"] = "304,312,254,258",
			["southfurywatershed"] = "282,174,244,222",
			["drygulchravine"] = "415,60,236,196",
			["senjinvillage"] = "457,406,192,184",
			["razorhill"] = "431,157,224,227",
			["northwatchfoothold"] = "399,440,162,157",
			["orgrimmar"] = "309,0,259,165",
		},
		["feralas"] = {
			["campmojache"] = "671,181,174,220",
			["feathermoonstronghold"] = "362,237,217,192",
			["darkmistruins"] = "568,287,172,198",
			["writhingdeep"] = "652,298,232,206",
			["ruinsoffeathermoon"] = "186,229,208,204",
			["theforgottencoast"] = "375,343,194,304",
			["feralscar"] = "457,281,191,179",
			["grimtotemcompund"] = "607,170,159,218",
			["ruinsofisildien"] = "467,354,206,237",
			["gordunnioutpost"] = "663,116,192,157",
			["thetwincolossals"] = "271,0,350,334",
			["diremaul"] = "485,101,265,284",
			["lowerwilds"] = "756,191,207,209",
		},
		["silithus"] = {
			["thescarabwall"] = "0,455,580,213",
			["valorsrest"] = "614,0,315,285",
			["twilightbasecamp"] = "100,151,434,231",
			["southwindvillage"] = "550,181,309,243",
			["thecrystalvale"] = "126,0,329,246",
			["hiveashi"] = "345,4,405,267",
			["cenarionhold"] = "427,143,292,260",
			["hiveregal"] = "380,310,489,358",
			["hivezora"] = "0,206,542,367",
		},
		["stonetalonmountains"] = {
			["windshearcrag"] = "533,179,374,287",
			["kromgarfortress"] = "588,341,183,196",
			["stonetalonpeak"] = "265,0,305,244",
			["unearthedgrounds"] = "654,369,265,206",
			["greatwoodvale"] = "602,448,322,220",
			["boulderslideravine"] = "532,512,194,156",
			["cliffwalkerpost"] = "366,95,241,192",
			["webwinderpath"] = "468,263,267,352",
			["sunrockretreat"] = "353,285,222,222",
			["webwinderhollow"] = "479,401,164,258",
			["ruinsofeldrethar"] = "367,411,221,235",
			["battlescarvalley"] = "220,189,290,297",
			["windshearhold"] = "516,289,176,189",
			["thaldarahoverlook"] = "252,121,210,189",
			["malakajin"] = "618,537,211,131",
			["mirkfallonlake"] = "417,143,244,247",
			["thecharredvale"] = "199,368,277,274",
		},
		["southernbarrens"] = {
			["huntershill"] = "300,64,218,178",
			["honorsstand"] = "201,0,315,170",
			["ruinsoftaurajo"] = "244,286,285,171",
			["razorfenkraul"] = "273,528,214,140",
			["vendettapoint"] = "267,196,254,214",
			["forwardcommand"] = "423,251,216,172",
			["battlescar"] = "274,307,384,248",
			["theovergrowth"] = "289,117,355,226",
			["baelmodan"] = "398,457,269,211",
			["northwatchhold"] = "548,147,280,279",
			["frazzlecrazmotherload"] = "269,436,242,195",
		},
		["dustwallow"] = {
			["witchhill"] = "428,0,270,353",
			["theramoreisle"] = "542,223,305,247",
			["direhornpost"] = "358,169,279,301",
			["blackhoofvillage"] = "199,0,344,183",
			["brackenwllvillage"] = "133,59,384,249",
			["alcazisland"] = "656,21,206,200",
			["mudsprocket"] = "109,313,433,351",
			["shadyrestinn"] = "137,188,317,230",
			["thewyrmbog"] = "359,369,436,299",
		},
		["hyjal_terrain1"] = {
			["archimondesvengeance"] = "320,5,270,300",
			["shrineofgoldrinn"] = "116,17,291,321",
			["nordrassil"] = "392,0,537,323",
			["gatesofsothann"] = "622,320,272,334",
			["sethriasroost"] = "139,436,277,232",
			["theregrowth"] = "52,253,441,319",
			["direforgehill"] = "303,197,270,173",
			["ashenlake"] = "6,78,282,418",
			["thescorchedplain"] = "411,216,365,264",
			["thethroneofflame"] = "318,378,419,290",
			["darkwhispergorge"] = "682,128,320,471",
		},
		["thousandneedles"] = {
			["southseaholdfast"] = "756,412,246,256",
			["thetwilightwithering"] = "347,329,374,339",
			["splithoofheights"] = "571,49,431,410",
			["thegreatlift"] = "136,0,272,232",
			["razorfendowns"] = "298,0,361,314",
			["theshimmeringdeep"] = "591,257,411,411",
			["freewindpost"] = "276,186,436,271",
			["highperch"] = "0,134,246,380",
			["rustmauldivesite"] = "527,465,234,203",
			["westreachsummit"] = "0,0,280,325",
			["twilightbulwark"] = "125,241,358,418",
			["darkcloudpinnacle"] = "169,116,317,252",
		},

	-- Eastern Kingdoms

		["vashjirruins"] = {
			["nespirah"] = "460,261,286,269",
			["glimmeringdeepgorge"] = "270,222,272,180",
			["silvertidehollow"] = "150,32,480,319",
			["shimmeringgrotto"] = "400,0,339,278",
			["ruinsofvashjir"] = "217,268,349,361",
			["ruinsoftherseral"] = "554,175,197,223",
			["bethmoraridge"] = "407,445,335,223",
		},
		["duskwood"] = {
			["theyorgenfarmstead"] = "401,396,233,248",
			["addlesstead"] = "32,348,299,296",
			["thetranquilgardenscemetary"] = "627,344,291,244",
			["darkshire"] = "640,128,329,314",
			["brightwoodgrove"] = "497,112,279,399",
			["vulgologremound"] = "228,355,268,282",
			["thehushedbank"] = "0,152,189,307",
			["thedarkenedbank"] = "71,26,931,235",
			["manormistmantle"] = "661,122,219,182",
			["racenhill"] = "96,292,205,157",
			["thetwilightgrove"] = "314,101,320,388",
			["therottingorchard"] = "539,368,291,263",
			["ravenhillcemetary"] = "91,132,323,309",
		},
		["vashjirkelpforest"] = {
			["darkwhispergorge"] = "528,228,220,189",
			["honorstomb"] = "380,43,291,206",
			["legionsfate"] = "210,35,278,315",
			["gnawsboneyard"] = "451,325,311,217",
			["theaccursedreef"] = "365,162,340,225",
			["gubogglesledge"] = "399,280,227,207",
			["holdingpens"] = "456,401,316,267",
		},
		["twilighthighlands_terrain1"] = {
			["victorypoint"] = "302,306,177,159",
			["dragonmawpass"] = "76,120,283,206",
			["bloodgulch"] = "416,205,215,157",
			["obsidianforest"] = "436,380,342,288",
			["thundermar"] = "374,93,238,229",
			["grimbatol"] = "83,223,230,276",
			["theblackbreach"] = "498,121,211,210",
			["wyrmsbend"] = "205,232,191,198",
			["dragonmawport"] = "631,245,251,207",
			["crucibleofcarnage"] = "387,268,203,208",
			["twilightshore"] = "610,345,260,202",
			["vermillionredoubt"] = "71,16,324,264",
			["thegullet"] = "269,179,175,180",
			["humboldtconflaguration"] = "344,89,143,141",
			["gorshakwarcamp"] = "543,220,194,170",
			["highbank"] = "697,403,220,227",
			["crushblow"] = "370,447,182,195",
			["thetwilightcitadel"] = "151,314,361,354",
			["highlandforest"] = "482,330,239,232",
			["thetwilightbreach"] = "312,192,199,212",
			["thekrazzworks"] = "654,0,226,232",
			["slitheringcove"] = "622,169,198,201",
			["thetwilightgate"] = "327,356,165,199",
			["ruinsofdrakgor"] = "296,0,206,182",
			["firebeardspatrol"] = "499,265,215,181",
			["dunwaldruins"] = "395,367,197,218",
			["weepingwound"] = "358,0,214,190",
			["kirthaven"] = "482,0,308,267",
			["glopgutshollow"] = "291,89,174,190",
		},
		["hinterlands"] = {
			["queldanillodge"] = "220,181,241,211",
			["thealtarofzul"] = "357,343,225,196",
			["shaolwatha"] = "565,208,281,261",
			["thecreepingruin"] = "390,252,199,199",
			["zunwatha"] = "152,284,226,225",
			["plaguemistravine"] = "133,105,191,278",
			["shadraalor"] = "220,379,240,196",
			["aeriepeak"] = "0,236,238,267",
			["valorwindlake"] = "286,269,199,212",
			["agolwatha"] = "367,159,208,204",
			["jinthaalor"] = "487,334,287,289",
			["skulkrock"] = "490,195,176,235",
			["seradane"] = "475,5,303,311",
			["theoverlookcliffs"] = "677,267,244,401",
		},
		["blastedlands"] = {
			["serpentscoil"] = "459,97,218,183",
			["nethergardekeep"] = "530,6,295,205",
			["dreadmaulpost"] = "327,182,235,188",
			["altarofstorms"] = "225,110,238,195",
			["riseofthedefiler"] = "375,102,168,170",
			["dreadmaulhold"] = "258,0,272,206",
			["thetaintedforest"] = "132,311,348,357",
			["surwich"] = "333,474,199,191",
			["thedarkportal"] = "368,179,370,298",
			["theredreaches"] = "533,268,268,354",
			["shattershore"] = "578,91,240,270",
			["sunveilexcursion"] = "386,374,233,266",
			["nethergardesupplycamps"] = "436,0,195,199",
			["thetaintedscar"] = "144,175,308,226",
		},
		["wetlands"] = {
			["sundownmarsh"] = "121,63,276,243",
			["blackchannelmarsh"] = "37,240,301,232",
			["dunalgaz"] = "346,419,298,215",
			["slabchiselssurvey"] = "532,352,300,316",
			["satlspray"] = "218,0,250,282",
			["greenwardensgrove"] = "460,102,250,269",
			["raptorridge"] = "599,123,256,245",
			["thelganrock"] = "371,335,258,207",
			["bluegillmarsh"] = "31,102,321,248",
			["mosshidefen"] = "506,232,369,235",
			["direforgehills"] = "506,34,329,228",
			["angerfangencampment"] = "359,201,236,256",
			["whelgarsexcavationsite"] = "185,195,298,447",
			["dunmodr"] = "356,7,257,185",
			["ironbeardstomb"] = "372,76,185,224",
			["menethilharbor"] = "0,297,325,363",
		},
		["easternplaguelands"] = {
			["zulmashar"] = "528,0,286,176",
			["thefungalvale"] = "183,211,274,216",
			["theundercroft"] = "56,457,280,211",
			["lightshopechapel"] = "687,271,196,220",
			["corinscrossing"] = "493,289,186,213",
			["tyrshand"] = "651,414,214,254",
			["eastwalltower"] = "541,184,181,176",
			["northpasstower"] = "401,69,250,192",
			["acherus"] = "774,102,228,273",
			["thondorilriver"] = "0,100,262,526",
			["themarrisstead"] = "133,335,202,202",
			["thenoxiousglade"] = "650,55,297,299",
			["thepestilentscar"] = "383,348,182,320",
			["theinfectisscar"] = "595,263,177,266",
			["terrordale"] = "0,10,258,320",
			["blackwoodlake"] = "382,151,238,231",
			["stratholme"] = "118,0,310,178",
			["quellithienlodge"] = "351,0,277,175",
			["plaguewood"] = "144,40,328,253",
			["darrowshire"] = "211,462,248,206",
			["ruinsofthescarletenclave"] = "738,295,264,373",
			["lightsshieldtower"] = "391,271,243,162",
			["northdale"] = "570,61,265,232",
			["crownguardtower"] = "258,351,202,191",
			["lakemereldar"] = "462,427,266,241",
		},
		["badlands"] = {
			["agmondsend"] = "230,315,342,353",
			["apocryphansrest"] = "0,66,252,353",
			["campcagg"] = "0,281,339,347",
			["uldaman"] = "336,0,266,210",
			["lethlorravine"] = "533,55,469,613",
			["campboff"] = "407,220,274,448",
			["hammertoesdigsite"] = "411,116,209,196",
			["campkosh"] = "504,19,236,260",
			["angorfortress"] = "230,68,285,223",
			["deathwingscar"] = "175,178,328,313",
			["thedustbowl"] = "144,99,214,285",
		},
		["silverpine"] = {
			["northtidesrun"] = "147,0,281,345",
			["thesepulcher"] = "341,157,218,200",
			["forsakenhighcommand"] = "445,0,361,175",
			["thedecrepitfields"] = "471,156,176,152",
			["northtidesbeachhead"] = "323,68,174,199",
			["theforsakenfront"] = "433,327,152,189",
			["valgansfield"] = "461,77,162,172",
			["deepelemmine"] = "483,212,217,198",
			["thebattlefront"] = "349,429,255,180",
			["fenrisisle"] = "581,15,352,302",
			["shadowfangkeep"] = "337,337,179,165",
			["olsensfarthing"] = "312,249,251,167",
			["ambermill"] = "509,250,283,243",
			["berensperil"] = "505,405,318,263",
			["forsakenrearguard"] = "369,0,186,238",
			["thegreymanewall"] = "318,506,409,162",
			["theskitteringdark"] = "236,0,227,172",
		},
		["thecapeofstranglethorn"] = {
			["bootybay"] = "289,341,225,255",
			["gurubashiarena"] = "345,0,238,260",
			["mistvalevalley"] = "408,248,253,242",
			["crystalveinmine"] = "528,73,271,204",
			["wildshore"] = "340,392,236,276",
			["nekmaniwellspring"] = "292,213,246,221",
			["ruinsofaboraz"] = "533,181,184,176",
			["jagueroisle"] = "471,404,240,264",
			["thesundering"] = "452,0,244,209",
			["hardwrenchhideaway"] = "208,116,356,221",
			["ruinsofjubuwal"] = "468,119,155,221",
		},
		["vashjirdepths"] = {
			["abyssalbreach"] = "497,0,491,470",
			["seabrush"] = "415,183,225,250",
			["fireplumetrench"] = "315,110,298,251",
			["lghorek"] = "162,210,306,293",
			["coldlightchasm"] = "266,280,267,374",
			["abandonedreef"] = "50,263,371,394",
			["korthunsend"] = "412,283,370,385",
			["deepfinridge"] = "275,32,363,262",
		},
		["stranglethornjungle"] = {
			["kurzenscompound"] = "499,0,244,238",
			["balalruins"] = "267,168,159,137",
			["thevilereef"] = "140,208,236,224",
			["moshoggogremound"] = "543,253,234,206",
			["ruinsofzulkunda"] = "158,0,228,265",
			["fortlivingston"] = "398,375,230,170",
			["mazthoril"] = "488,364,350,259",
			["nesingwarysexpedition"] = "306,63,227,190",
			["zuuldalaruins"] = "9,22,324,263",
			["kalairuins"] = "354,184,139,150",
			["zulgurub"] = "626,0,376,560",
			["baliamahruins"] = "397,243,239,205",
			["bambala"] = "566,164,190,176",
			["mizjahruins"] = "387,246,157,173",
			["lakenazferiti"] = "413,95,240,228",
			["gromgolbasecamp"] = "298,228,167,179",
			["rebelcamp"] = "306,0,302,166",
		},
		["ruinsofgilneas"] = {
			["gilneaspuzzle"] = "0,0,1002,668",
		},

		["gilneas_terrain2"] = {
			["greymanemanor"] = "141,202,244,241",
			["theblackwald"] = "504,394,280,224",
			["theheadlands"] = "160,0,328,336",
			["crowleyorchard"] = "261,427,210,166",
			["emberstonemine"] = "639,43,281,351",
			["duskhaven"] = "272,333,286,178",
			["tempestsreach"] = "652,290,350,345",
			["korothsden"] = "393,386,222,268",
			["hammondfarmstead"] = "167,352,194,236",
			["haywardfishery"] = "293,449,177,219",
			["stormglenvillage"] = "516,465,321,203",
			["northgatewoods"] = "482,14,282,298",
			["northernheadlands"] = "387,0,267,314",
			["keelharbor"] = "298,95,280,342",
		},
		["searinggorge"] = {
			["blackrockmountain"] = "243,424,304,244",
			["thoriumpoint"] = "255,38,429,301",
			["tannercamp"] = "413,360,571,308",
			["thecauldron"] = "232,171,481,360",
			["blackcharcave"] = "0,361,375,307",
			["grimsiltworksite"] = "531,241,441,266",
			["firewatchridge"] = "0,75,365,393",
			["dustfirevalley"] = "588,0,392,355",
		},
		["elwynn"] = {
			["westbrookgarrison"] = "116,355,269,313",
			["jerodslanding"] = "396,430,230,206",
			["northshirevalley"] = "355,138,295,296",
			["goldshire"] = "247,294,276,231",
			["stromwind"] = "0,0,512,422",
			["stonecairnlake"] = "552,186,340,272",
			["crystallake"] = "417,327,220,207",
			["towerofazora"] = "529,287,270,241",
			["ridgepointtower"] = "708,442,285,194",
			["brackwellpumpkinpatch"] = "532,424,287,216",
			["fargodeepmine"] = "240,420,269,248",
			["eastvaleloggingcamp"] = "703,292,294,243",
		},
		["arathi"] = {
			["refugepoint"] = "293,145,196,270",
			["galensfall"] = "0,144,212,305",
			["northfoldmanor"] = "132,105,227,268",
			["circleofeastbinding"] = "506,126,183,238",
			["bouldergor"] = "171,123,249,278",
			["goshekfarm"] = "430,249,306,248",
			["cirecleofouterbinding"] = "332,273,215,188",
			["hammerfall"] = "581,118,270,271",
			["thandolspan"] = "261,416,237,252",
			["boulderfisthall"] = "327,367,252,258",
			["faldirscove"] = "77,400,273,268",
			["witherbarkvillage"] = "476,359,260,220",
			["stromgardekeep"] = "21,269,284,306",
			["dabyriesfarmstead"] = "404,144,210,227",
			["circleofinnerbinding"] = "201,312,228,227",
			["circleofwestbinding"] = "85,24,220,287",
		},
		["dunmorogh"] = {
			["thegrizzledden"] = "374,287,211,160",
			["coldridgepass"] = "360,340,225,276",
			["kharanos"] = "449,220,184,188",
			["gnomeregan"] = "0,27,409,318",
			["thetundridhills"] = "579,306,174,249",
			["theshimmeringdeep"] = "397,132,171,234",
			["golbolarquarry"] = "663,288,198,251",
			["iceflowlake"] = "263,0,236,358",
			["amberstillranch"] = "595,225,249,183",
			["ironforgeairfield"] = "630,0,308,335",
			["frostmanehold"] = "50,227,437,249",
			["coldridgevalley"] = "100,366,398,302",
			["ironforge"] = "398,0,376,347",
			["helmsbedlake"] = "760,268,218,234",
			["northgateoutpost"] = "765,43,237,366",
			["frostmanefront"] = "469,256,226,335",
		},
		["westfall"] = {
			["thedaggerhills"] = "303,395,292,273",
			["furlbrowspumpkinfarm"] = "394,0,197,213",
			["thegapingchasm"] = "294,168,184,217",
			["jangoloadmine"] = "311,0,196,229",
			["goldcoastquarry"] = "199,79,235,306",
			["themolsenfarm"] = "348,118,202,224",
			["westfalllighthouse"] = "221,477,211,167",
			["sentinelhill"] = "404,226,229,265",
			["demontsplace"] = "203,376,201,195",
			["alexstonfarmstead"] = "167,263,346,222",
			["saldeansfarm"] = "451,81,244,237",
			["moonbrook"] = "308,325,232,213",
			["thedustplains"] = "480,378,317,261",
			["thedeadacre"] = "531,200,193,273",
			["thejansenstead"] = "474,0,202,179",
		},
		["burningsteppes"] = {
			["blackrockpass"] = "419,258,298,410",
			["dreadmaulrock"] = "568,151,274,263",
			["dracodar"] = "0,237,362,431",
			["altarofstorms"] = "0,0,182,360",
			["ruinsofthaurissan"] = "421,0,324,354",
			["blackrockmountain"] = "79,0,281,388",
			["terrorwingpath"] = "646,7,350,341",
			["blackrockstronghold"] = "235,0,320,385",
			["morgansvigil"] = "615,255,383,413",
			["pillarofash"] = "253,255,274,413",
		},
		["westernplaguelands"] = {
			["thebulwark"] = "48,235,316,316",
			["hearthglen"] = "235,0,432,271",
			["caerdarrow"] = "601,390,194,208",
			["sorrowhill"] = "261,448,368,220",
			["felstonefield"] = "229,228,241,212",
			["darrowmerelake"] = "510,354,492,314",
			["northridgelumbercamp"] = "231,123,359,182",
			["thewrithinghaunt"] = "472,332,169,195",
			["thondrorilriver"] = "533,0,311,436",
			["theweepingcave"] = "551,151,185,230",
			["redpinedell"] = "286,211,290,133",
			["dalsonsfarm"] = "300,232,325,192",
			["andorhal"] = "96,343,464,325",
			["gahrronswithering"] = "495,213,241,252",
		},
		["tirisfal"] = {
			["balnirfarmstead"] = "594,324,242,179",
			["venomwebvale"] = "752,150,250,279",
			["thebulwark"] = "709,330,293,338",
			["brill"] = "480,252,199,182",
			["scarletmonastery"] = "740,47,262,262",
			["scarletwatchpost"] = "692,99,161,234",
			["agamandmills"] = "324,90,285,260",
			["brightwaterlake"] = "573,122,210,292",
			["ruinsoflorderon"] = "423,359,390,267",
			["sollidenfarmstead"] = "201,192,286,225",
			["calstonestate"] = "389,255,179,169",
			["coldhearthmanor"] = "418,317,212,177",
			["deathknell"] = "9,207,431,407",
			["nightmarevale"] = "347,325,225,281",
			["crusaderoutpost"] = "686,232,175,210",
			["garrenshaunt"] = "477,129,190,214",
		},
		["redridge"] = {
			["rendersvalley"] = "451,377,427,291",
			["stonewatchkeep"] = "480,0,228,420",
			["lakeridgehighway"] = "148,316,392,352",
			["campeverstill"] = "445,286,189,193",
			["renderscamp"] = "214,0,357,246",
			["lakeeverstill"] = "81,214,464,250",
			["lakeshire"] = "0,110,410,256",
			["althersmill"] = "350,139,228,247",
			["shalewindcanyon"] = "688,283,306,324",
			["stonewatchfalls"] = "525,302,316,182",
			["galardellvalley"] = "574,0,428,463",
			["threecorners"] = "0,256,323,406",
			["redridgecanyons"] = "37,0,413,292",
		},
		["swampofsorrows"] = {
			["splinterspearjunction"] = "194,236,238,343",
			["stagalbog"] = "540,360,347,303",
			["marshtidewatch"] = "478,0,330,342",
			["pooloftears"] = "575,238,257,229",
			["theshiftingmire"] = "331,24,292,360",
			["sorrowmurk"] = "703,80,229,418",
			["ithariuscave"] = "7,242,268,316",
			["mistyreedstrand"] = "600,0,402,668",
			["stonard"] = "297,258,357,308",
			["mistyvalley"] = "0,80,268,285",
			["theharborage"] = "161,79,266,284",
			["bogpaddle"] = "600,0,262,193",
		},
		["lochmodan"] = {
			["thefarstriderlodge"] = "570,209,349,292",
			["stronewroughtdam"] = "339,0,333,200",
			["silverstreammine"] = "221,0,225,252",
			["northgatepass"] = "16,0,319,289",
			["ironbandsexcavationsite"] = "481,296,397,291",
			["stonesplintervalley"] = "177,345,273,294",
			["thelsamar"] = "0,146,455,295",
			["grizzlepawridge"] = "245,324,273,230",
			["valleyofkings"] = "0,311,310,345",
			["theloch"] = "340,81,330,474",
			["mogroshstronghold"] = "549,52,294,249",
		},
		["deadwindpass"] = {
			["deadmanscrossing"] = "83,0,617,522",
			["thevice"] = "433,208,350,449",
			["karazhan"] = "92,310,513,358",
		},
		["hillsbradfoothills"] = {
			["tarrenmill"] = "494,226,165,203",
			["gavinsnaze"] = "344,254,116,129",
			["lordamereinternmentcamp"] = "194,216,250,167",
			["mistyshore"] = "321,42,158,169",
			["nethandersteed"] = "502,373,204,244",
			["hillsbradfields"] = "191,302,302,175",
			["growlesscave"] = "359,191,171,136",
			["theheadland"] = "390,255,105,148",
			["azurelodemine"] = "287,399,180,182",
			["dalarancrater"] = "102,137,316,238",
			["gallowscorner"] = "451,140,155,147",
			["strahnbrad"] = "505,44,275,193",
			["darrowhill"] = "425,279,147,160",
			["southpointtower"] = "59,310,312,254",
			["dandredsfold"] = "341,0,258,113",
			["slaughterhollow"] = "413,55,148,120",
			["soferasnaze"] = "484,166,148,146",
			["ruinsofalterac"] = "347,85,189,181",
			["corrahnsdagger"] = "426,224,135,160",
			["purgationisle"] = "200,505,144,139",
			["crushridgehold"] = "463,101,134,124",
			["dungarok"] = "542,410,269,258",
			["durnholdekeep"] = "565,217,437,451",
			["chillwindpoint"] = "555,68,447,263",
			["theuplands"] = "441,0,212,160",
			["southshore"] = "383,352,229,219",
		},

	-- Jamie exports

	["azuremystisle"] =
	{
		["ammenford"] = "515,279,256,256",
		["ammenvale"] = "527,104,475,512",
		["azurewatch"] = "383,249,256,256",
		["bristlelimbvillage"] = "174,363,256,256",
		["emberglade"] = "488,24,256,256",
		["fairbridgestrand"] = "356,0,256,128",
		["greezlescamp"] = "507,350,256,256",
		["moongrazewoods"] = "449,183,256,256",
		["odesyuslanding"] = "352,378,256,256",
		["podcluster"] = "281,305,256,256",
		["podwreckage"] = "462,349,128,256",
		["siltingshore"] = "291,3,256,256",
		["silvermystisle"] = "23,446,256,222",
		["stillpinehold"] = "365,49,256,256",
		["theexodar"] = "74,85,512,512",
		["valaarsberth"] = "176,303,256,256",
		["wrathscalepoint"] = "220,421,256,247",
	},
	["bladesedgemountains"] =
	{
		["bashirlanding"] = "422,0,256,256",
		["bladedgulch"] = "623,147,256,256",
		["bladesiprehold"] = "314,161,256,507",
		["bloodmaulcamp"] = "412,95,256,256",
		["bloodmauloutpost"] = "342,371,256,297",
		["brokenwilds"] = "733,109,256,256",
		["circleofwrath"] = "439,210,256,256",
		["deathsdoor"] = "512,249,256,419",
		["forgecampanger"] = "586,147,416,256",
		["forgecampterror"] = "144,416,512,252",
		["forgecampwrath"] = "254,176,256,256",
		["grishnath"] = "286,28,256,256",
		["gruulslayer"] = "527,81,256,256",
		["jaggedridge"] = "446,414,256,254",
		["moknathalvillage"] = "658,297,256,256",
		["ravenswood"] = "214,55,512,256",
		["razorridge"] = "533,332,256,336",
		["ridgeofmadness"] = "554,258,256,410",
		["ruuanweald"] = "479,98,256,512",
		["skald"] = "673,71,256,256",
		["sylvanaar"] = "289,350,256,318",
		["thecrystalpine"] = "585,0,256,256",
		["thunderlordstronghold"] = "405,272,256,396",
		["veillashh"] = "271,428,256,240",
		["veilruuan"] = "563,151,256,128",
		["vekhaarstand"] = "629,406,256,256",
		["vortexpinnacle"] = "166,206,256,462",
	},
	["bloodmystisle"] =
	{
		["amberwebpass"] = "44,62,256,512",
		["axxarien"] = "297,136,256,256",
		["blacksiltshore"] = "177,426,512,242",
		["bladewood"] = "367,209,256,256",
		["bloodscaleisle"] = "763,256,239,256",
		["bloodwatch"] = "437,258,256,256",
		["bristlelimbenclave"] = "546,410,256,256",
		["kesselscrossing"] = "517,527,485,141",
		["middenvale"] = "414,406,256,256",
		["mystwood"] = "309,483,256,185",
		["nazzivian"] = "250,404,256,256",
		["ragefeatherridge"] = "481,117,256,256",
		["ruinsofloretharan"] = "556,216,256,256",
		["talonstand"] = "657,78,256,256",
		["telathionscamp"] = "180,216,128,128",
		["thebloodcursedreef"] = "729,54,256,256",
		["thebloodwash"] = "302,27,256,256",
		["thecrimsonreach"] = "555,87,256,256",
		["thecryocore"] = "293,285,256,256",
		["thefoulpool"] = "221,136,256,256",
		["thehiddenreef"] = "205,39,256,256",
		["thelostfold"] = "503,470,256,198",
		["thevectorcoil"] = "43,238,512,430",
		["thewarppiston"] = "451,29,256,256",
		["veridianpoint"] = "637,0,256,256",
		["vindicatorsrest"] = "232,242,256,256",
		["wrathscalelair"] = "598,338,256,256",
		["wyrmscarisland"] = "613,82,256,256",
	},
	["eversongwoods"] =
	{
		["azurebreezecoast"] = "669,228,256,256",
		["duskwithergrounds"] = "605,253,256,256",
		["eastsanctum"] = "460,373,256,256",
		["elrendarfalls"] = "580,399,128,256",
		["fairbreezevilliage"] = "386,386,256,256",
		["farstriderretreat"] = "524,359,256,128",
		["goldenboughpass"] = "243,469,256,128",
		["lakeelrendar"] = "584,471,128,197",
		["northsanctum"] = "361,298,256,256",
		["ruinsofsilvermoon"] = "307,136,256,256",
		["runestonefalithas"] = "378,496,256,172",
		["runestoneshandor"] = "464,494,256,174",
		["satherilshaven"] = "324,384,256,256",
		["silvermooncity"] = "440,87,512,512",
		["stillwhisperpond"] = "474,314,256,256",
		["sunsailanchorage"] = "231,404,256,128",
		["sunstriderisle"] = "195,5,512,512",
		["thegoldenstrand"] = "183,415,128,253",
		["thelivingwood"] = "511,420,128,248",
		["thescortchedgrove"] = "255,507,256,128",
		["thuronslivery"] = "539,305,256,128",
		["torwatha"] = "648,315,256,353",
		["tranquilshore"] = "215,298,256,256",
		["westsanctum"] = "292,319,128,256",
		["zebwatha"] = "554,475,128,193",
	},
	["ghostlands"] =
	{
		["amanipass"] = "598,232,404,436",
		["bleedingziggurat"] = "184,238,256,256",
		["dawnstarspire"] = "575,0,427,256",
		["deatholme"] = "95,375,512,293",
		["elrendarcrossing"] = "326,0,512,256",
		["farstriderenclave"] = "573,136,429,256",
		["goldenmistvillage"] = "44,0,512,512",
		["howlingziggurat"] = "340,219,256,449",
		["isleoftribulations"] = "585,0,256,256",
		["sanctumofthemoon"] = "210,126,256,256",
		["sanctumofthesun"] = "448,150,256,512",
		["suncrownvillage"] = "460,0,512,256",
		["thalassiapass"] = "364,406,256,262",
		["tranquillien"] = "365,2,256,512",
		["windrunnerspire"] = "40,287,256,256",
		["windrunnervillage"] = "60,117,256,512",
		["zebnowa"] = "466,237,512,431",
	},
	["hellfire"] =
	{
		["denofhaalesh"] = "182,412,256,256",
		["expeditionarmory"] = "261,413,512,255",
		["falconwatch"] = "183,326,512,342",
		["fallenskyridge"] = "34,142,256,256",
		["forgecamprage"] = "478,25,512,512",
		["hellfirecitadel"] = "338,210,256,458",
		["honorhold"] = "469,298,256,256",
		["magharpost"] = "206,110,256,256",
		["poolsofaggonar"] = "326,45,256,512",
		["ruinsofshanaar"] = "25,290,256,378",
		["templeoftelhamat"] = "38,152,512,512",
		["thelegionfront"] = "579,128,256,512",
		["thestairofdestiny"] = "737,156,256,512",
		["thrallmar"] = "467,154,256,256",
		["throneofkiljaeden"] = "477,6,512,256",
		["voidridge"] = "705,368,256,256",
		["warpfields"] = "308,408,256,260",
		["zethgor"] = "580,430,422,238",
	},
	["nagrand"] =
	{
		["burningbladeruins"] = "660,334,256,334",
		["clanwatch"] = "532,363,256,256",
		["forgecampfear"] = "36,248,512,420",
		["forgecamphate"] = "162,154,256,256",
		["garadar"] = "431,143,256,256",
		["halaa"] = "335,193,256,256",
		["kilsorrowfortress"] = "558,427,256,241",
		["laughingskullruins"] = "351,52,256,256",
		["oshugun"] = "168,334,512,334",
		["ringoftrials"] = "533,267,256,256",
		["southwindcleft"] = "391,258,256,256",
		["sunspringpost"] = "219,199,256,256",
		["telaar"] = "387,390,256,256",
		["throneoftheelements"] = "504,53,256,256",
		["twilightridge"] = "10,107,256,512",
		["warmaulhill"] = "157,32,256,256",
		["windyreedpass"] = "598,79,256,256",
		["windyreedvillage"] = "666,233,256,256",
		["zangarridge"] = "277,54,256,256",
	},
	["netherstorm"] =
	{
		["area52"] = "241,388,256,128",
		["arklonruins"] = "328,397,256,256",
		["celestialridge"] = "644,173,256,256",
		["ecodomefarfield"] = "396,10,256,256",
		["etheriumstaginggrounds"] = "481,208,256,256",
		["forgebaseog"] = "237,22,256,256",
		["kirinvarvillage"] = "490,523,256,145",
		["manaforgebanar"] = "147,281,256,387",
		["manaforgecoruu"] = "357,489,256,179",
		["manaforgeduro"] = "465,336,256,256",
		["manafrogeara"] = "171,155,256,256",
		["netherstone"] = "411,20,256,256",
		["netherstormbridge"] = "132,294,256,256",
		["ruinedmanaforge"] = "513,138,256,256",
		["ruinsofenkaat"] = "253,301,256,256",
		["ruinsoffarahlon"] = "354,49,512,256",
		["socretharsseat"] = "229,38,256,256",
		["sunfuryhold"] = "454,451,256,217",
		["tempestkeep"] = "593,284,409,384",
		["theheap"] = "239,455,256,213",
		["thescrapfield"] = "356,261,256,256",
		["thestormspire"] = "298,134,256,256",
	},
	["shadowmoonvalley"] =
	{
		["altarofshatar"] = "520,93,256,256",
		["coilskarpoint"] = "348,8,512,512",
		["eclipsepoint"] = "343,310,512,358",
		["illadarpoint"] = "143,256,256,256",
		["legionhold"] = "104,155,512,512",
		["netherwingcliffs"] = "554,308,256,256",
		["netherwingledge"] = "510,445,492,223",
		["shadowmoonvilliage"] = "116,35,512,512",
		["theblacktemple"] = "606,126,396,512",
		["thedeathforge"] = "290,129,256,512",
		["thehandofguldan"] = "394,90,512,512",
		["thewardenscage"] = "469,258,512,410",
		["wildhammerstronghold"] = "168,229,512,439",
	},
	["terokkarforest"] =
	{
		["allerianstronghold"] = "480,277,256,256",
		["auchenaigrounds"] = "247,434,256,234",
		["bleedinghollowclanruins"] = "103,301,256,367",
		["bonechewerruins"] = "521,275,256,256",
		["carrionhill"] = "377,272,256,256",
		["cenarionthicket"] = "314,0,256,256",
		["firewingpoint"] = "617,149,385,512",
		["grangolvarvilliage"] = "143,171,512,256",
		["raastokglade"] = "505,154,256,256",
		["razorthornshelf"] = "478,19,256,256",
		["refugecaravan"] = "316,268,128,256",
		["ringofobservance"] = "310,345,256,256",
		["sethekktomb"] = "245,289,256,256",
		["shattrathcity"] = "104,4,512,512",
		["skethylmountains"] = "449,348,512,320",
		["smolderingcaravan"] = "321,460,256,208",
		["stonebreakerhold"] = "397,165,256,256",
		["thebarrierhills"] = "116,4,256,256",
		["tuurem"] = "455,34,256,512",
		["veilrhaze"] = "222,362,256,256",
		["writhingmound"] = "417,327,256,256",
	},
	["zangarmarsh"] =
	{
		["angoroshgrounds"] = "88,50,256,256",
		["angoroshstronghold"] = "124,0,256,128",
		["bloodscaleenclave"] = "596,412,256,256",
		["cenarionrefuge"] = "694,321,308,256",
		["coilfangreservoir"] = "462,90,256,512",
		["feralfenvillage"] = "314,332,512,336",
		["marshlightlake"] = "81,152,256,256",
		["oreborharborage"] = "329,25,256,512",
		["quaggridge"] = "141,325,256,343",
		["sporeggar"] = "20,202,512,256",
		["telredor"] = "569,112,256,512",
		["thedeadmire"] = "716,128,286,512",
		["thehewnbog"] = "219,51,256,512",
		["thelagoon"] = "512,303,256,256",
		["thespawningglen"] = "31,339,256,256",
		["twinspireruins"] = "342,249,256,256",
		["umbrafenvillage"] = "720,461,256,207",
		["zabrajin"] = "175,232,256,256",
	},

	-- Manually added for patch 2.4
	["sunwell"] =
	{
		["sunsreachharbor"] = "252,252,512,416",
		["sunsreachsanctum"] = "251,4,512,512",
	},

	-- WotLK

	["scarletenclave"] =
	{
		["scarletenclave"] = "0,0,1024,768",	-- FIX!!
	},
	["lakewintergrasp"] = {
		["lakewintergrasp"] = "0,0,1024,768",
	},
	["dalaran"] = {
		["dalaran1_"] = "0,0,1024,768",		-- FIX!!
	},
	
	["npe"] = {
		["npe"] = "0,0,1024,768",		-- FIX!!
	},

	["boreantundra"] = {
		["deathsstand"] = "707,181,289,279",
		["templecityofenkilah"] = "712,15,290,292",
		["warsongstronghold"] = "329,237,260,278",
		["riplashstrand"] = "293,383,382,258",
		["thedensofdying"] = "662,11,203,209",
		["thegeyserfields"] = "480,0,375,342",
		["torpsfarm"] = "272,237,186,276",
		["valiancekeep"] = "457,264,259,302",
		["garroshslanding"] = "153,238,267,378",
		["borgorokoutpost"] = "314,0,396,203",
		["amberledge"] = "325,140,244,214",
		["kaskala"] = "509,214,385,316",
		["steeljawscaravan"] = "397,66,244,319",
		["coldarra"] = "50,0,460,381",
	},
	["sholazarbasin"] = {
		["kartakshold"] = "76,375,329,293",
		["theavalanche"] = "596,92,322,265",
		["thesavagethicket"] = "396,51,293,229",
		["thesuntouchedpillar"] = "82,186,455,316",
		["themakersperch"] = "172,135,249,248",
		["themakersoverlook"] = "705,236,233,286",
		["rainspeakercanopy"] = "427,244,207,235",
		["themosslightpillar"] = "265,355,239,313",
		["theglimmeringpillar"] = "308,34,294,327",
		["thelifebloodpillar"] = "501,134,312,369",
		["thestormwrightsshelf"] = "138,58,268,288",
		["riversheart"] = "359,339,468,329",
	},
	["dragonblight"] = {
		["lightsrest"] = "703,7,299,278",
		["galakrondsrest"] = "433,118,258,225",
		["newhearthglen"] = "614,358,214,261",
		["rubydragonshrine"] = "374,208,188,211",
		["icemistvillage"] = "134,165,235,337",
		["venomspite"] = "661,264,226,212",
		["westwindrefugeecamp"] = "42,187,229,299",
		["obsidiandragonshrine"] = "256,104,304,203",
		["naxxramas"] = "691,160,311,272",
		["wyrmresttemple"] = "453,219,317,353",
		["scarletpoint"] = "569,7,235,354",
		["emeralddragonshrine"] = "543,362,196,218",
		["agmarshammer"] = "258,203,236,218",
		["theforgottenshore"] = "698,332,301,286",
		["thecrystalvice"] = "487,0,229,259",
		["angrathar"] = "210,0,306,242",
		["lakeindule"] = "217,313,356,300",
		["coldwindheights"] = "403,0,213,219",
	},
	["crystalsongforest"] = {
		["windrunnersoverlook"] = "444,383,558,285",
		["theunboundthicket"] = "500,105,502,477",
		["theazurefront"] = "0,244,416,424",
		["forlornwoods"] = "129,0,544,668",
		["violetstand"] = "0,176,264,303",
		["thegreattree"] = "0,91,252,260",
		["thedecrepitflow"] = "0,0,288,222",
		["sunreaverscommand"] = "536,40,446,369",
	},
	["howlingfjord"] = {
		["scalawagpoint"] = "168,410,350,258",
		["baleheim"] = "576,170,174,173",
		["giantsrun"] = "572,0,298,306",
		["halgrind"] = "397,208,187,263",
		["utgardekeep"] = "477,216,248,382",
		["vengeancelanding"] = "664,25,223,338",
		["nifflevar"] = "595,240,178,208",
		["emberclutch"] = "283,203,213,256",
		["ivaldsruin"] = "668,223,193,201",
		["cauldrosisle"] = "490,161,181,178",
		["fortwildervar"] = "490,0,251,192",
		["thetwistedglade"] = "420,57,266,210",
		["newagamand"] = "415,360,284,308",
		["baelgunsexcavationsite"] = "621,327,244,305",
		["apothecarycamp"] = "99,37,263,265",
		["ancientlift"] = "342,351,177,191",
		["kamagua"] = "99,278,333,265",
		["gjalerbron"] = "225,0,242,189",
		["explorersleagueoutpost"] = "585,336,232,216",
		["westguardkeep"] = "90,180,347,220",
		["skorn"] = "343,108,238,232",
		["campwinterhoof"] = "354,0,223,209",
		["steelgate"] = "222,100,222,168",
	},
	["zuldrak"] = {
		["zeramas"] = "7,412,307,256",
		["draksotrafields"] = "326,358,286,265",
		["altarofrhunok"] = "431,127,247,304",
		["altarofsseratus"] = "288,168,237,248",
		["kolramas"] = "380,437,302,231",
		["gundrak"] = "629,0,336,297",
		["altarofquetzlun"] = "607,251,261,288",
		["altarofharkoa"] = "533,345,265,257",
		["lightsbreach"] = "181,363,321,305",
		["thrymsend"] = "0,247,272,268",
		["amphitheaterofanguish"] = "289,287,266,254",
		["voltarus"] = "174,191,218,291",
		["altarofmamtoth"] = "575,88,291,258",
		["zimtorga"] = "479,241,249,258",
	},
	["grizzlyhills"] = {
		["grizzlemaw"] = "358,187,294,227",
		["voldrune"] = "176,421,283,247",
		["conquesthold"] = "17,307,332,294",
		["dunargol"] = "547,257,455,400",
		["ragefangshrine"] = "312,294,475,362",
		["drakiljinruins"] = "607,41,351,284",
		["venturebay"] = "18,461,274,207",
		["thormodan"] = "509,0,329,246",
		["granitesprings"] = "7,207,356,224",
		["blueskylogginggrounds"] = "232,129,249,235",
		["draktheronkeep"] = "0,46,382,285",
		["amberpinelodge"] = "217,244,278,290",
		["ursocsden"] = "331,32,328,260",
		["camponeqwah"] = "548,137,324,265",
	},
	["thestormpeaks"] = {
		["frosthold"] = "134,429,244,220",
		["templeofstorms"] = "239,301,169,164",
		["ulduar"] = "218,0,369,265",
		["sparksocketminefield"] = "242,468,251,200",
		["borsbreath"] = "109,375,322,195",
		["engineofthemakers"] = "316,296,210,179",
		["garmsbane"] = "395,470,184,191",
		["dunniffelem"] = "481,285,309,383",
		["narvirscradle"] = "214,144,180,239",
		["nidavelir"] = "108,206,221,200",
		["brunnhildarvillage"] = "339,370,305,298",
		["snowdriftplains"] = "162,143,205,232",
		["valkyrion"] = "98,318,228,158",
		["templeoflife"] = "570,113,182,270",
		["terraceofthemakers"] = "292,122,363,341",
		["thunderfall"] = "627,179,306,484",
	},
	["icecrownglacier"] = {
		["aldurthar"] = "355,37,373,375",
		["corprethar"] = "342,392,308,212",
		["thebombardment"] = "538,181,248,243",
		["onslaughtharbor"] = "0,167,204,268",
		["sindragosasfall"] = "626,31,300,343",
		["thefleshwerks"] = "218,291,219,283",
		["jotunheim"] = "22,122,393,474",
		["valleyofechoes"] = "715,390,269,217",
		["theconflagration"] = "327,305,227,210",
		["thebrokenfront"] = "558,329,283,231",
		["scourgeholme"] = "690,267,245,239",
		["ymirheim"] = "444,276,223,207",
		["theshadowvault"] = "321,15,223,399",
		["argenttournamentground"] = "616,30,314,224",
		["icecrowncitadel"] = "392,466,308,202",
		["valhalas"] = "217,50,238,240",
	},

	-- Patch 3.2
	["hrothgarslanding"] =
	{
--		["hrothgarslanding"] = "0,0,1024,768",
		["hrothgarslanding2"] = "256,0,256,256,1",	-- Just draw 4 parts
		["hrothgarslanding3"] = "512,0,256,256,1",
		["hrothgarslanding6"] = "256,256,256,256,1",
		["hrothgarslanding7"] = "512,256,256,256,1",
	},

	-- Cataclysm
	["tolbarad"] = {
		["tolbarad"] = "0,0,1024,768",			-- Manual
	},
	["tolbaraddailyarea"] = {
		["tolbaraddailyarea"] = "0,0,1024,768",		-- Manual
	},

	["themaelstrom"] = {
		["themaelstrom"] = "0,0,1024,768",		-- Manual
	},
	["thelostisles_terrain2"] = {
		["gallywixdocks"] = "351,21,173,180",
		["alliancebeachhead"] = "129,348,177,172",
		["bilgewaterlumberyard"] = "462,43,248,209",
		["thesavageglen"] = "213,325,231,216",
		["oostan"] = "492,161,210,258",
		["raptorrise"] = "416,368,168,205",
		["warchiefslookout"] = "264,144,159,230",
		["ooomlotvillage"] = "508,345,221,211",
		["scorchedgully"] = "323,185,305,288",
		["ktcoilplatform"] = "433,11,156,142",
		["hordebasecamp"] = "244,458,222,190",
		["lostpeak"] = "581,21,350,517",
		["shipwreckshore"] = "189,408,172,175",
		["skyfalls"] = "416,131,190,186",
		["ruinsofvashelan"] = "440,452,212,216",
		["landingsite"] = "377,359,142,133",
		["theslavepits"] = "279,68,212,193",
	},
	["kezan"] = {
		["bilgewaterport"] = "163,148,694,290",
		["firstbankofkezan"] = "98,325,376,343",
		["swindlestreet"] = "317,232,168,213",
		["theslick"] = "219,108,592,202",
		["kajamine"] = "586,308,354,360",
		["kajarofield"] = "383,260,250,307",
		["gallywixsvilla"] = "0,41,303,452",
		["kezanmap"] = "0,4,1002,664",
		["drudgetown"] = "180,367,351,301",
	},
	["deepholm"] = {
		["stonehearth"] = "0,314,371,354",
		["twilightterrace"] = "297,384,237,198",
		["scouredreach"] = "448,0,516,287",
		["needlerockchasm"] = "20,0,378,359",
		["stormsfurywreckage"] = "458,383,292,285",
		["twilightoverlook"] = "570,420,411,248",
		["deathwingsfall"] = "549,297,454,343",
		["thepaleroost"] = "85,0,467,273",
		["needlerockslag"] = "0,146,370,285",
		["theshatteredfield"] = "141,438,430,230",
		["therazanesthrone"] = "434,0,274,156",
		["crimsonexpanse"] = "540,12,462,400",
		["templeofearth"] = "287,177,355,345",
	},

	["moltenfront"] = {
		["moltenfront"] = "0,0,1024,768",		-- Manual
	},

}

--------
-- OLD From Textures\Minimap\md5translate.trs
-- From art.mpq World\Minimaps

Map.KalMapBlks = {
	[2341] = 207604,
	[2342] = 207605,
	[2343] = 207606,
	[2344] = 207607,
	[2345] = 207608,
	[2439] = 207622,
	[2440] = 207623,
	[2441] = 207624,
	[2442] = 207625,
	[2443] = 207626,
	[2444] = 207627,
	[2445] = 207628,
	[2512] = 207632,
	[2513] = 207633,
	[2514] = 207634,
	[2515] = 207635,
	[2533] = 207653,
	[2534] = 207654,
	[2535] = 207655,
	[2536] = 207656,
	[2537] = 207657,
	[2538] = 207658,
	[2539] = 207659,
	[2540] = 207660,
	[2541] = 207661,
	[2542] = 207662,
	[2543] = 207663,
	[2544] = 207664,
	[2545] = 207665,
	[2546] = 207666,
	[2611] = 207678,
	[2612] = 207679,
	[2613] = 207680,
	[2614] = 207681,
	[2615] = 207682,
	[2616] = 207683,
	[2624] = 207691,
	[2625] = 207692,
	[2626] = 207693,
	[2627] = 207694,
	[2628] = 207695,
	[2629] = 207696,
	[2630] = 207697,
	[2631] = 207698,
	[2632] = 207699,
	[2633] = 207700,
	[2634] = 207701,
	[2635] = 207702,
	[2636] = 207703,
	[2637] = 207704,
	[2638] = 207705,
	[2639] = 207706,
	[2640] = 207707,
	[2641] = 207708,
	[2642] = 207709,
	[2643] = 207710,
	[2644] = 207711,
	[2645] = 207712,
	[2646] = 207713,
	[2647] = 207714,
	[2648] = 207715,
	[2649] = 207716,
	[2650] = 207717,
	[2651] = 207718,
	[2709] = 207723,
	[2710] = 207724,
	[2711] = 207725,
	[2712] = 207726,
	[2713] = 207727,
	[2714] = 207728,
	[2715] = 207729,
	[2716] = 207730,
	[2717] = 207731,
	[2718] = 207732,
	[2719] = 207733,
	[2720] = 207734,
	[2721] = 207735,
	[2722] = 207736,
	[2723] = 207737,
	[2724] = 207738,
	[2725] = 207739,
	[2726] = 207740,
	[2727] = 207741,
	[2728] = 207742,
	[2729] = 207743,
	[2730] = 207744,
	[2731] = 207745,
	[2732] = 207746,
	[2733] = 207747,
	[2734] = 207748,
	[2735] = 207749,
	[2736] = 207750,
	[2737] = 207751,
	[2738] = 207752,
	[2739] = 207753,
	[2740] = 207754,
	[2741] = 207755,
	[2742] = 207756,
	[2743] = 207757,
	[2744] = 207758,
	[2745] = 207759,
	[2746] = 207760,
	[2747] = 207761,
	[2748] = 207762,
	[2749] = 207763,
	[2750] = 207764,
	[2751] = 207765,
	[2752] = 207766,
	[2809] = 207770,
	[2810] = 207771,
	[2811] = 207772,
	[2812] = 207773,
	[2813] = 207774,
	[2814] = 207775,
	[2815] = 207776,
	[2816] = 207777,
	[2817] = 207778,
	[2818] = 207779,
	[2819] = 207780,
	[2820] = 207781,
	[2821] = 207782,
	[2822] = 207783,
	[2823] = 207784,
	[2824] = 207785,
	[2825] = 207786,
	[2826] = 207787,
	[2827] = 207788,
	[2828] = 207789,
	[2829] = 207790,
	[2830] = 207791,
	[2831] = 207792,
	[2832] = 207793,
	[2833] = 207794,
	[2834] = 207795,
	[2835] = 207796,
	[2836] = 207797,
	[2837] = 207798,
	[2838] = 207799,
	[2839] = 207800,
	[2840] = 207801,
	[2841] = 207802,
	[2842] = 207803,
	[2843] = 207804,
	[2844] = 207805,
	[2845] = 207806,
	[2846] = 207807,
	[2847] = 207808,
	[2848] = 207809,
	[2849] = 207810,
	[2850] = 207811,
	[2851] = 207812,
	[2852] = 207813,
	[2909] = 207817,
	[2910] = 207818,
	[2911] = 207819,
	[2912] = 207820,
	[2913] = 207821,
	[2914] = 207822,
	[2915] = 207823,
	[2916] = 207824,
	[2917] = 207825,
	[2918] = 207826,
	[2919] = 207827,
	[2920] = 207828,
	[2921] = 207829,
	[2922] = 207830,
	[2923] = 207831,
	[2924] = 207832,
	[2925] = 207833,
	[2926] = 207834,
	[2927] = 207835,
	[2928] = 207836,
	[2929] = 207837,
	[2930] = 207838,
	[2931] = 207839,
	[2932] = 207840,
	[2933] = 207841,
	[2934] = 207842,
	[2935] = 207843,
	[2936] = 207844,
	[2937] = 207845,
	[2938] = 207846,
	[2939] = 207847,
	[2940] = 207848,
	[2941] = 207849,
	[2942] = 207850,
	[2943] = 207851,
	[2944] = 207852,
	[2945] = 207853,
	[2946] = 207854,
	[2947] = 207855,
	[2948] = 207856,
	[2949] = 207857,
	[2950] = 207858,
	[2951] = 207859,
	[2952] = 207860,
	[3009] = 207864,
	[3010] = 207865,
	[3011] = 207866,
	[3012] = 207867,
	[3013] = 207868,
	[3014] = 207869,
	[3015] = 207870,
	[3016] = 207871,
	[3017] = 207872,
	[3018] = 207873,
	[3019] = 207874,
	[3020] = 207875,
	[3021] = 207876,
	[3022] = 207877,
	[3023] = 207878,
	[3024] = 207879,
	[3025] = 207880,
	[3026] = 207881,
	[3027] = 207882,
	[3028] = 207883,
	[3029] = 207884,
	[3030] = 207885,
	[3031] = 207886,
	[3032] = 207887,
	[3033] = 207888,
	[3034] = 207889,
	[3035] = 207890,
	[3036] = 207891,
	[3037] = 207892,
	[3038] = 207893,
	[3039] = 207894,
	[3040] = 207895,
	[3041] = 207896,
	[3042] = 207897,
	[3043] = 207898,
	[3044] = 207899,
	[3045] = 207900,
	[3046] = 207901,
	[3047] = 207902,
	[3048] = 207903,
	[3049] = 207904,
	[3050] = 207905,
	[3051] = 207906,
	[3052] = 207907,
	[3109] = 207911,
	[3110] = 207912,
	[3111] = 207913,
	[3112] = 207914,
	[3113] = 207915,
	[3114] = 207916,
	[3115] = 207917,
	[3116] = 207918,
	[3117] = 207919,
	[3118] = 207920,
	[3119] = 207921,
	[3120] = 207922,
	[3121] = 207923,
	[3122] = 207924,
	[3123] = 207925,
	[3124] = 207926,
	[3125] = 207927,
	[3126] = 207928,
	[3127] = 207929,
	[3128] = 207930,
	[3129] = 207931,
	[3130] = 207932,
	[3131] = 207933,
	[3132] = 207934,
	[3133] = 207935,
	[3134] = 207936,
	[3135] = 207937,
	[3136] = 207938,
	[3137] = 207939,
	[3138] = 207940,
	[3139] = 207941,
	[3140] = 207942,
	[3141] = 207943,
	[3142] = 207944,
	[3143] = 207945,
	[3144] = 207946,
	[3145] = 207947,
	[3146] = 207948,
	[3147] = 207949,
	[3148] = 207950,
	[3149] = 207951,
	[3150] = 207952,
	[3151] = 207953,
	[3152] = 207954,
	[3153] = 207955,
	[3210] = 207959,
	[3211] = 207960,
	[3212] = 207961,
	[3213] = 207962,
	[3214] = 207963,
	[3215] = 207964,
	[3216] = 207965,
	[3217] = 207966,
	[3218] = 207967,
	[3219] = 207968,
	[3220] = 207969,
	[3221] = 207970,
	[3222] = 207971,
	[3223] = 207972,
	[3224] = 207973,
	[3225] = 207974,
	[3226] = 207975,
	[3227] = 207976,
	[3228] = 207977,
	[3229] = 207978,
	[3230] = 207979,
	[3231] = 207980,
	[3232] = 207981,
	[3233] = 207982,
	[3234] = 207983,
	[3235] = 207984,
	[3236] = 207985,
	[3237] = 207986,
	[3238] = 207987,
	[3239] = 207988,
	[3240] = 207989,
	[3241] = 207990,
	[3242] = 207991,
	[3243] = 207992,
	[3244] = 207993,
	[3245] = 207994,
	[3246] = 207995,
	[3247] = 207996,
	[3248] = 207997,
	[3249] = 207998,
	[3250] = 207999,
	[3251] = 208000,
	[3252] = 208001,
	[3253] = 208002,
	[3311] = 208007,
	[3312] = 208008,
	[3313] = 208009,
	[3314] = 208010,
	[3315] = 208011,
	[3316] = 208012,
	[3317] = 208013,
	[3318] = 208014,
	[3319] = 208015,
	[3320] = 208016,
	[3321] = 208017,
	[3322] = 208018,
	[3323] = 208019,
	[3324] = 208020,
	[3325] = 208021,
	[3326] = 208022,
	[3327] = 208023,
	[3328] = 208024,
	[3329] = 208025,
	[3330] = 208026,
	[3331] = 208027,
	[3332] = 208028,
	[3333] = 208029,
	[3334] = 208030,
	[3335] = 208031,
	[3336] = 208032,
	[3337] = 208033,
	[3338] = 208034,
	[3339] = 208035,
	[3340] = 208036,
	[3341] = 208037,
	[3342] = 208038,
	[3343] = 208039,
	[3344] = 208040,
	[3345] = 208041,
	[3346] = 208042,
	[3347] = 208043,
	[3348] = 208044,
	[3349] = 208045,
	[3350] = 208046,
	[3351] = 208047,
	[3352] = 208048,
	[3353] = 208049,
	[3415] = 208055,
	[3416] = 208056,
	[3417] = 208057,
	[3418] = 208058,
	[3419] = 208059,
	[3420] = 208060,
	[3421] = 208061,
	[3422] = 208062,
	[3423] = 208063,
	[3424] = 208064,
	[3425] = 208065,
	[3426] = 208066,
	[3427] = 208067,
	[3428] = 208068,
	[3429] = 208069,
	[3430] = 208070,
	[3431] = 208071,
	[3432] = 208072,
	[3433] = 208073,
	[3434] = 208074,
	[3435] = 208075,
	[3436] = 208076,
	[3437] = 208077,
	[3438] = 208078,
	[3439] = 208079,
	[3440] = 208080,
	[3441] = 208081,
	[3442] = 208082,
	[3443] = 208083,
	[3444] = 208084,
	[3445] = 208085,
	[3446] = 208086,
	[3447] = 208087,
	[3448] = 208088,
	[3449] = 208089,
	[3450] = 208090,
	[3451] = 208091,
	[3452] = 208092,
	[3453] = 208093,
	[3515] = 208099,
	[3516] = 208100,
	[3517] = 208101,
	[3518] = 208102,
	[3519] = 208103,
	[3520] = 208104,
	[3521] = 208105,
	[3522] = 208106,
	[3523] = 208107,
	[3524] = 208108,
	[3525] = 208109,
	[3526] = 208110,
	[3527] = 208111,
	[3528] = 208112,
	[3529] = 208113,
	[3530] = 208114,
	[3531] = 208115,
	[3532] = 208116,
	[3533] = 208117,
	[3534] = 208118,
	[3535] = 208119,
	[3536] = 208120,
	[3537] = 208121,
	[3538] = 208122,
	[3539] = 208123,
	[3540] = 208124,
	[3541] = 208125,
	[3542] = 208126,
	[3543] = 208127,
	[3544] = 208128,
	[3545] = 208129,
	[3546] = 208130,
	[3547] = 208131,
	[3548] = 208132,
	[3549] = 208133,
	[3550] = 208134,
	[3551] = 208135,
	[3552] = 208136,
	[3553] = 208137,
	[3615] = 208143,
	[3616] = 208144,
	[3617] = 208145,
	[3618] = 208146,
	[3619] = 208147,
	[3620] = 208148,
	[3621] = 208149,
	[3622] = 208150,
	[3623] = 208151,
	[3624] = 208152,
	[3625] = 208153,
	[3626] = 208154,
	[3627] = 208155,
	[3628] = 208156,
	[3629] = 208157,
	[3630] = 208158,
	[3631] = 208159,
	[3632] = 208160,
	[3633] = 208161,
	[3634] = 208162,
	[3635] = 208163,
	[3636] = 208164,
	[3637] = 208165,
	[3638] = 208166,
	[3639] = 208167,
	[3640] = 208168,
	[3641] = 208169,
	[3642] = 208170,
	[3643] = 208171,
	[3644] = 208172,
	[3645] = 208173,
	[3646] = 208174,
	[3647] = 208175,
	[3648] = 208176,
	[3649] = 208177,
	[3650] = 208178,
	[3651] = 208179,
	[3652] = 208180,
	[3653] = 208181,
	[3714] = 208186,
	[3715] = 208187,
	[3716] = 208188,
	[3717] = 208189,
	[3718] = 208190,
	[3719] = 208191,
	[3720] = 208192,
	[3721] = 208193,
	[3722] = 208194,
	[3723] = 208195,
	[3724] = 208196,
	[3725] = 208197,
	[3726] = 208198,
	[3727] = 208199,
	[3728] = 208200,
	[3729] = 208201,
	[3730] = 208202,
	[3731] = 208203,
	[3732] = 208204,
	[3733] = 208205,
	[3734] = 208206,
	[3735] = 208207,
	[3736] = 208208,
	[3737] = 208209,
	[3738] = 208210,
	[3739] = 208211,
	[3740] = 208212,
	[3741] = 208213,
	[3742] = 208214,
	[3743] = 208215,
	[3744] = 208216,
	[3745] = 208217,
	[3746] = 208218,
	[3747] = 208219,
	[3748] = 208220,
	[3749] = 208221,
	[3750] = 208222,
	[3751] = 208223,
	[3752] = 208224,
	[3814] = 208230,
	[3815] = 208231,
	[3816] = 208232,
	[3817] = 208233,
	[3818] = 208234,
	[3819] = 208235,
	[3820] = 208236,
	[3821] = 208237,
	[3822] = 208238,
	[3823] = 208239,
	[3824] = 208240,
	[3825] = 208241,
	[3826] = 208242,
	[3827] = 208243,
	[3828] = 208244,
	[3829] = 208245,
	[3830] = 208246,
	[3831] = 208247,
	[3832] = 208248,
	[3833] = 208249,
	[3834] = 208250,
	[3835] = 208251,
	[3836] = 208252,
	[3837] = 208253,
	[3838] = 208254,
	[3839] = 208255,
	[3840] = 208256,
	[3841] = 208257,
	[3842] = 208258,
	[3843] = 208259,
	[3844] = 208260,
	[3845] = 208261,
	[3846] = 208262,
	[3847] = 208263,
	[3848] = 208264,
	[3849] = 208265,
	[3850] = 208266,
	[3851] = 208267,
	[3914] = 208274,
	[3915] = 208275,
	[3916] = 208276,
	[3917] = 208277,
	[3918] = 208278,
	[3919] = 208279,
	[3920] = 208280,
	[3921] = 208281,
	[3922] = 208282,
	[3923] = 208283,
	[3924] = 208284,
	[3925] = 208285,
	[3926] = 208286,
	[3927] = 208287,
	[3928] = 208288,
	[3929] = 208289,
	[3930] = 208290,
	[3931] = 208291,
	[3932] = 208292,
	[3933] = 208293,
	[3934] = 208294,
	[3935] = 208295,
	[3936] = 208296,
	[3937] = 208297,
	[3938] = 208298,
	[3939] = 208299,
	[3940] = 208300,
	[3941] = 208301,
	[3942] = 208302,
	[3943] = 208303,
	[3944] = 208304,
	[3945] = 208305,
	[3946] = 208306,
	[3947] = 208307,
	[3948] = 208308,
	[3949] = 208309,
	[3950] = 208310,
	[3951] = 208311,
	[4014] = 208318,
	[4015] = 208319,
	[4016] = 208320,
	[4017] = 208321,
	[4018] = 208322,
	[4019] = 208323,
	[4020] = 208324,
	[4021] = 208325,
	[4022] = 208326,
	[4023] = 208327,
	[4024] = 208328,
	[4025] = 208329,
	[4026] = 208330,
	[4027] = 208331,
	[4028] = 208332,
	[4029] = 208333,
	[4030] = 208334,
	[4031] = 208335,
	[4032] = 208336,
	[4033] = 208337,
	[4034] = 208338,
	[4035] = 208339,
	[4036] = 208340,
	[4037] = 208341,
	[4038] = 208342,
	[4039] = 208343,
	[4040] = 208344,
	[4041] = 208345,
	[4042] = 208346,
	[4043] = 208347,
	[4044] = 208348,
	[4045] = 208349,
	[4046] = 208350,
	[4047] = 208351,
	[4048] = 208352,
	[4049] = 208353,
	[4050] = 208354,
	[4051] = 208355,
	[4115] = 208363,
	[4116] = 208364,
	[4117] = 208365,
	[4118] = 208366,
	[4119] = 208367,
	[4120] = 208368,
	[4121] = 208369,
	[4122] = 208370,
	[4123] = 208371,
	[4124] = 208372,
	[4125] = 208373,
	[4126] = 208374,
	[4127] = 208375,
	[4128] = 208376,
	[4129] = 208377,
	[4130] = 208378,
	[4131] = 208379,
	[4132] = 208380,
	[4133] = 208381,
	[4134] = 208382,
	[4135] = 208383,
	[4136] = 208384,
	[4137] = 208385,
	[4138] = 208386,
	[4139] = 208387,
	[4140] = 208388,
	[4141] = 208389,
	[4142] = 208390,
	[4143] = 208391,
	[4144] = 208392,
	[4145] = 208393,
	[4146] = 208394,
	[4147] = 208395,
	[4148] = 208396,
	[4149] = 208397,
	[4150] = 208398,
	[4151] = 208399,
	[4216] = 208408,
	[4217] = 208409,
	[4218] = 208410,
	[4219] = 208411,
	[4220] = 208412,
	[4221] = 208413,
	[4222] = 208414,
	[4223] = 208415,
	[4224] = 208416,
	[4225] = 208417,
	[4226] = 208418,
	[4227] = 208419,
	[4228] = 208420,
	[4229] = 208421,
	[4230] = 208422,
	[4231] = 208423,
	[4232] = 208424,
	[4233] = 208425,
	[4234] = 208426,
	[4235] = 208427,
	[4236] = 208428,
	[4237] = 208429,
	[4238] = 208430,
	[4239] = 208431,
	[4240] = 208432,
	[4241] = 208433,
	[4242] = 208434,
	[4243] = 208435,
	[4244] = 208436,
	[4245] = 208437,
	[4246] = 208438,
	[4247] = 208439,
	[4248] = 208440,
	[4249] = 208441,
	[4250] = 208442,
	[4251] = 208443,
	[4316] = 208452,
	[4317] = 208453,
	[4318] = 208454,
	[4319] = 208455,
	[4320] = 208456,
	[4321] = 208457,
	[4322] = 208458,
	[4323] = 208459,
	[4324] = 208460,
	[4325] = 208461,
	[4326] = 208462,
	[4327] = 208463,
	[4328] = 208464,
	[4329] = 208465,
	[4330] = 208466,
	[4331] = 208467,
	[4332] = 208468,
	[4333] = 208469,
	[4334] = 208470,
	[4335] = 208471,
	[4344] = 208477,
	[4345] = 208478,
	[4346] = 208479,
	[4347] = 208480,
	[4348] = 208481,
	[4349] = 208482,
	[4421] = 208492,
	[4422] = 208493,
	[4423] = 208494,
	[4424] = 208495,
	[4425] = 208496,
	[4426] = 208497,
	[4427] = 208498,
	[4428] = 208499,
	[4429] = 208500,
	[4521] = 208518,
	[4522] = 208519,
	[4523] = 208520,
	[4524] = 208521,
	[4525] = 208522,
	[4526] = 208523,
	[4527] = 208524,
	[4528] = 208525,
	[4529] = 208526,
	[4621] = 208534,
	[4622] = 208535,
	[4623] = 208536,
	[4624] = 208537,
	[4625] = 208538,
	[4626] = 208539,
	[4627] = 208540,
	[4628] = 208541,
	[4629] = 208542,
	[4722] = 208551,
	[4723] = 208552,
	[4724] = 208553,
}

Map.EkMapBlks = {
	[1741] = 467255,
	[1742] = 467189,
	[1743] = 467193,
	[1744] = 467197,
	[1745] = 467134,
	[1746] = 467139,
	[1841] = 467256,
	[1842] = 467190,
	[1843] = 467194,
	[1844] = 467198,
	[1845] = 467135,
	[1846] = 467140,
	[1941] = 467246,
	[1942] = 467191,
	[1943] = 467195,
	[1944] = 467199,
	[1945] = 467136,
	[1946] = 467141,
	[2039] = 467241,
	[2040] = 467244,
	[2041] = 467247,
	[2042] = 467192,
	[2043] = 467196,
	[2044] = 467200,
	[2045] = 467137,
	[2046] = 467142,
	[2139] = 467242,
	[2140] = 467245,
	[2141] = 467248,
	[2142] = 467201,
	[2143] = 467203,
	[2144] = 467207,
	[2145] = 467138,
	[2146] = 467143,
	[2239] = 467232,
	[2240] = 467235,
	[2241] = 467236,
	[2242] = 467202,
	[2243] = 467204,
	[2244] = 467208,
	[2245] = 467149,
	[2246] = 467155,
	[2339] = 467233,
	[2340] = 466918,
	[2341] = 466921,
	[2342] = 466924,
	[2343] = 467205,
	[2344] = 467209,
	[2345] = 467150,
	[2346] = 467156,
	[2439] = 467234,
	[2440] = 466919,
	[2441] = 466922,
	[2442] = 466925,
	[2443] = 467206,
	[2444] = 467210,
	[2445] = 467151,
	[2446] = 467157,
	[2539] = 467222,
	[2540] = 466920,
	[2541] = 466923,
	[2542] = 466926,
	[2543] = 467213,
	[2544] = 467216,
	[2545] = 467152,
	[2546] = 467158,
	[2639] = 467223,
	[2640] = 467225,
	[2641] = 467227,
	[2642] = 467211,
	[2643] = 467214,
	[2644] = 467217,
	[2645] = 467153,
	[2627] = 204242,
	[2628] = 204243,
	[2629] = 204244,
	[2630] = 204245,
	[2631] = 204246,
	[2632] = 204247,
	[2633] = 204248,
	[2634] = 204249,
	[2635] = 204250,
	[2636] = 204251,
	[2637] = 253800,
	[2652] = 204260,
	[2653] = 204261,
	[2654] = 204262,
	[2726] = 204271,
	[2727] = 204272,
	[2728] = 204273,
	[2729] = 204274,
	[2730] = 204275,
	[2731] = 204276,
	[2732] = 204277,
	[2733] = 204278,
	[2734] = 204279,
	[2735] = 204280,
	[2736] = 204281,
	[2737] = 204282,
	[2749] = 204294,
	[2750] = 204295,
	[2751] = 204296,
	[2752] = 204297,
	[2753] = 204298,
	[2754] = 204299,
	[2825] = 204310,
	[2826] = 204311,
	[2827] = 204312,
	[2828] = 204313,
	[2829] = 204314,
	[2830] = 204315,
	[2831] = 204316,
	[2832] = 204317,
	[2833] = 204318,
	[2834] = 204319,
	[2835] = 204320,
	[2836] = 204321,
	[2837] = 204322,
	[2838] = 204323,
	[2839] = 204324,
	[2840] = 204325,
	[2841] = 204326,
	[2842] = 204327,
	[2843] = 204328,
	[2844] = 204329,
	[2845] = 204330,
	[2846] = 204331,
	[2847] = 204332,
	[2848] = 204333,
	[2849] = 204334,
	[2850] = 204335,
	[2851] = 204336,
	[2852] = 204337,
	[2853] = 204338,
	[2854] = 204339,
	[2855] = 204340,
	[2856] = 204341,
	[2857] = 204342,
	[2858] = 204343,
	[2859] = 204344,
	[2925] = 204350,
	[2926] = 204351,
	[2927] = 204352,
	[2928] = 204353,
	[2929] = 204354,
	[2930] = 204355,
	[2931] = 204356,
	[2932] = 204357,
	[2933] = 204358,
	[2934] = 204359,
	[2935] = 204360,
	[2936] = 204361,
	[2937] = 204362,
	[2938] = 204363,
	[2939] = 204364,
	[2940] = 204365,
	[2941] = 204366,
	[2942] = 204367,
	[2943] = 204368,
	[2944] = 204369,
	[2945] = 204370,
	[2946] = 204371,
	[2947] = 204372,
	[2948] = 204373,
	[2949] = 204374,
	[2950] = 204375,
	[2951] = 204376,
	[2952] = 204377,
	[2953] = 204378,
	[2954] = 204379,
	[2955] = 204380,
	[2956] = 204381,
	[2957] = 204382,
	[2958] = 204383,
	[2959] = 204384,
	[2960] = 204385,
	[3025] = 204390,
	[3026] = 204391,
	[3027] = 204392,
	[3028] = 204393,
	[3029] = 204394,
	[3030] = 204395,
	[3031] = 204396,
	[3032] = 204397,
	[3033] = 204398,
	[3034] = 204399,
	[3035] = 204400,
	[3036] = 204401,
	[3037] = 204402,
	[3038] = 204403,
	[3039] = 204404,
	[3040] = 204405,
	[3041] = 204406,
	[3042] = 204407,
	[3043] = 204408,
	[3044] = 204409,
	[3045] = 204410,
	[3046] = 204411,
	[3047] = 204412,
	[3048] = 204413,
	[3049] = 204414,
	[3050] = 204415,
	[3051] = 204416,
	[3052] = 204417,
	[3053] = 204418,
	[3054] = 204419,
	[3055] = 204420,
	[3056] = 204421,
	[3057] = 204422,
	[3058] = 204423,
	[3059] = 204424,
	[3060] = 204425,
	[3125] = 204430,
	[3126] = 204431,
	[3127] = 204432,
	[3128] = 204433,
	[3129] = 204434,
	[3130] = 204435,
	[3131] = 204436,
	[3132] = 204437,
	[3133] = 204438,
	[3134] = 204439,
	[3135] = 204440,
	[3136] = 204441,
	[3137] = 204442,
	[3138] = 204443,
	[3139] = 204444,
	[3140] = 204445,
	[3141] = 204446,
	[3142] = 204447,
	[3143] = 204448,
	[3144] = 204449,
	[3145] = 204450,
	[3146] = 204451,
	[3147] = 204452,
	[3148] = 204453,
	[3149] = 204454,
	[3150] = 204455,
	[3151] = 204456,
	[3152] = 204457,
	[3153] = 204458,
	[3154] = 204459,
	[3155] = 204460,
	[3156] = 204461,
	[3157] = 204462,
	[3158] = 204463,
	[3159] = 204464,
	[3160] = 204465,
	[3225] = 204470,
	[3226] = 204471,
	[3227] = 204472,
	[3228] = 204473,
	[3229] = 204474,
	[3230] = 204475,
	[3231] = 204476,
	[3232] = 204477,
	[3233] = 204478,
	[3234] = 204479,
	[3235] = 204480,
	[3236] = 204481,
	[3237] = 204482,
	[3238] = 204483,
	[3239] = 204484,
	[3240] = 204485,
	[3241] = 204486,
	[3242] = 204487,
	[3243] = 204488,
	[3244] = 204489,
	[3245] = 204490,
	[3246] = 204491,
	[3247] = 204492,
	[3248] = 204493,
	[3249] = 204494,
	[3250] = 204495,
	[3251] = 204496,
	[3252] = 204497,
	[3253] = 204498,
	[3254] = 204499,
	[3255] = 204500,
	[3256] = 204501,
	[3257] = 204502,
	[3258] = 204503,
	[3259] = 204504,
	[3260] = 204505,
	[3325] = 204510,
	[3326] = 204511,
	[3327] = 204512,
	[3328] = 204513,
	[3329] = 204514,
	[3330] = 204515,
	[3331] = 204516,
	[3332] = 204517,
	[3333] = 204518,
	[3334] = 204519,
	[3335] = 204520,
	[3336] = 204521,
	[3337] = 204522,
	[3338] = 204523,
	[3339] = 204524,
	[3340] = 204525,
	[3341] = 204526,
	[3342] = 204527,
	[3343] = 204528,
	[3344] = 204529,
	[3345] = 204530,
	[3346] = 204531,
	[3347] = 204532,
	[3348] = 204533,
	[3349] = 204534,
	[3350] = 204535,
	[3351] = 204536,
	[3352] = 204537,
	[3353] = 204538,
	[3354] = 204539,
	[3355] = 204540,
	[3356] = 204541,
	[3357] = 204542,
	[3358] = 204543,
	[3359] = 204544,
	[3360] = 204545,
	[3425] = 204550,
	[3426] = 204551,
	[3427] = 204552,
	[3428] = 204553,
	[3429] = 204554,
	[3430] = 204555,
	[3431] = 204556,
	[3432] = 204557,
	[3433] = 204558,
	[3434] = 204559,
	[3435] = 204560,
	[3436] = 204561,
	[3437] = 204562,
	[3438] = 204563,
	[3439] = 204564,
	[3440] = 204565,
	[3441] = 204566,
	[3442] = 204567,
	[3443] = 204568,
	[3444] = 204569,
	[3445] = 204570,
	[3446] = 204571,
	[3447] = 204572,
	[3448] = 204573,
	[3449] = 204574,
	[3450] = 204575,
	[3451] = 204576,
	[3452] = 204577,
	[3453] = 204578,
	[3454] = 204579,
	[3455] = 204580,
	[3456] = 204581,
	[3457] = 204582,
	[3458] = 204583,
	[3459] = 204584,
	[3460] = 204585,
	[3524] = 204591,
	[3525] = 204592,
	[3526] = 204593,
	[3527] = 204594,
	[3528] = 204595,
	[3529] = 204596,
	[3530] = 204597,
	[3531] = 204598,
	[3532] = 204599,
	[3533] = 204600,
	[3534] = 204601,
	[3535] = 204602,
	[3536] = 204603,
	[3537] = 204604,
	[3538] = 204605,
	[3539] = 204606,
	[3540] = 204607,
	[3541] = 204608,
	[3542] = 204609,
	[3543] = 204610,
	[3544] = 204611,
	[3545] = 204612,
	[3546] = 204613,
	[3547] = 204614,
	[3548] = 204615,
	[3549] = 204616,
	[3550] = 204617,
	[3551] = 204618,
	[3552] = 204619,
	[3553] = 204620,
	[3554] = 204621,
	[3555] = 204622,
	[3556] = 204623,
	[3557] = 204624,
	[3558] = 204625,
	[3623] = 204630,
	[3624] = 204631,
	[3625] = 204632,
	[3626] = 204633,
	[3627] = 204634,
	[3628] = 204635,
	[3629] = 204636,
	[3630] = 204637,
	[3631] = 204638,
	[3632] = 204639,
	[3633] = 204640,
	[3634] = 204641,
	[3635] = 204642,
	[3636] = 204643,
	[3637] = 204644,
	[3638] = 204645,
	[3639] = 204646,
	[3640] = 204647,
	[3641] = 204648,
	[3642] = 204649,
	[3643] = 204650,
	[3644] = 204651,
	[3645] = 204652,
	[3646] = 204653,
	[3647] = 204654,
	[3648] = 204655,
	[3649] = 204656,
	[3650] = 204657,
	[3651] = 204658,
	[3652] = 204659,
	[3653] = 204660,
	[3654] = 204661,
	[3655] = 204662,
	[3656] = 204663,
	[3723] = 204670,
	[3724] = 204671,
	[3725] = 204672,
	[3726] = 204673,
	[3727] = 204674,
	[3728] = 204675,
	[3729] = 204676,
	[3730] = 204677,
	[3731] = 204678,
	[3732] = 204679,
	[3733] = 204680,
	[3734] = 204681,
	[3735] = 204682,
	[3736] = 204683,
	[3737] = 204684,
	[3738] = 204685,
	[3739] = 204686,
	[3740] = 204687,
	[3741] = 204688,
	[3742] = 204689,
	[3743] = 204690,
	[3744] = 204691,
	[3745] = 204692,
	[3746] = 204693,
	[3747] = 204694,
	[3748] = 204695,
	[3749] = 204696,
	[3750] = 204697,
	[3751] = 204698,
	[3752] = 204699,
	[3753] = 204700,
	[3754] = 204701,
	[3755] = 204702,
	[3756] = 204703,
	[3823] = 204710,
	[3824] = 204711,
	[3825] = 204712,
	[3826] = 204713,
	[3827] = 204714,
	[3828] = 204715,
	[3829] = 204716,
	[3830] = 204717,
	[3831] = 204718,
	[3832] = 204719,
	[3833] = 204720,
	[3834] = 204721,
	[3835] = 204722,
	[3836] = 204723,
	[3837] = 204724,
	[3838] = 204725,
	[3839] = 204726,
	[3840] = 204727,
	[3841] = 204728,
	[3842] = 204729,
	[3843] = 204730,
	[3844] = 204731,
	[3845] = 204732,
	[3846] = 204733,
	[3847] = 204734,
	[3848] = 204735,
	[3849] = 204736,
	[3850] = 204737,
	[3851] = 204738,
	[3852] = 204739,
	[3853] = 204740,
	[3854] = 204741,
	[3855] = 204742,
	[3923] = 204750,
	[3924] = 204751,
	[3925] = 204752,
	[3926] = 204753,
	[3927] = 204754,
	[3928] = 204755,
	[3929] = 204756,
	[3930] = 204757,
	[3931] = 204758,
	[3932] = 204759,
	[3933] = 204760,
	[3934] = 204761,
	[3935] = 204762,
	[3936] = 204763,
	[3937] = 204764,
	[3938] = 204765,
	[3939] = 204766,
	[3940] = 204767,
	[3941] = 204768,
	[3942] = 204769,
	[3943] = 204770,
	[3944] = 204771,
	[3945] = 204772,
	[3946] = 204773,
	[3947] = 204774,
	[3948] = 204775,
	[3949] = 204776,
	[3950] = 204777,
	[3951] = 204778,
	[3952] = 204779,
	[3953] = 204780,
	[3954] = 204781,
	[3955] = 204782,
	[4023] = 204790,
	[4024] = 204791,
	[4025] = 204792,
	[4026] = 204793,
	[4027] = 204794,
	[4028] = 204795,
	[4029] = 204796,
	[4030] = 204797,
	[4031] = 204798,
	[4032] = 204799,
	[4033] = 204800,
	[4034] = 204801,
	[4035] = 204802,
	[4036] = 204803,
	[4037] = 204804,
	[4038] = 204805,
	[4039] = 204806,
	[4040] = 204807,
	[4041] = 204808,
	[4042] = 204809,
	[4043] = 204810,
	[4044] = 204811,
	[4045] = 204812,
	[4046] = 204813,
	[4047] = 204814,
	[4048] = 204815,
	[4049] = 204816,
	[4050] = 204817,
	[4051] = 204818,
	[4052] = 204819,
	[4053] = 204820,
	[4123] = 204828,
	[4124] = 204829,
	[4125] = 204830,
	[4126] = 204831,
	[4127] = 204832,
	[4128] = 204833,
	[4129] = 204834,
	[4130] = 204835,
	[4131] = 204836,
	[4132] = 204837,
	[4133] = 204838,
	[4136] = 204841,
	[4137] = 204842,
	[4138] = 204843,
	[4139] = 204844,
	[4140] = 204845,
	[4141] = 204846,
	[4142] = 204847,
	[4143] = 204848,
	[4144] = 204849,
	[4145] = 204850,
	[4146] = 204851,
	[4147] = 204852,
	[4148] = 204853,
	[4149] = 204854,
	[4150] = 204855,
	[4151] = 204856,
	[4152] = 204857,
	[4224] = 204861,
	[4225] = 204862,
	[4226] = 204863,
	[4227] = 204864,
	[4228] = 204865,
	[4229] = 204866,
	[4230] = 204867,
	[4236] = 204873,
	[4237] = 204874,
	[4238] = 204875,
	[4239] = 204876,
	[4240] = 204877,
	[4241] = 204878,
	[4242] = 204879,
	[4325] = 204893,
	[4326] = 204894,
	[4327] = 204895,
	[4328] = 204896,
	[4329] = 204897,
	[4336] = 341448,
	[4337] = 341449,
	[4338] = 341450,
	[4339] = 341451,
	[4340] = 341442,
	[4341] = 341444,
	[4425] = 204903,
	[4426] = 204904,
	[4436] = 341452,
	[4437] = 341453,
	[4438] = 341454,
	[4439] = 341455,
	[4440] = 341443,
	[4441] = 341445,
}

Map.OLMapBlks = {
	[1334] = 206599,
	[1335] = 206600,
	[1429] = 206610,
	[1430] = 206611,
	[1431] = 206612,
	[1432] = 206613,
	[1433] = 206614,
	[1434] = 206615,
	[1435] = 206616,
	[1436] = 206617,
	[1437] = 206618,
	[1528] = 206630,
	[1529] = 206631,
	[1530] = 206632,
	[1531] = 206633,
	[1532] = 206634,
	[1533] = 206635,
	[1534] = 206636,
	[1535] = 206637,
	[1536] = 206638,
	[1537] = 206639,
	[1538] = 206640,
	[1628] = 206651,
	[1629] = 206652,
	[1630] = 206653,
	[1631] = 206654,
	[1632] = 206655,
	[1633] = 206656,
	[1634] = 206657,
	[1635] = 206658,
	[1636] = 206659,
	[1637] = 206660,
	[1638] = 206661,
	[1725] = 206669,
	[1726] = 206670,
	[1727] = 206671,
	[1728] = 206672,
	[1729] = 206673,
	[1730] = 206674,
	[1731] = 206675,
	[1732] = 206676,
	[1733] = 206677,
	[1734] = 206678,
	[1735] = 206679,
	[1736] = 206680,
	[1737] = 206681,
	[1738] = 206682,
	[1824] = 206690,
	[1825] = 206691,
	[1826] = 206692,
	[1827] = 206693,
	[1828] = 206694,
	[1829] = 206695,
	[1830] = 206696,
	[1831] = 206697,
	[1832] = 206698,
	[1833] = 206699,
	[1834] = 206700,
	[1835] = 206701,
	[1836] = 206702,
	[1837] = 206703,
	[1838] = 206704,
	[1924] = 206712,
	[1925] = 206713,
	[1926] = 206714,
	[1927] = 206715,
	[1928] = 206716,
	[1929] = 206717,
	[1930] = 206718,
	[1931] = 206719,
	[1932] = 206720,
	[1933] = 206721,
	[1934] = 206722,
	[1935] = 206723,
	[1936] = 206724,
	[1937] = 206725,
	[1938] = 206726,
	[1939] = 206727,
	[1940] = 206728,
	[2024] = 206734,
	[2025] = 206735,
	[2026] = 206736,
	[2027] = 206737,
	[2028] = 206738,
	[2029] = 206739,
	[2030] = 206740,
	[2031] = 206741,
	[2032] = 206742,
	[2033] = 206743,
	[2034] = 206744,
	[2035] = 206745,
	[2036] = 206746,
	[2037] = 206747,
	[2038] = 206748,
	[2039] = 206749,
	[2040] = 206750,
	[2123] = 206755,
	[2124] = 206756,
	[2125] = 206757,
	[2126] = 206758,
	[2127] = 206759,
	[2128] = 206760,
	[2129] = 206761,
	[2130] = 206762,
	[2131] = 206763,
	[2132] = 206764,
	[2133] = 206765,
	[2134] = 206766,
	[2135] = 206767,
	[2136] = 206768,
	[2137] = 206769,
	[2138] = 206770,
	[2139] = 206771,
	[2140] = 206772,
	[2223] = 206777,
	[2224] = 206778,
	[2225] = 206779,
	[2226] = 206780,
	[2227] = 206781,
	[2228] = 206782,
	[2229] = 206783,
	[2230] = 206784,
	[2231] = 206785,
	[2232] = 206786,
	[2233] = 206787,
	[2234] = 206788,
	[2235] = 206789,
	[2236] = 206790,
	[2237] = 206791,
	[2238] = 206792,
	[2239] = 206793,
	[2240] = 206794,
	[2323] = 206799,
	[2324] = 206800,
	[2325] = 206801,
	[2326] = 206802,
	[2327] = 206803,
	[2328] = 206804,
	[2329] = 206805,
	[2330] = 206806,
	[2331] = 206807,
	[2332] = 206808,
	[2333] = 206809,
	[2334] = 206810,
	[2335] = 206811,
	[2336] = 206812,
	[2337] = 206813,
	[2338] = 206814,
	[2339] = 206815,
	[2340] = 206816,
	[2422] = 206820,
	[2423] = 206821,
	[2424] = 206822,
	[2425] = 206823,
	[2426] = 206824,
	[2427] = 206825,
	[2430] = 206828,
	[2431] = 206829,
	[2432] = 206830,
	[2433] = 206831,
	[2434] = 206832,
	[2435] = 206833,
	[2436] = 206834,
	[2437] = 206835,
	[2438] = 206836,
	[2439] = 206837,
	[2440] = 206838,
	[2522] = 206842,
	[2523] = 206843,
	[2524] = 206844,
	[2525] = 206845,
	[2526] = 206846,
	[2527] = 206847,
	[2528] = 206848,
	[2530] = 206850,
	[2531] = 206851,
	[2532] = 206852,
	[2533] = 206853,
	[2534] = 206854,
	[2535] = 206855,
	[2536] = 206856,
	[2537] = 206857,
	[2538] = 206858,
	[2539] = 206859,
	[2540] = 206860,
	[2622] = 206864,
	[2623] = 206865,
	[2624] = 206866,
	[2625] = 206867,
	[2626] = 206868,
	[2627] = 206869,
	[2628] = 206870,
	[2629] = 206871,
	[2630] = 206872,
	[2631] = 206873,
	[2632] = 206874,
	[2633] = 206875,
	[2634] = 206876,
	[2635] = 206877,
	[2636] = 206878,
	[2637] = 206879,
	[2638] = 206880,
	[2639] = 206881,
	[2640] = 206882,
	[2722] = 206886,
	[2723] = 206887,
	[2724] = 206888,
	[2725] = 206889,
	[2726] = 206890,
	[2727] = 206891,
	[2728] = 206892,
	[2729] = 206893,
	[2730] = 206894,
	[2731] = 206895,
	[2732] = 206896,
	[2733] = 206897,
	[2734] = 206898,
	[2735] = 206899,
	[2736] = 206900,
	[2737] = 206901,
	[2738] = 206902,
	[2739] = 206903,
	[2740] = 206904,
	[2823] = 206909,
	[2824] = 206910,
	[2825] = 206911,
	[2826] = 206912,
	[2827] = 206913,
	[2828] = 206914,
	[2829] = 206915,
	[2830] = 206916,
	[2831] = 206917,
	[2832] = 206918,
	[2833] = 206919,
	[2834] = 206920,
	[2836] = 206922,
	[2837] = 206923,
	[2838] = 206924,
	[2839] = 206925,
	[2840] = 206926,
	[2841] = 206927,
	[2923] = 206931,
	[2924] = 206932,
	[2925] = 206933,
	[2926] = 206934,
	[2930] = 206938,
	[2931] = 206939,
	[2932] = 206940,
	[2933] = 206941,
	[2934] = 206942,
	[2936] = 206944,
	[2937] = 206945,
	[2938] = 206946,
	[2939] = 206947,
	[2940] = 206948,
	[2941] = 206949,
	[3026] = 206956,
	[3031] = 206961,
	[3032] = 206962,
	[3033] = 206963,
	[3034] = 206964,
	[3036] = 206966,
	[3037] = 206967,
	[3038] = 206968,
	[3039] = 206969,
	[3040] = 206970,
	[3041] = 206971,
	[3042] = 206972,
	[3132] = 206984,
	[3136] = 206988,
	[3137] = 206989,
	[3138] = 206990,
	[3139] = 206991,
	[3140] = 206992,
	[3141] = 206993,
	[3142] = 206994,
	[3237] = 207002,
	[3238] = 207003,
	[3239] = 207004,
	[3240] = 207005,
	[3241] = 207006,
	[3242] = 207007,
	[3337] = 207015,
	[3338] = 207016,
	[3339] = 207017,
}

Map.NRMapBlks = {
	[1609] = 245287,
	[1610] = 245288,
	[1611] = 245289,
	[1612] = 208688,
	[1613] = 208689,
	[1614] = 208690,
	[1615] = 208691,
	[1616] = 208692,
	[1617] = 208693,
	[1618] = 208694,
	[1619] = 208695,
	[1620] = 208696,
	[1621] = 208697,
	[1622] = 208698,
	[1623] = 208699,
	[1624] = 208700,
	[1625] = 208701,
	[1626] = 208702,
	[1627] = 208703,
	[1628] = 208704,
	[1629] = 208705,
	[1630] = 208706,
	[1631] = 208707,
	[1632] = 208708,
	[1633] = 208709,
	[1709] = 245293,
	[1710] = 245294,
	[1711] = 245295,
	[1712] = 208711,
	[1713] = 208712,
	[1714] = 208713,
	[1715] = 208714,
	[1716] = 208715,
	[1717] = 208716,
	[1718] = 208717,
	[1719] = 208718,
	[1720] = 208719,
	[1721] = 208720,
	[1722] = 208721,
	[1723] = 208722,
	[1724] = 208723,
	[1725] = 208724,
	[1726] = 208725,
	[1727] = 208726,
	[1728] = 208727,
	[1729] = 208728,
	[1730] = 208729,
	[1731] = 208730,
	[1732] = 208731,
	[1733] = 208732,
	[1809] = 245299,
	[1810] = 245300,
	[1811] = 245301,
	[1812] = 208734,
	[1813] = 208735,
	[1814] = 208736,
	[1815] = 208737,
	[1816] = 208738,
	[1817] = 208739,
	[1818] = 208740,
	[1819] = 208741,
	[1820] = 208742,
	[1821] = 208743,
	[1822] = 208744,
	[1823] = 208745,
	[1824] = 208746,
	[1825] = 208747,
	[1826] = 208748,
	[1827] = 208749,
	[1828] = 208750,
	[1829] = 208751,
	[1830] = 208752,
	[1831] = 208753,
	[1832] = 208754,
	[1833] = 208755,
	[1909] = 245305,
	[1910] = 245306,
	[1911] = 245307,
	[1912] = 208757,
	[1913] = 208758,
	[1914] = 208759,
	[1915] = 208760,
	[1916] = 208761,
	[1917] = 208762,
	[1918] = 208763,
	[1919] = 208764,
	[1920] = 208765,
	[1921] = 208766,
	[1922] = 208767,
	[1923] = 208768,
	[1924] = 208769,
	[1925] = 208770,
	[1926] = 208771,
	[1927] = 208772,
	[1928] = 208773,
	[1929] = 208774,
	[1930] = 208775,
	[1931] = 208776,
	[1932] = 208777,
	[1933] = 208778,
	[2009] = 245311,
	[2010] = 245312,
	[2011] = 245313,
	[2012] = 208780,
	[2013] = 208781,
	[2014] = 208782,
	[2015] = 208783,
	[2016] = 208784,
	[2017] = 208785,
	[2018] = 208786,
	[2019] = 208787,
	[2020] = 208788,
	[2021] = 208789,
	[2022] = 208790,
	[2023] = 208791,
	[2024] = 208792,
	[2025] = 208793,
	[2026] = 208794,
	[2027] = 208795,
	[2028] = 208796,
	[2029] = 208797,
	[2030] = 208798,
	[2031] = 208799,
	[2032] = 208800,
	[2033] = 208801,
	[2109] = 245317,
	[2110] = 245318,
	[2111] = 245319,
	[2112] = 208803,
	[2113] = 208804,
	[2114] = 208805,
	[2115] = 208806,
	[2116] = 208807,
	[2117] = 208808,
	[2118] = 208809,
	[2119] = 208810,
	[2120] = 208811,
	[2121] = 208812,
	[2122] = 208813,
	[2123] = 208814,
	[2124] = 208815,
	[2125] = 208816,
	[2126] = 208817,
	[2127] = 208818,
	[2128] = 208819,
	[2129] = 208820,
	[2130] = 208821,
	[2131] = 208822,
	[2132] = 208823,
	[2133] = 208824,
	[2209] = 245323,
	[2210] = 245324,
	[2211] = 245325,
	[2212] = 208826,
	[2213] = 208827,
	[2214] = 208828,
	[2215] = 208829,
	[2216] = 208830,
	[2217] = 208831,
	[2218] = 208832,
	[2219] = 208833,
	[2220] = 208834,
	[2221] = 208835,
	[2222] = 208836,
	[2223] = 208837,
	[2224] = 208838,
	[2225] = 208839,
	[2226] = 208840,
	[2227] = 208841,
	[2228] = 208842,
	[2229] = 208843,
	[2230] = 208844,
	[2231] = 208845,
	[2232] = 208846,
	[2233] = 208847,
	[2309] = 245329,
	[2310] = 245330,
	[2311] = 245331,
	[2312] = 208849,
	[2313] = 208850,
	[2314] = 208851,
	[2315] = 208852,
	[2316] = 208853,
	[2317] = 208854,
	[2318] = 208855,
	[2319] = 208856,
	[2320] = 208857,
	[2321] = 208858,
	[2322] = 208859,
	[2323] = 208860,
	[2324] = 208861,
	[2325] = 208862,
	[2326] = 208863,
	[2327] = 208864,
	[2328] = 208865,
	[2329] = 208866,
	[2330] = 208867,
	[2331] = 208868,
	[2332] = 208869,
	[2333] = 208870,
	[2409] = 245335,
	[2410] = 245336,
	[2411] = 245337,
	[2412] = 208872,
	[2413] = 208873,
	[2414] = 208874,
	[2415] = 208875,
	[2416] = 208876,
	[2417] = 208877,
	[2418] = 208878,
	[2419] = 208879,
	[2420] = 208880,
	[2421] = 208881,
	[2422] = 208882,
	[2423] = 208883,
	[2424] = 208884,
	[2425] = 208885,
	[2426] = 208886,
	[2427] = 208887,
	[2428] = 208888,
	[2429] = 208889,
	[2430] = 208890,
	[2431] = 208891,
	[2432] = 208892,
	[2433] = 208893,
	[2509] = 245341,
	[2510] = 245342,
	[2511] = 245343,
	[2512] = 208895,
	[2513] = 208896,
	[2514] = 208897,
	[2515] = 208898,
	[2516] = 208899,
	[2517] = 208900,
	[2518] = 208901,
	[2519] = 208902,
	[2520] = 208903,
	[2521] = 208904,
	[2522] = 208905,
	[2523] = 208906,
	[2524] = 208907,
	[2525] = 208908,
	[2526] = 208909,
	[2527] = 208910,
	[2528] = 208911,
	[2529] = 208912,
	[2530] = 208913,
	[2531] = 208914,
	[2532] = 208915,
	[2533] = 208916,
	[2609] = 245347,
	[2610] = 245348,
	[2611] = 245349,
	[2612] = 208918,
	[2613] = 208919,
	[2614] = 208920,
	[2615] = 208921,
	[2616] = 208922,
	[2617] = 208923,
	[2618] = 208924,
	[2619] = 208925,
	[2620] = 208926,
	[2621] = 208927,
	[2622] = 208928,
	[2623] = 208929,
	[2624] = 208930,
	[2625] = 208931,
	[2626] = 208932,
	[2627] = 208933,
	[2628] = 208934,
	[2629] = 208935,
	[2630] = 208936,
	[2631] = 208937,
	[2632] = 208938,
	[2633] = 208939,
	[2709] = 245353,
	[2710] = 245354,
	[2711] = 245355,
	[2712] = 208941,
	[2713] = 208942,
	[2714] = 208943,
	[2715] = 208944,
	[2716] = 208945,
	[2717] = 208946,
	[2718] = 208947,
	[2719] = 208948,
	[2720] = 208949,
	[2721] = 208950,
	[2722] = 208951,
	[2723] = 208952,
	[2724] = 208953,
	[2725] = 208954,
	[2726] = 208955,
	[2727] = 208956,
	[2728] = 208957,
	[2729] = 208958,
	[2730] = 208959,
	[2731] = 208960,
	[2732] = 208961,
	[2733] = 208962,
	[2809] = 245359,
	[2810] = 245360,
	[2811] = 245361,
	[2812] = 208964,
	[2813] = 208965,
	[2814] = 208966,
	[2815] = 208967,
	[2816] = 208968,
	[2817] = 208969,
	[2818] = 208970,
	[2819] = 208971,
	[2820] = 208972,
	[2821] = 208973,
	[2822] = 208974,
	[2823] = 208975,
	[2824] = 208976,
	[2825] = 208977,
	[2826] = 208978,
	[2827] = 208979,
	[2828] = 208980,
	[2829] = 208981,
	[2830] = 208982,
	[2831] = 208983,
	[2832] = 208984,
	[2833] = 208985,
	[2909] = 245365,
	[2910] = 245366,
	[2911] = 245367,
	[2912] = 208987,
	[2913] = 208988,
	[2914] = 208989,
	[2915] = 208990,
	[2916] = 208991,
	[2917] = 208992,
	[2918] = 208993,
	[2919] = 208994,
	[2920] = 208995,
	[2921] = 208996,
	[2922] = 208997,
	[2923] = 208998,
	[2924] = 208999,
	[2925] = 209000,
	[2926] = 209001,
	[2927] = 209002,
	[2928] = 209003,
	[2929] = 209004,
	[2930] = 209005,
	[2931] = 209006,
	[2932] = 209007,
	[2933] = 209008,
	[3009] = 245371,
	[3010] = 245372,
	[3011] = 245373,
	[3012] = 209010,
	[3013] = 209011,
	[3014] = 209012,
	[3015] = 209013,
	[3016] = 209014,
	[3017] = 209015,
	[3018] = 209016,
	[3019] = 209017,
	[3020] = 209018,
	[3021] = 209019,
	[3022] = 209020,
	[3023] = 209021,
	[3024] = 209022,
	[3025] = 209023,
	[3026] = 209024,
	[3027] = 209025,
	[3028] = 209026,
	[3029] = 209027,
	[3030] = 209028,
	[3031] = 209029,
	[3032] = 209030,
	[3033] = 209031,
	[3109] = 245377,
	[3110] = 245378,
	[3111] = 245379,
	[3112] = 209033,
	[3113] = 209034,
	[3114] = 209035,
	[3115] = 209036,
	[3116] = 209037,
	[3117] = 209038,
	[3118] = 209039,
	[3119] = 209040,
	[3120] = 209041,
	[3121] = 209042,
	[3122] = 209043,
	[3123] = 209044,
	[3124] = 209045,
	[3125] = 209046,
	[3126] = 209047,
	[3127] = 209048,
	[3128] = 209049,
	[3129] = 209050,
	[3130] = 209051,
	[3131] = 209052,
	[3132] = 209053,
	[3133] = 209054,
	[3209] = 245383,
	[3210] = 245384,
	[3211] = 245385,
	[3212] = 209056,
	[3213] = 209057,
	[3214] = 209058,
	[3215] = 209059,
	[3216] = 209060,
	[3217] = 209061,
	[3218] = 209062,
	[3219] = 209063,
	[3220] = 209064,
	[3221] = 209065,
	[3222] = 209066,
	[3223] = 209067,
	[3224] = 209068,
	[3225] = 209069,
	[3226] = 209070,
	[3227] = 209071,
	[3228] = 209072,
	[3229] = 209073,
	[3230] = 209074,
	[3231] = 209075,
	[3232] = 209076,
	[3233] = 209077,
	[3309] = 245389,
	[3310] = 245390,
	[3311] = 245391,
	[3312] = 209079,
	[3313] = 209080,
	[3314] = 209081,
	[3315] = 209082,
	[3316] = 209083,
	[3317] = 209084,
	[3318] = 209085,
	[3319] = 209086,
	[3320] = 209087,
	[3321] = 209088,
	[3322] = 209089,
	[3323] = 209090,
	[3324] = 209091,
	[3325] = 209092,
	[3326] = 209093,
	[3327] = 209094,
	[3328] = 209095,
	[3329] = 209096,
	[3330] = 209097,
	[3331] = 209098,
	[3332] = 209099,
	[3333] = 209100,
	[3409] = 245395,
	[3410] = 245396,
	[3411] = 245397,
	[3412] = 209102,
	[3413] = 209103,
	[3414] = 209104,
	[3415] = 209105,
	[3416] = 209106,
	[3417] = 209107,
	[3418] = 209108,
	[3419] = 209109,
	[3420] = 209110,
	[3421] = 209111,
	[3422] = 209112,
	[3423] = 209113,
	[3424] = 209114,
	[3425] = 209115,
	[3426] = 209116,
	[3427] = 209117,
	[3428] = 209118,
	[3429] = 209119,
	[3430] = 209120,
	[3431] = 209121,
	[3432] = 209122,
	[3433] = 209123,
	[3509] = 245401,
	[3510] = 245402,
	[3511] = 245403,
	[3512] = 209125,
	[3513] = 209126,
	[3514] = 209127,
	[3515] = 209128,
	[3516] = 209129,
	[3517] = 209130,
	[3518] = 209131,
	[3519] = 209132,
	[3520] = 209133,
	[3521] = 209134,
	[3522] = 209135,
	[3523] = 209136,
	[3524] = 209137,
	[3525] = 209138,
	[3526] = 209139,
	[3527] = 209140,
	[3528] = 209141,
	[3529] = 209142,
	[3530] = 209143,
	[3531] = 209144,
	[3532] = 209145,
	[3533] = 209146,
	[3609] = 245407,
	[3610] = 245408,
	[3611] = 245409,
	[3612] = 209148,
	[3613] = 209149,
	[3614] = 209150,
	[3615] = 209151,
	[3616] = 209152,
	[3617] = 209153,
	[3618] = 209154,
	[3619] = 209155,
	[3620] = 209156,
	[3621] = 209157,
	[3622] = 209158,
	[3623] = 209159,
	[3624] = 209160,
	[3625] = 209161,
	[3626] = 209162,
	[3627] = 209163,
	[3628] = 209164,
	[3629] = 209165,
	[3630] = 209166,
	[3631] = 209167,
	[3632] = 209168,
	[3633] = 209169,
	[3709] = 245413,
	[3710] = 245414,
	[3711] = 245415,
	[3712] = 209171,
	[3713] = 209172,
	[3714] = 209173,
	[3715] = 209174,
	[3716] = 209175,
	[3717] = 209176,
	[3718] = 209177,
	[3719] = 209178,
	[3720] = 209179,
	[3721] = 209180,
	[3722] = 209181,
	[3723] = 209182,
	[3724] = 209183,
	[3725] = 209184,
	[3726] = 209185,
	[3727] = 209186,
	[3728] = 209187,
	[3729] = 209188,
	[3730] = 209189,
	[3731] = 209190,
	[3732] = 209191,
	[3733] = 209192,
	[3809] = 245419,
	[3810] = 245420,
	[3811] = 245421,
	[3812] = 209194,
	[3813] = 209195,
	[3814] = 209196,
	[3815] = 209197,
	[3816] = 209198,
	[3817] = 209199,
	[3818] = 209200,
	[3819] = 209201,
	[3820] = 209202,
	[3821] = 209203,
	[3822] = 209204,
	[3823] = 209205,
	[3824] = 209206,
	[3825] = 209207,
	[3826] = 209208,
	[3827] = 209209,
	[3828] = 209210,
	[3829] = 209211,
	[3830] = 209212,
	[3831] = 209213,
	[3832] = 209214,
	[3833] = 209215,
	[3909] = 245425,
	[3910] = 245426,
	[3911] = 245427,
	[3912] = 209217,
	[3913] = 209218,
	[3914] = 209219,
	[3915] = 209220,
	[3916] = 209221,
	[3917] = 209222,
	[3918] = 209223,
	[3919] = 209224,
	[3920] = 209225,
	[3921] = 209226,
	[3922] = 209227,
	[3923] = 209228,
	[3924] = 209229,
	[3925] = 209230,
	[3926] = 209231,
	[3927] = 209232,
	[3928] = 209233,
	[3929] = 209234,
	[3930] = 209235,
	[3931] = 209236,
	[3932] = 209237,
	[3933] = 209238,
	[4009] = 245431,
	[4010] = 245432,
	[4011] = 245433,
	[4012] = 209240,
	[4013] = 209241,
	[4014] = 209242,
	[4015] = 209243,
	[4016] = 209244,
	[4017] = 209245,
	[4018] = 209246,
	[4019] = 209247,
	[4020] = 209248,
	[4021] = 209249,
	[4022] = 209250,
	[4023] = 209251,
	[4024] = 209252,
	[4025] = 209253,
	[4026] = 209254,
	[4027] = 209255,
	[4028] = 209256,
	[4029] = 209257,
	[4030] = 209258,
	[4031] = 209259,
	[4032] = 209260,
	[4033] = 209261,
	[4109] = 245437,
	[4110] = 245438,
	[4111] = 245439,
	[4112] = 209263,
	[4113] = 209264,
	[4114] = 209265,
	[4115] = 209266,
	[4116] = 209267,
	[4117] = 209268,
	[4118] = 209269,
	[4119] = 209270,
	[4120] = 209271,
	[4121] = 209272,
	[4122] = 209273,
	[4123] = 209274,
	[4124] = 209275,
	[4125] = 209276,
	[4126] = 209277,
	[4127] = 209278,
	[4128] = 209279,
	[4129] = 209280,
	[4130] = 209281,
	[4131] = 209282,
	[4132] = 209283,
	[4133] = 209284,
	[4209] = 245443,
	[4210] = 245444,
	[4211] = 245445,
	[4212] = 209286,
	[4213] = 209287,
	[4214] = 209288,
	[4215] = 209289,
	[4216] = 209290,
	[4217] = 209291,
	[4218] = 209292,
	[4219] = 209293,
	[4220] = 209294,
	[4221] = 209295,
	[4222] = 209296,
	[4223] = 209297,
	[4224] = 209298,
	[4225] = 209299,
	[4226] = 209300,
	[4227] = 209301,
	[4228] = 209302,
	[4229] = 209303,
	[4230] = 209304,
	[4231] = 209305,
	[4232] = 209306,
	[4233] = 209307,
	[4309] = 245449,
	[4310] = 245450,
	[4311] = 245451,
	[4312] = 209309,
	[4313] = 209310,
	[4314] = 209311,
	[4315] = 209312,
	[4316] = 209313,
	[4317] = 209314,
	[4318] = 209315,
	[4319] = 209316,
	[4320] = 209317,
	[4321] = 209318,
	[4322] = 209319,
	[4323] = 209320,
	[4324] = 209321,
	[4325] = 209322,
	[4326] = 209323,
	[4327] = 209324,
	[4328] = 209325,
	[4329] = 209326,
	[4330] = 209327,
	[4331] = 209328,
	[4332] = 209329,
	[4333] = 209330,
	[4409] = 245455,
	[4410] = 245456,
	[4411] = 245457,
	[4412] = 209332,
	[4413] = 209333,
	[4414] = 209334,
	[4415] = 209335,
	[4416] = 209336,
	[4417] = 209337,
	[4418] = 209338,
	[4419] = 209339,
	[4420] = 209340,
	[4421] = 209341,
	[4422] = 209342,
	[4423] = 209343,
	[4424] = 209344,
	[4425] = 209345,
	[4426] = 209346,
	[4427] = 209347,
	[4428] = 209348,
	[4429] = 209349,
	[4430] = 209350,
	[4431] = 209351,
	[4432] = 209352,
	[4433] = 209353,
	[4509] = 245461,
	[4510] = 245462,
	[4511] = 245463,
	[4512] = 209355,
	[4513] = 209356,
	[4514] = 209357,
	[4515] = 209358,
	[4516] = 209359,
	[4517] = 209360,
	[4518] = 209361,
	[4519] = 209362,
	[4520] = 209363,
	[4521] = 209364,
	[4522] = 209365,
	[4523] = 209366,
	[4524] = 209367,
	[4525] = 209368,
	[4526] = 209369,
	[4527] = 209370,
	[4528] = 209371,
	[4529] = 209372,
	[4530] = 209373,
	[4531] = 209374,
	[4532] = 209375,
	[4533] = 209376,
}

Map.LIMapBlks = {
	[2426] = 306396,
	[2427] = 306406,
	[2428] = 306416,
	[2429] = 306426,
	[2430] = 306436,
	[2431] = 306446,
	[2432] = 306456,
	[2526] = 306397,
	[2527] = 306407,
	[2528] = 306417,
	[2529] = 306427,
	[2530] = 306437,
	[2531] = 306447,
	[2532] = 306457,
	[2626] = 306398,
	[2627] = 306408,
	[2628] = 306418,
	[2629] = 306428,
	[2630] = 306438,
	[2631] = 306448,
	[2632] = 306458,
	[2726] = 306399,
	[2727] = 306409,
	[2728] = 306419,
	[2729] = 306429,
	[2730] = 306439,
	[2731] = 306449,
	[2732] = 306459,
	[2826] = 306400,
	[2827] = 306410,
	[2828] = 306420,
	[2829] = 306430,
	[2830] = 306440,
	[2831] = 306450,
	[2832] = 306460,
	[2926] = 306401,
	[2927] = 306411,
	[2928] = 306421,
	[2929] = 306431,
	[2930] = 306441,
	[2931] = 306451,
	[2932] = 306461,
	[3026] = 306402,
	[3027] = 306412,
	[3028] = 306422,
	[3029] = 306432,
	[3030] = 306442,
	[3031] = 306452,
	[3032] = 306462,
	[3126] = 306403,
	[3127] = 306413,
	[3128] = 306423,
	[3129] = 306433,
	[3130] = 306443,
	[3131] = 306453,
}

Map.BloodelfMapBlks = {
	[4116] = 207095,
	[4117] = 207096,
	[4118] = 207097,
	[4211] = 207107,
	[4212] = 207108,
	[4213] = 207109,
	[4214] = 207110,
	[4215] = 207111,
	[4216] = 207112,
	[4217] = 207113,
	[4218] = 207114,
	[4219] = 207115,
	[4220] = 207116,
	[4221] = 207117,
	[4306] = 207119,
	[4307] = 207120,
	[4308] = 207121,
	[4309] = 207122,
	[4310] = 207123,
	[4311] = 207124,
	[4312] = 207125,
	[4313] = 207126,
	[4314] = 207127,
	[4315] = 207128,
	[4316] = 207129,
	[4317] = 207130,
	[4318] = 207131,
	[4319] = 207132,
	[4320] = 207133,
	[4321] = 207134,
	[4406] = 207136,
	[4407] = 207137,
	[4408] = 207138,
	[4409] = 207139,
	[4410] = 207140,
	[4411] = 207141,
	[4412] = 207142,
	[4413] = 207143,
	[4414] = 207144,
	[4415] = 207145,
	[4416] = 207146,
	[4417] = 207147,
	[4418] = 207148,
	[4419] = 207149,
	[4420] = 207150,
	[4421] = 207151,
	[4506] = 207153,
	[4507] = 207154,
	[4508] = 207155,
	[4509] = 207156,
	[4510] = 207157,
	[4511] = 207158,
	[4512] = 207159,
	[4513] = 207160,
	[4514] = 207161,
	[4515] = 207162,
	[4516] = 207163,
	[4517] = 207164,
	[4518] = 207165,
	[4519] = 207166,
	[4520] = 207167,
	[4521] = 207168,
	[4606] = 207170,
	[4607] = 207171,
	[4608] = 207172,
	[4609] = 207173,
	[4610] = 207174,
	[4611] = 207175,
	[4612] = 207176,
	[4613] = 207177,
	[4614] = 207178,
	[4615] = 207179,
	[4616] = 207180,
	[4617] = 207181,
	[4618] = 207182,
	[4619] = 207183,
	[4620] = 207184,
	[4621] = 207185,
	[4713] = 207194,
	[4714] = 207195,
	[4715] = 207196,
	[4716] = 207197,
	[4717] = 207198,
	[4718] = 207199,
	[4719] = 207200,
	[4720] = 207201,
}

Map.DraeneiMapBlks = {
	[5034] = 207234,
	[5035] = 207235,
	[5133] = 207247,
	[5134] = 207248,
	[5135] = 207249,
	[5136] = 207250,
	[5137] = 207251,
	[5140] = 207254,
	[5141] = 207255,
	[5142] = 207256,
	[5233] = 207261,
	[5234] = 207262,
	[5235] = 207263,
	[5236] = 207264,
	[5237] = 207265,
	[5238] = 207266,
	[5239] = 207267,
	[5240] = 207268,
	[5241] = 207269,
	[5242] = 207270,
	[5333] = 207275,
	[5334] = 207276,
	[5335] = 207277,
	[5336] = 207278,
	[5337] = 207279,
	[5338] = 207280,
	[5339] = 207281,
	[5340] = 207282,
	[5341] = 207283,
	[5342] = 207284,
	[5433] = 207289,
	[5434] = 207290,
	[5435] = 207291,
	[5436] = 207292,
	[5437] = 207293,
	[5438] = 207294,
	[5439] = 207295,
	[5440] = 207296,
	[5441] = 207297,
	[5533] = 207303,
	[5534] = 207304,
	[5535] = 207305,
	[5536] = 207306,
	[5537] = 207307,
	[5538] = 207308,
	[5539] = 207309,
	[5540] = 207310,
	[5541] = 207311,
	[5633] = 207317,
	[5634] = 207318,
	[5635] = 207319,
	[5636] = 207320,
	[5637] = 207321,
	[5638] = 207322,
	[5639] = 207323,
	[5640] = 207324,
	[5641] = 207325,
	[5737] = 207335,
	[5738] = 207336,
	[5739] = 207337,
	[5740] = 207338,
	[5741] = 207339,
	[5837] = 207349,
	[5838] = 207350,
	[5839] = 207351,
	[5840] = 207352,
	[5841] = 207353,
	[5938] = 207359,
	[5939] = 207360,
	[5940] = 207361,
}

Map.TolBaradMapBlks = {
	[2731] = 400328,
	[2732] = 400334,
	[2733] = 400340,
	[2734] = 400346,
	[2735] = 400352,
	[2831] = 400329,
	[2832] = 400335,
	[2833] = 400341,
	[2834] = 400347,
	[2835] = 400353,
	[2931] = 400330,
	[2932] = 400336,
	[2933] = 400342,
	[2934] = 400348,
	[2935] = 400354,
	[3031] = 400331,
	[3032] = 400337,
	[3033] = 400343,
	[3034] = 400349,
	[3035] = 400355,
	[3131] = 400332,
	[3132] = 400338,
	[3133] = 400344,
	[3134] = 400350,
	[3135] = 400356,
}

Map.KezanMapBlks = {
	[2648] = 308609,
	[2649] = 308616,
	[2650] = 308623,
	[2651] = 308630,
	[2746] = 308596,
	[2747] = 308603,
	[2748] = 308610,
	[2749] = 308617,
	[2750] = 308624,
	[2751] = 308631,
	[2846] = 308597,
	[2847] = 308604,
	[2848] = 308611,
	[2849] = 308618,
	[2850] = 308625,
	[2851] = 308632,
	[2946] = 308598,
	[2947] = 308605,
	[2948] = 308612,
	[2949] = 308619,
	[2950] = 308626,
	[2951] = 308633,
	[3046] = 308599,
	[3047] = 308606,
	[3048] = 308613,
	[3049] = 308620,
	[3050] = 308627,
	[3051] = 308634,
	[3148] = 308614,
	[3149] = 308621,
	[3150] = 308628,
	[3151] = 308635,
}

Map.DeepholmMapBlks = {
	[2728] = 358428,
	[2729] = 358433,
	[2730] = 358438,
	[2731] = 358443,
	[2827] = 358424,
	[2828] = 358429,
	[2829] = 358434,
	[2830] = 358439,
	[2831] = 358444,
	[2832] = 358449,
	[2927] = 358425,
	[2928] = 358430,
	[2929] = 358435,
	[2930] = 358440,
	[2931] = 358445,
	[2932] = 358450,
	[3027] = 358426,
	[3028] = 358431,
	[3029] = 358436,
	[3030] = 358441,
	[3031] = 358446,
	[3032] = 358451,
	[3127] = 362428,
	[3128] = 358677,
	[3129] = 358679,
	[3130] = 358681,
	[3131] = 358683,
	[3132] = 358857,
	[3227] = 362429,
	[3228] = 358678,
	[3229] = 358680,
	[3230] = 358682,
	[3231] = 358684,
	[3232] = 358858,
	[3328] = 362433,
	[3329] = 361120,
	[3330] = 361121,
	[3331] = 361122,
}

Map.MoltenFrontMapBlks = {
	[3028] = 512517,
	[3029] = 512521,
	[3030] = 512525,
	[3031] = 514571,
	[3128] = 512518,
	[3129] = 512522,
	[3130] = 512526,
	[3131] = 514572,
	[3228] = 512519,
	[3229] = 512523,
	[3230] = 512527,
	[3231] = 514573,
	[3328] = 514558,
	[3329] = 514562,
	[3330] = 514566,
	[3331] = 514574,
}

Map.TheWanderingIsleMapBlks = {
	[2328] = 511569,
	[2329] = 511579,
	[2330] = 511589,
	[2331] = 511599,
	[2428] = 511570,
	[2429] = 511580,
	[2430] = 511590,
	[2431] = 511600,
	[2528] = 511571,
	[2529] = 511581,
	[2530] = 511591,
	[2531] = 511601,
	[2628] = 511572,
	[2629] = 511582,
	[2630] = 511592,
	[2631] = 511602,
	[2728] = 511573,
	[2729] = 511583,
	[2730] = 511593,
	[2731] = 511603,
}

Map.DarkMoonFaireBlks = {
	[1636] = 535785,
	[1637] = 535792,
	[1638] = 535794,
	[1639] = 535796,
	[1640] = 535798,
	[1641] = 535800,
	[1642] = 535802,
	[1736] = 535786,
	[1737] = 532859,
	[1738] = 532864,
	[1739] = 532869,
	[1740] = 532874,
	[1741] = 532879,
	[1742] = 535803,
	[1836] = 535787,
	[1837] = 532860,
	[1838] = 532865,
	[1839] = 532870,
	[1840] = 532875,
	[1841] = 532880,
	[1842] = 535804,
	[1936] = 535788,
	[1937] = 532861,
	[1938] = 532866,
	[1939] = 532871,
	[1940] = 532876,
	[1941] = 532881,
	[1942] = 535805,
	[2036] = 535789,
	[2037] = 532862,
	[2038] = 532867,
	[2039] = 532872,
	[2040] = 532877,
	[2041] = 532882,
	[2042] = 535806,
	[2136] = 535790,
	[2137] = 532863,
	[2138] = 532868,
	[2139] = 532873,
	[2140] = 532878,
	[2141] = 532883,
	[2142] = 535807,
	[2236] = 535791,
	[2237] = 535793,
	[2238] = 535795,
	[2239] = 535797,
	[2240] = 535799,
	[2241] = 535801,
	[2242] = 535808,
}

Map.MiniMapBlks = {
	[1] = {
		Map.KalMapBlks,
		1908,
		19, 8,
		 Map.MapWorldInfo[13].X + Map.MapInfo[1].X + 2025.753921875 + 222, Map.MapWorldInfo[13].Y + Map.MapInfo[1].Y + -0.476021875 - 324,
		"World\\Minimaps\\Kalimdor"
	},
	[2] = {
		Map.EkMapBlks,
		2420,
		24, 20,
		Map.MapWorldInfo[14].X + Map.MapInfo[2].X -1080, Map.MapWorldInfo[14].Y + Map.MapInfo[2].Y - 1308,
		"World\\Minimaps\\Azeroth"
	},
	[3] = {
		Map.OLMapBlks,
		1221,
		12, 21,
		Map.MapWorldInfo[1945].X + Map.MapInfo[3].X + 465.4, Map.MapWorldInfo[1945].Y + Map.MapInfo[3].Y + -9.7,
		"World\\Minimaps\\Expansion01"
	},
	[4] = {
		Map.NRMapBlks,
		1109,
		11, 09,
		Map.MapWorldInfo[113].X + Map.MapInfo[4].X + -397.1, Map.MapWorldInfo[113].Y + Map.MapInfo[4].Y + -334.1,
		"World\\Minimaps\\Northrend"
	},
	[5] = {
		Map.LIMapBlks,
		2324,
		23, 24,
		Map.MapWorldInfo[948].X + Map.MapInfo[5].X + -178.84, Map.MapWorldInfo[948].Y + Map.MapInfo[5].Y + 401.76665039063,
		"World\\Minimaps\\LostIsles"
	},
	[94] = {
		Map.BloodelfMapBlks,
		4111,
		41, 11,
		Map.MapWorldInfo[14].X + Map.MapInfo[2].X + 231.60, Map.MapWorldInfo[14].Y + Map.MapInfo[2].Y - 1751.40,
		"World\\Minimaps\\Expansion01"
	},	
	[97] = {
		Map.DraeneiMapBlks,
		5033,
		50, 33,
		Map.MapWorldInfo[13].X + Map.MapInfo[1].X + 1833.076104875 + 221.20 , Map.MapWorldInfo[13].Y + Map.MapInfo[1].Y + 656.598490125 - 325.10,
		"World\\Minimaps\\Expansion01"
	},
	[244] = {
		Map.TolBaradMapBlks,
		2731,
		27, 31,
		Map.MapWorldInfo[14].X + Map.MapInfo[2].X + 2500.940740625, Map.MapWorldInfo[14].Y + Map.MapInfo[2].Y + 2448.61535,
		"World\\Minimaps\\TolBarad"
	},
	[194] = {
		Map.KezanMapBlks,
		2324,
		23, 24,
		Map.MapWorldInfo[948].X + Map.MapInfo[5].X + 297.05, Map.MapWorldInfo[948].Y + Map.MapInfo[5].Y + -1411.53334960937,
		"World\\Minimaps\\LostIsles"
	},	
	[207] = {		-- 2625 to 3534
		Map.DeepholmMapBlks,
		2625,
		26, 25,
		Map.MapWorldInfo[948].X + Map.MapInfo[5].X + 1251.16, Map.MapWorldInfo[948].Y + Map.MapInfo[5].Y + 228.97665039063,
		"World\\Minimaps\\Deephome"
	},	
	[338] = {
		Map.MoltenFrontMapBlks,
		2725,		-- 2725 to 3531
		27, 25,
		Map.MapWorldInfo[338].X + Map.MapInfo[1].X + 3152.92266259766, Map.MapWorldInfo[338].Y + Map.MapInfo[1].Y + -2105.97034960937,
		"World\\Minimaps\\FirelandsDailies"
	},
	[407] = {
		Map.DarkMoonFaireBlks,
		1636,
		16, 36,
		Map.MapWorldInfo[407].X + Map.MapInfo[5].X + -253,Map.MapWorldInfo[407].Y + Map.MapInfo[5].Y + -238,
		"World\\Minimaps\\DarkmoonFaire"
	},	
}

--------
-- Get minimap info for map
-- (map id)
-- ret: table, x, y

function Nx.Map:GetMiniInfo (mapId)

	local winfo = self.MapWorldInfo[mapId]
	if not winfo then return end
	local id = winfo.MId

	if not id then
		id = winfo.Cont

		if not id then
			return
		end

		if id == 9 then		-- BGs?
			return
		end

		local info = self.MapInfo[id]
		if not info then
			return
		end
	end

	local t = self.MiniMapBlks[id]

	if not t then			-- "Isle of Quel'Danas"??
		if Nx.db.profile.Debug.DebugMap then
			Nx.prt("GetMiniInfo: missing %s %s", id, mapId)
		end
		return
	end

	return t, t[5], t[6]
end

--------
-- Get minimap block file name (256x256 texture)

function Nx.Map:GetMiniBlkName (miniT, x, y)

	local off = x * 100 + y

--	Nx.prtCtrl ("%s, %s, %s = %s", x, y, off, off + miniT[2])

	--V4

	local v = miniT[1][off + miniT[2]]

	if v then

		if #v > 0 then
			return format ("%s\\noLiquid_map%02d_%02d", miniT[7], x + miniT[3], y + miniT[4])
		end
		if (strfind(miniT[7],"HawaiiMainLand")) then
			local hasFac = false
			for factionIndex = 1, GetNumFactions() do
				local name, description, standingId, bottomValue, topValue, earnedValue, atWarWith,canToggleAtWar, isHeader, isCollapsed, hasRep, isWatched, isChild = GetFactionInfo(factionIndex)
				if (name == "Operation: Shieldwall") or (name == "Dominance Offensive") then
					hasFac = true
				end
			end
			if (hasFac) then
				if ((x + miniT[3] == 33) or (x + miniT[3] == 34)) and ((y + miniT[4] == 33) or (y + miniT[4] == 34)) then
					return format("World\\Minimaps\\AllianceBeachDailyArea\\map%02d_%02d", x + miniT[3], y + miniT[4])
				end
				if ((x + miniT[3] == 27) or (x + miniT[3] == 28)) and ((y + miniT[4] == 35) or (y + miniT[4] == 36) or (y + miniT[4] == 37) or (y + miniT[4] == 38)) then
					return format("World\\Minimaps\\HordeBeachDailyArea\\map%02d_%02d", x + miniT[3], y + miniT[4])
				end
			end
			if (x + miniT[3] >= 18) and (x + miniT[3] <= 25) and (y + miniT[4] >= 17) and (y + miniT[4] <= 24) then
				return format("World\\Minimaps\\MoguIslandDailyArea\\map%02d_%02d",x+miniT[3], y + miniT[4]-2)
			end
		  return format ("%s\\map%02d_%02d", miniT[7], x + miniT[3], y + miniT[4])
		else
			return format ("%s\\map%02d_%02d", miniT[7], x + miniT[3], y + miniT[4])
		end

	end
end

function Nx.Map:GetZoneInfo (mapid)
	local vec, vec2 = CreateVector2D(0,0), CreateVector2D(0.5,0.5)
	local winfo = Nx.Map:GetMap(1).MapWorldInfo
	if not winfo or (winfo[mapid] and winfo[mapid].Scale) then	
		return
	end
	local _,topLeft = C_Map.GetWorldPosFromMapPos(mapid,vec)
	local _,bottomRight = C_Map.GetWorldPosFromMapPos(mapid,vec2)
	if topLeft and bottomRight then
		local top, left = topLeft:GetXY()
        local bottom, right = bottomRight:GetXY()
		bottom = top + (bottom - top) * 2
		right = left + (right - left) * 2
		winfo[mapid] = {}
		winfo[mapid].X = ((left * -1) / 5)
		winfo[mapid].Y = ((top * -1) / 5)
		winfo[mapid].Scale = ((right * -1) + left) / 500
	end	
	local mapinfo = C_Map.GetMapInfo(mapid)
	if mapinfo and (mapinfo.mapType == 5 or mapinfo.mapType == 4) then				
		winfo[mapid].Instance = true
	end
end

Map.MapLevels={
	[811] = { [3] = 6010, [4] = 6011, },
	[903] = { [1] = 6012, [2] = 6013, },
	[905] = { [3] = 6010, [4] = 6011, },
	[504] = { [2] = 4014, },
	[321] = { [2] = 1034, },
}

--[[ !!!!!!!!!!!!!!!! PLEASE DONT REMOVE THIS !!!!!!!!!!!!!!!!
function Nx.Map:ConvertMapData()

	local data = {}
	Nx.DumpZoneOverlays = data

	local areas = {}
	Nx.DumpMapAreas = areas

	local wma = { strsplit ("\n", self.WorldMapArea) }
	local wmo = { strsplit ("\n", self.WorldMapOverlay) }

	for n, s in ipairs (wma) do

		local aid, map, _, aname, ay1, ay2, ax1, ax2 = strsplit (",", s)
		aid = tonumber (aid)
		map = tonumber (map)

		aname = gsub (aname, '"', "")
		aname = strlower (aname)
		Nx.prt(aid)
		local nxid = aid
		if nxid and nxid > 0 then

--			local name, minLvl, maxLvl, faction, cont = strsplit ("|", Nx.Zones[nxid])

--			if faction ~= "3" then		-- Not instance

				ay1 = tonumber (ay1)
				ay2 = tonumber (ay2)
				ax1 = tonumber (ax1)
				ax2 = tonumber (ax2)

				local scale = (-ay2 + ay1) / 500
				Nx.prt(scale)
				if scale > 0 then
					local t = {}
					areas[nxid] = t
					t[1] = scale
					t[2] = -ay1 / 5		-- X
					t[3] = -ax1 / 5		-- Y
					t[4] = aname
					Nx.prt("%s %s %s %s",t[4],t[2],t[3],t[1])
				end
--			end
		end

--		if map == 0 or map == 1 then
--		if map == 648 or map == 646 or map == 730 then		-- Maelstrom
--		if map == 654 then					-- Gilneas
--		if map == 571 or map == 609 then			-- Northrend, DK start
		if map == 1064 or map == 870 then
--			Nx.prt ("%s %s %s", aid, map, aname)

			local area = {}

			for n, os in ipairs (wmo) do

				-- 84,41,736,0,0,0,"BanethilHollow",175,235,374,221,292,430,375,497,0x0,

				local _, oaid, _, _, _, _, oname, w, h, x, y = strsplit (",", os)

				oname = gsub (oname, '"', "")

				if tonumber (oaid) == aid and #oname > 0 then
					oname = strlower (oname)
					area[oname] = format ("%s,%s,%s,%s", x, y, w, h)
				end
			end

			if next (area) then				-- Not empty?
				data[aname] = area
			end
		end
	end
end
]]--

-- Copied from HereBeDragons-Migrate all credit goes to HereBeDragons team
local SetupMigrationData
local MapMigrationData, mapFileToIdMap, uiMapIdToIdMap
function Nx.Map:GetLegacyMapInfo(uiMapId)
    if not uiMapId then return nil end
    if not uiMapIdToIdMap then SetupMigrationData() end
    local c = uiMapIdToIdMap[uiMapId]
    if not c then return end
    
    local m, f = floor(c / 10000), (c % 10000)
    return m, f, MapMigrationData[m].mapFile, MapMigrationData[m]
end
MapMigrationData = {
    [4] = { mapFile = "Durotar", [0] = 1, [8] = 2, [12] = 5, [19] = 6, [11] = 4, [10] = 3},
    [9] = { mapFile = "Mulgore", [0] = 7, [6] = 8, [7] = 9},
    [11] = { mapFile = "Barrens", [0] = 10, [20] = 11},
    [1414] = { mapFile = "Kalimdor", [0] = 12},
    [1415] = { mapFile = "Azeroth", [0] = 13},
    [16] = { mapFile = "Arathi", [0] = 14},
    [17] = { mapFile = "Badlands", [0] = 15, [18] = 16},
    [19] = { mapFile = "BlastedLands", [0] = 17},
    [20] = { mapFile = "Tirisfal", [0] = 18, [13] = 19, [25] = 20},
    [21] = { mapFile = "Silverpine", [0] = 21},
    [22] = { mapFile = "WesternPlaguelands", [0] = 22},
    [23] = { mapFile = "EasternPlaguelands", [0] = 23, [20] = 24},
    [24] = { mapFile = "HillsbradFoothills", [0] = 25},
    [26] = { mapFile = "Hinterlands", [0] = 26},
    [27] = { mapFile = "DunMorogh", [6] = 28, [7] = 29, [11] = 31, [10] = 30, [0] = 27},
    [28] = { mapFile = "SearingGorge", [0] = 32, [15] = 34, [14] = 33, [16] = 35},
    [29] = { mapFile = "BurningSteppes", [0] = 36},
    [30] = { mapFile = "Elwynn", [1] = 38, [2] = 39, [0] = 37, [19] = 40, [21] = 41},
    [32] = { mapFile = "DeadwindPass", [0] = 42, [24] = 45, [22] = 43, [23] = 44, [27] = 46},
    [758] = { mapFile = "TheBastionofTwilight", [1] = 294, [2] = 295, [3] = 296},
    [886] = { mapFile = "TerraceOfEndlessSpring", [0] = 456},
    [1014] = { mapFile = "Dalaran70", [0] = 625, [12] = 629, [4] = 626, [11] = 628, [10] = 627},
    [759] = { mapFile = "HallsofOrigination", [1] = 297, [2] = 298, [3] = 299},
    [887] = { mapFile = "SiegeofNiuzaoTemple", [1] = 458, [2] = 459, [0] = 457},
    [1015] = { mapFile = "Azsuna", [0] = 630, [17] = 631, [19] = 633, [18] = 632},
    [760] = { mapFile = "RazorfenDowns", [1] = 300},
    [888] = { mapFile = "ShadowglenStart", [0] = 460},
    [761] = { mapFile = "RazorfenKraul", [1] = 301},
    [889] = { mapFile = "ValleyofTrialsStart", [0] = 461},
    [1017] = { mapFile = "Stormheim", [1] = 635, [0] = 634, [28] = 640, [27] = 639, [26] = 638, [9] = 636, [25] = 637},
    [762] = { mapFile = "ScarletMonastery", [1] = 302, [2] = 303, [3] = 304, [4] = 305},
    [890] = { mapFile = "CampNaracheStart", [0] = 462},
    [1018] = { mapFile = "Valsharah", [0] = 641, [13] = 642, [15] = 644, [14] = 643},
    [763] = { mapFile = "Scholomance", [1] = 306, [2] = 307, [3] = 308, [4] = 309},
    [891] = { mapFile = "EchoIslesStart", [0] = 463, [9] = 464},
    [510] = { mapFile = "CrystalsongForest", [0] = 127},
    [40] = { mapFile = "Wetlands", [0] = 56},
    [764] = { mapFile = "ShadowfangKeep", [1] = 310, [2] = 311, [3] = 312, [4] = 313, [5] = 314, [6] = 315, [7] = 316},
    [892] = { mapFile = "DeathknellStart", [0] = 465, [12] = 466},
    [1020] = { mapFile = "TwistingNether70", [0] = 645},
    [765] = { mapFile = "Stratholme", [1] = 317, [2] = 318},
    [893] = { mapFile = "SunstriderIsleStart", [0] = 467},
    [1021] = { mapFile = "BrokenShore", [1] = 647, [2] = 648, [0] = 646},
    [766] = { mapFile = "AhnQiraj", [1] = 319, [2] = 320, [3] = 321},
    [894] = { mapFile = "AmmenValeStart", [0] = 468},
    [1022] = { mapFile = "Helheim", [0] = 649},
    [767] = { mapFile = "ThroneofTides", [1] = 322, [2] = 323},
    [895] = { mapFile = "NewTinkertownStart", [0] = 469, [8] = 470},
    [512] = { mapFile = "StrandoftheAncients", [0] = 128},
    [640] = { mapFile = "Deepholm", [1] = 208, [2] = 209, [0] = 207},
    [768] = { mapFile = "TheStonecore", [1] = 324},
    [896] = { mapFile = "MogushanVaults", [1] = 471, [2] = 472, [3] = 473},
    [1024] = { mapFile = "Highmountain", [0] = 650, [29] = 657, [8] = 653, [16] = 654, [5] = 651, [40] = 660, [20] = 655, [21] = 656, [6] = 652, [31] = 659, [30] = 658},
    [321] = { mapFile = "Orgrimmar", [1] = 86, [0] = 85},
    [769] = { mapFile = "Skywall", [1] = 325},
    [897] = { mapFile = "HeartofFear", [1] = 474, [2] = 475},
    [1026] = { mapFile = "HellfireRaid", [1] = 662, [2] = 663, [3] = 664, [4] = 665, [5] = 666, [6] = 667, [7] = 668, [8] = 669, [9] = 670, [0] = 661},
    [161] = { mapFile = "Tanaris", [0] = 71, [17] = 74, [15] = 72, [16] = 73, [18] = 75},
    [1027] = { mapFile = "AraukNashalIntroScenario", [0] = 671},
    [898] = { mapFile = "Scholomance", [1] = 476, [2] = 477, [3] = 478, [4] = 479},
    [1028] = { mapFile = "MardumtheShatteredAbyss", [1] = 673, [2] = 674, [3] = 675, [0] = 672},
    [899] = { mapFile = "ProvingGrounds", [1] = 480},
    [772] = { mapFile = "AhnQirajTheFallenKingdom", [0] = 327},
    [900] = { mapFile = "AncientMoguCrypt", [1] = 481, [2] = 482},
    [1032] = { mapFile = "VaultOfTheWardensDH", [1] = 677, [2] = 678, [3] = 679},
    [81] = { mapFile = "StonetalonMountains", [0] = 65},
    [773] = { mapFile = "ThroneoftheFourWinds", [1] = 328},
    [1034] = { mapFile = "HelmouthShallows", [0] = 694},
    [1035] = { mapFile = "ValhallasWarriorOrderHome", [1] = 695},
    [775] = { mapFile = "CoTMountHyjal", [0] = 329},
    [520] = { mapFile = "TheNexus", [1] = 129},
    [776] = { mapFile = "GruulsLair", [1] = 330},
    [521] = { mapFile = "CoTStratholme", [1] = 131, [0] = 130},
    [1041] = { mapFile = "HallsofValor", [1] = 704, [2] = 705, [0] = 703},
    [522] = { mapFile = "Ahnkahet", [1] = 132},
    [906] = { mapFile = "DustwallowMarshScenarioAlliance", [0] = 483},
    [523] = { mapFile = "UtgardeKeep", [1] = 133, [2] = 134, [3] = 135},
    [779] = { mapFile = "MagtheridonsLair", [1] = 331},
    [524] = { mapFile = "UtgardePinnacle", [1] = 136, [2] = 137},
    [41] = { mapFile = "Teldrassil", [2] = 58, [3] = 59, [4] = 60, [0] = 57, [5] = 61},
    [780] = { mapFile = "CoilfangReservoir", [1] = 332},
    [525] = { mapFile = "HallsofLightning", [1] = 138, [2] = 139},
    [781] = { mapFile = "ZulAman", [0] = 333},
    [526] = { mapFile = "Ulduar77", [1] = 140},
    [782] = { mapFile = "TempestKeep", [1] = 334},
    [527] = { mapFile = "TheEyeofEternity", [1] = 141},
    [911] = { mapFile = "KrasarangAlliance", [0] = 486},
    [528] = { mapFile = "Nexus80", [1] = 143, [2] = 144, [3] = 145, [4] = 146, [0] = 142},
    [912] = { mapFile = "KrasarangPatience", [0] = 487},
    [529] = { mapFile = "Ulduar", [1] = 148, [2] = 149, [3] = 150, [4] = 151, [5] = 152, [0] = 147},
    [1057] = { mapFile = "MaelstromShaman", [0] = 726},
    [530] = { mapFile = "Gundrak", [1] = 154, [0] = 153},
    [1059] = { mapFile = "TerraceofEndlessSpringScenario", [0] = 728},
    [914] = { mapFile = "VoljinScenario", [1] = 489, [0] = 488},
    [531] = { mapFile = "TheObsidianSanctum", [0] = 155},
    [532] = { mapFile = "VaultofArchavon", [1] = 156},
    [533] = { mapFile = "AzjolNerub", [1] = 157, [2] = 158, [3] = 159},
    [789] = { mapFile = "SunwellPlateau", [1] = 336, [0] = 335},
    [534] = { mapFile = "DrakTharonKeep", [1] = 160, [2] = 161},
    [1067] = { mapFile = "DarkheartThicket", [0] = 733},
    [535] = { mapFile = "Naxxramas", [1] = 162, [2] = 163, [3] = 164, [4] = 165, [5] = 166, [6] = 167},
    [1069] = { mapFile = "TheBeyond", [1] = 736},
    [919] = { mapFile = "BlackTempleScenario", [1] = 491, [2] = 492, [3] = 493, [4] = 494, [5] = 495, [6] = 496, [7] = 497, [0] = 490},
    [536] = { mapFile = "VioletHold", [1] = 168},
    [1071] = { mapFile = "FirelandsShaman", [0] = 738},
    [920] = { mapFile = "KrasarangHorde", [0] = 498},
    [1072] = { mapFile = "TrueshotLodge", [0] = 739},
    [793] = { mapFile = "ZulGurub", [0] = 337},
    [461] = { mapFile = "ArathiBasin", [0] = 93},
    [1075] = { mapFile = "AbyssalMawShamanAcquisition", [1] = 742, [2] = 743},
    [922] = { mapFile = "DeeprunTram", [1] = 499, [2] = 500},
    [1076] = { mapFile = "UlduarMagni", [1] = 744, [2] = 745, [3] = 746},
    [795] = { mapFile = "MoltenFront", [0] = 338},
    [462] = { mapFile = "EversongWoods", [0] = 94},
    [34] = { mapFile = "Duskwood", [0] = 47},
    [42] = { mapFile = "Darkshore", [0] = 62},
    [796] = { mapFile = "BlackTemple", [1] = 340, [2] = 341, [3] = 342, [4] = 343, [5] = 344, [6] = 345, [7] = 346, [0] = 339},
    [924] = { mapFile = "DalaranCity", [1] = 501, [2] = 502},
    [541] = { mapFile = "HrothgarsLanding", [0] = 170},
    [797] = { mapFile = "HellfireRamparts", [1] = 347},
    [925] = { mapFile = "BrawlgarArena", [1] = 503},
    [542] = { mapFile = "TheArgentColiseum", [1] = 171},
    [798] = { mapFile = "MagistersTerrace", [1] = 348, [2] = 349},
    [543] = { mapFile = "TheArgentColiseum", [1] = 172, [2] = 173},
    [799] = { mapFile = "Karazhan", [1] = 350, [2] = 351, [3] = 352, [4] = 353, [5] = 354, [6] = 355, [7] = 356, [8] = 357, [9] = 358, [10] = 359, [11] = 360, [12] = 361, [13] = 362, [14] = 363, [15] = 364, [16] = 365, [17] = 366},
    [464] = { mapFile = "AzuremystIsle", [0] = 97, [2] = 98, [3] = 99},
    [544] = { mapFile = "TheLostIsles", [1] = 175, [2] = 176, [3] = 177, [4] = 178, [0] = 174},
    [800] = { mapFile = "Firelands", [1] = 368, [2] = 369, [0] = 367},
    [928] = { mapFile = "IsleoftheThunderKing", [1] = 505, [2] = 506, [0] = 504},
    [545] = { mapFile = "Gilneas", [1] = 180, [2] = 181, [3] = 182, [0] = 179},
    [673] = { mapFile = "TheCapeOfStranglethorn", [0] = 210},
    [401] = { mapFile = "AlteracValley", [0] = 91},
    [929] = { mapFile = "IsleOfGiants", [0] = 507},
    [1090] = { mapFile = "TolBaradWarlockScenario", [1] = 774, [0] = 773},
    [201] = { mapFile = "UngoroCrater", [0] = 78, [14] = 79},
    [930] = { mapFile = "ThunderKingRaid", [1] = 508, [2] = 509, [3] = 510, [4] = 511, [5] = 512, [6] = 513, [7] = 514, [8] = 515},
    [1092] = { mapFile = "AzuremystIsleScenario", [0] = 776},
    [803] = { mapFile = "TheNexusLegendary", [1] = 370},
    [466] = { mapFile = "Expansion01", [0] = 1945},
    [1094] = { mapFile = "NightmareRaid", [1] = 777, [2] = 778, [3] = 779, [4] = 780, [5] = 781, [6] = 782, [7] = 783, [8] = 784, [9] = 785, [10] = 786, [11] = 787, [12] = 788, [13] = 789},
    [1096] = { mapFile = "AszunaDungeonExterior", [0] = 790},
    [101] = { mapFile = "Desolace", [0] = 66, [22] = 68, [21] = 67},
    [933] = { mapFile = "IsleoftheThunderKingScenario", [1] = 517, [0] = 516},
    [806] = { mapFile = "TheJadeForest", [6] = 372, [7] = 373, [15] = 374, [16] = 375, [0] = 371},
    [934] = { mapFile = "ThunderKingLootRoom", [1] = 518},
    [1100] = { mapFile = "KarazhanScenario", [1] = 794, [2] = 795, [3] = 796, [4] = 797},
    [807] = { mapFile = "ValleyoftheFourWinds", [0] = 376, [14] = 377},
    [935] = { mapFile = "GoldRush", [0] = 519},
    [1102] = { mapFile = "ArcwayScenario", [1] = 798},
    [680] = { mapFile = "Ragefire", [1] = 213},
    [808] = { mapFile = "TheWanderingIsle", [0] = 378},
    [1104] = { mapFile = "MageCampaignTheOculus", [1] = 800, [2] = 801, [3] = 802, [4] = 803, [0] = 799},
    [341] = { mapFile = "Ironforge", [0] = 87},
    [809] = { mapFile = "KunLaiSummit", [0] = 379, [8] = 380, [9] = 381, [10] = 382, [20] = 386, [11] = 383, [21] = 387, [12] = 384, [17] = 385},
    [937] = { mapFile = "ValeOfEternalBlossomsScenario", [1] = 521, [0] = 520},
    [810] = { mapFile = "TownlongWastes", [0] = 388, [13] = 389},
    [938] = { mapFile = "EmberdeepScenario", [1] = 522},
    [811] = { mapFile = "ValeofEternalBlossoms", [1] = 391, [2] = 392, [3] = 393, [4] = 394, [0] = 390, [19] = 396, [18] = 395},
    [939] = { mapFile = "DunMoroghScenario", [0] = 523},
    [35] = { mapFile = "LochModan", [0] = 48},
    [43] = { mapFile = "Ashenvale", [0] = 63},
    [940] = { mapFile = "tempKrasarangHordeBase", [0] = 524},
    [685] = { mapFile = "RuinsofGilneasCity", [0] = 218},
    [813] = { mapFile = "NetherstormArena", [0] = 397},
    [471] = { mapFile = "TheExodar", [0] = 103},
    [1114] = { mapFile = "HelheimRaid", [1] = 807, [2] = 808, [0] = 806},
    [686] = { mapFile = "ZulFarrak", [0] = 219},
    [1115] = { mapFile = "LegionKarazhanDungeon", [1] = 809, [2] = 810, [3] = 811, [4] = 812, [5] = 813, [6] = 814, [7] = 815, [8] = 816, [9] = 817, [10] = 818, [11] = 819, [12] = 820, [13] = 821, [14] = 822},
    [1116] = { mapFile = "PitofSaronDK", [0] = 823},
    [687] = { mapFile = "TheTempleOfAtalHakkar", [1] = 220},
    [688] = { mapFile = "BlackfathomDeeps", [1] = 221, [2] = 222, [3] = 223},
    [816] = { mapFile = "WellofEternity", [0] = 398},
    [281] = { mapFile = "Winterspring", [0] = 83},
    [689] = { mapFile = "StranglethornVale", [0] = 224},
    [473] = { mapFile = "ShadowmoonValley", [0] = 104},
    [141] = { mapFile = "Dustwallow", [0] = 70},
    [690] = { mapFile = "TheStockade", [1] = 225},
    [946] = { mapFile = "Talador", [0] = 535, [13] = 536, [14] = 537, [30] = 538},
    [691] = { mapFile = "Gnomeregan", [1] = 226, [2] = 227, [3] = 228, [4] = 229},
    [819] = { mapFile = "HourofTwilight", [1] = 400, [0] = 399},
    [947] = { mapFile = "ShadowmoonValleyDR", [0] = 539, [22] = 541, [15] = 540},
    [1126] = {[0] = 824},
    [692] = { mapFile = "Uldaman", [1] = 230, [2] = 231},
    [820] = { mapFile = "EndTime", [1] = 402, [2] = 403, [3] = 404, [4] = 405, [5] = 406, [0] = 401},
    [948] = { mapFile = "SpiresOfArak", [0] = 542},
    [181] = { mapFile = "Aszhara", [0] = 76},
    [1220] = {[0] = 981},
    [1129] = { mapFile = "CaveoftheBloodtotemScenario", [1] = 826},
    [949] = { mapFile = "Gorgrond", [0] = 543, [17] = 545, [21] = 549, [20] = 548, [19] = 547, [16] = 544, [18] = 546},
    [1130] = { mapFile = "StratholmePaladinClassMount", [1] = 827},
    [1219] = {[1] = 975, [2] = 976, [3] = 977, [4] = 978, [5] = 979, [6] = 980, [0] = 974},
    [1131] = { mapFile = "TheEyeofEternityMageClassMount", [1] = 828},
    [950] = { mapFile = "NagrandDraenor", [11] = 552, [12] = 553, [0] = 550, [10] = 551},
    [1132] = { mapFile = "HallsOfValorWarriorClassMount", [1] = 829},
    [1050] = { mapFile = "WarlockClassShrine", [0] = 717},
    [823] = { mapFile = "DarkmoonFaireIsland", [1] = 408, [0] = 407},
    [476] = { mapFile = "BloodmystIsle", [0] = 106},
    [1216] = { mapFile = "VoidElfScenario", [0] = 972},
    [696] = { mapFile = "MoltenCore", [1] = 232},
    [824] = { mapFile = "DragonSoul", [1] = 410, [2] = 411, [3] = 412, [4] = 413, [5] = 414, [6] = 415, [0] = 409},
    [1215] = { mapFile = "VoidElfHub", [0] = 971},
    [1136] = { mapFile = "ColdridgeValleyScenario", [0] = 834},
    [697] = { mapFile = "ZulGurub", [0] = 233},
    [1137] = { mapFile = "TheDeadminesPetBattle", [1] = 835, [2] = 836},
    [477] = { mapFile = "Nagrand", [0] = 107},
    [1052] = { mapFile = "DemonHunterOrderHallTerrain", [1] = 720, [2] = 721, [0] = 719},
    [1054] = { mapFile = "TheVioletHoldAcquisition", [1] = 723},
    [1139] = { mapFile = "ArathiBasinWinter", [0] = 837},
    [1212] = { mapFile = "LightforgedVindicaar", [1] = 940, [2] = 941},
    [1140] = { mapFile = "BattleforBlackrockMountain", [0] = 838},
    [699] = { mapFile = "DireMaul", [1] = 235, [2] = 236, [3] = 237, [4] = 238, [5] = 239, [6] = 240, [0] = 234},
    [1211] = {[0] = 939},
    [478] = { mapFile = "TerokkarForest", [0] = 108},
    [36] = { mapFile = "Redridge", [0] = 49},
    [700] = { mapFile = "TwilightHighlands", [0] = 241},
    [1143] = { mapFile = "GnomereganPetBattle", [1] = 840, [2] = 841, [3] = 842},
    [1210] = {[0] = 938},
    [1144] = { mapFile = "SmallBattlegroundC", [0] = 843},
    [1066] = { mapFile = "LegionVioletHoldDungeon", [1] = 732},
    [1145] = {[0] = 844},
    [479] = { mapFile = "Netherstorm", [0] = 109},
    [1146] = { mapFile = "TombofSargerasDungeon", [1] = 845, [2] = 846, [3] = 847, [4] = 848, [5] = 849},
    [1204] = {[1] = 934, [2] = 935},
    [1147] = { mapFile = "TombRaid", [1] = 850, [2] = 851, [3] = 852, [4] = 853, [5] = 854, [6] = 855, [7] = 856},
    [1202] = { mapFile = "LightforgedDraeneiSwamp", [0] = 933},
    [1148] = { mapFile = "ThroneoftheFourWinds", [1] = 857},
    [1201] = { mapFile = "InvasionPointVal", [0] = 932},
    [1149] = { mapFile = "AssaultonBrokenShoreScenario", [0] = 858},
    [480] = { mapFile = "SilvermoonCity", [0] = 110},
    [1150] = {[0] = 859},
    [704] = { mapFile = "BlackrockDepths", [1] = 242, [2] = 243},
    [1151] = { mapFile = "TheRubySanctumDKMountScenario", [0] = 860},
    [1200] = { mapFile = "InvasionPointSangua", [0] = 931},
    [1152] = { mapFile = "FelwingLedgeMardumArea", [0] = 861},
    [1199] = { mapFile = "InvasionPointNaigtal", [0] = 930},
    [1153] = {[0] = 862},
    [481] = { mapFile = "ShattrathCity", [0] = 111},
    [1154] = {[0] = 863},
    [1068] = { mapFile = "MageClassShrine", [1] = 734, [2] = 735},
    [1155] = {[0] = 864},
    [241] = { mapFile = "Moonglade", [0] = 80},
    [1156] = { mapFile = "StormheimInvasionScenario", [1] = 865, [2] = 866},
    [1070] = { mapFile = "TheVortexPinnacle", [1] = 737},
    [1157] = { mapFile = "AzsunaInvasionScenario", [1] = 867},
    [482] = { mapFile = "NetherstormArena", [0] = 112},
    [1158] = { mapFile = "ValsharahInvasionScenario", [1] = 868},
    [708] = { mapFile = "TolBarad", [0] = 244},
    [1159] = { mapFile = "HighmountainInvasionScenario", [1] = 869, [2] = 870},
    [964] = { mapFile = "OgreMines", [1] = 573},
    [1160] = { mapFile = "LostGlacierDKMountScenario", [0] = 871},
    [709] = { mapFile = "TolBaradDailyArea", [0] = 245},
    [1161] = { mapFile = "StormstoutBreweryScenario", [1] = 873, [2] = 874, [0] = 872},
    [121] = { mapFile = "Feralas", [0] = 69},
    [1162] = {[0] = 875},
    [710] = { mapFile = "TheShatteredHalls", [1] = 246},
    [1163] = {[0] = 876},
    [1073] = { mapFile = "ArtifactSubtletyRogueAcquisition", [1] = 740, [2] = 741},
    [1164] = { mapFile = "HallsofValor", [0] = 877},
    [1078] = { mapFile = "Niskara", [0] = 748},
    [1165] = { mapFile = "DemonHunterOrderHallTerrain", [1] = 879, [2] = 880, [0] = 878},
    [1079] = { mapFile = "SuamarCatacombsDungeon", [1] = 749},
    [1166] = { mapFile = "TheEyeofEternityMageClassMount", [1] = 881},
    [1080] = { mapFile = "ThunderTotem", [0] = 750},
    [1081] = { mapFile = "BlackRookHoldDungeon", [1] = 751, [2] = 752, [3] = 753, [4] = 754, [5] = 755, [6] = 756},
    [1082] = { mapFile = "UrsocsLairScenario", [0] = 757},
    [1084] = { mapFile = "GloamingReef", [0] = 758},
    [1085] = { mapFile = "70BlackTempleLegion", [1] = 759},
    [1086] = { mapFile = "MalornesNightmare", [0] = 760},
    [485] = { mapFile = "Northrend", [0] = 113},
    [1170] = { mapFile = "ArgusMacAree", [0] = 882, [3] = 883, [4] = 884},
    [1087] = { mapFile = "SuramarNoblesDistrict", [1] = 762, [2] = 763, [0] = 761},
    [1171] = { mapFile = "ArgusCore", [0] = 885, [6] = 887, [5] = 886},
    [970] = { mapFile = "TanaanJungleIntro", [1] = 578, [0] = 577},
    [1172] = { mapFile = "HallOfCommunion", [1] = 888},
    [1091] = { mapFile = "TheExodar", [0] = 775},
    [1173] = { mapFile = "TKArcatrazScenario", [1] = 889, [2] = 890},
    [486] = { mapFile = "BoreanTundra", [0] = 114},
    [37] = { mapFile = "StranglethornJungle", [0] = 50},
    [1097] = { mapFile = "ArtifactBrewmasterScenario", [1] = 791, [2] = 792},
    [1175] = {[0] = 895},
    [61] = { mapFile = "ThousandNeedles", [0] = 64},
    [1176] = {[0] = 896},
    [717] = { mapFile = "RuinsofAhnQiraj", [0] = 247},
    [1177] = { mapFile = "DragonblightChromieScenario", [1] = 898, [2] = 899, [3] = 900, [4] = 901, [5] = 902, [0] = 897},
    [973] = { mapFile = "garrisonsmvalliance_tier1", [0] = 582},
    [1178] = { mapFile = "ArgusDungeon", [0] = 903},
    [718] = { mapFile = "OnyxiasLair", [1] = 248},
    [1099] = { mapFile = "BlackRookHoldScenario", [0] = 793},
    [1174] = { mapFile = "AzuremystScenario", [1] = 892, [2] = 893, [3] = 894, [0] = 891},
    [1142] = { mapFile = "PriestClassMountScenario", [1] = 839},
    [1135] = { mapFile = "ArgusSurface", [1] = 831, [2] = 832, [0] = 830, [7] = 833},
    [1127] = { mapFile = "WailingCavernsPetBattle", [1] = 825},
    [488] = { mapFile = "Dragonblight", [0] = 115},
    [1105] = { mapFile = "ScarletMonestaryDK", [1] = 804, [2] = 805},
    [720] = { mapFile = "Uldum", [0] = 249},
    [1183] = { mapFile = "SilithusBrawl", [0] = 904},
    [976] = { mapFile = "garrisonffhorde", [27] = 586, [28] = 587, [26] = 585},
    [1184] = { mapFile = "Argus", [0] = 994},
    [721] = { mapFile = "BlackrockSpire", [1] = 250, [2] = 251, [3] = 252, [4] = 253, [5] = 254, [6] = 255},
    [1185] = {[0] = 906},
    [1088] = { mapFile = "SuramarRaid", [1] = 764, [2] = 765, [3] = 766, [4] = 767, [5] = 768, [6] = 769, [7] = 770, [8] = 771, [9] = 772},
    [1186] = { mapFile = "AzeriteBG", [0] = 907},
    [722] = { mapFile = "AuchenaiCrypts", [1] = 256, [2] = 257},
    [1187] = {[0] = 908},
    [978] = { mapFile = "Ashran", [0] = 588, [29] = 589},
    [1188] = { mapFile = "ArgusRaid", [1] = 910, [2] = 911, [3] = 912, [4] = 913, [5] = 914, [6] = 915, [7] = 916, [8] = 917, [9] = 918, [10] = 919, [11] = 920, [0] = 909},
    [723] = { mapFile = "SethekkHalls", [1] = 258, [2] = 259},
    [851] = { mapFile = "DustwallowMarshScenario", [0] = 416},
    [490] = { mapFile = "GrizzlyHills", [0] = 116},
    [1190] = { mapFile = "InvasionPointAurinor", [0] = 921},
    [724] = { mapFile = "ShadowLabyrinth", [1] = 260},
    [1191] = { mapFile = "InvasionPointBonich", [0] = 922},
    [980] = { mapFile = "garrisonffhorde_tier1", [0] = 590},
    [1192] = { mapFile = "InvasionPointCengar", [0] = 923},
    [725] = { mapFile = "TheBloodFurnace", [1] = 261},
    [1193] = { mapFile = "InvasionPointNaigtal", [0] = 924},
    [491] = { mapFile = "HowlingFjord", [0] = 117},
    [1194] = { mapFile = "InvasionPointSangua", [0] = 925},
    [726] = { mapFile = "TheUnderbog", [1] = 262},
    [1195] = { mapFile = "InvasionPointVal", [0] = 926},
    [1077] = { mapFile = "TheDreamgrove", [0] = 747},
    [1196] = { mapFile = "InvasionPointAurinor", [0] = 927},
    [727] = { mapFile = "TheSteamvault", [1] = 263, [2] = 264},
    [1197] = { mapFile = "InvasionPointBonich", [0] = 928},
    [492] = { mapFile = "IcecrownGlacier", [0] = 118},
    [1198] = { mapFile = "InvasionPointCengar", [0] = 929},
    [728] = { mapFile = "TheSlavePens", [1] = 265},
    [856] = { mapFile = "TempleofKotmogu", [0] = 417},
    [984] = { mapFile = "DraenorAuchindoun", [1] = 593},
    [601] = { mapFile = "TheForgeofSouls", [1] = 183},
    [729] = { mapFile = "TheBotanica", [1] = 266},
    [857] = { mapFile = "Krasarang", [1] = 419, [2] = 420, [3] = 421, [0] = 418},
    [493] = { mapFile = "SholazarBasin", [0] = 119},
    [602] = { mapFile = "PitofSaron", [0] = 184},
    [730] = { mapFile = "TheMechanar", [1] = 267, [2] = 268},
    [858] = { mapFile = "DreadWastes", [0] = 422},
    [986] = { mapFile = "TaladorScenario", [0] = 594},
    [603] = { mapFile = "HallsofReflection", [1] = 185},
    [731] = { mapFile = "TheArcatraz", [1] = 269, [2] = 270, [3] = 271},
    [1205] = {[0] = 936},
    [987] = { mapFile = "IronDocks", [1] = 595},
    [38] = { mapFile = "SwampOfSorrows", [0] = 51},
    [732] = { mapFile = "ManaTombs", [1] = 272},
    [860] = { mapFile = "STVDiamondMineBG", [1] = 423},
    [988] = { mapFile = "FoundryRaid", [1] = 596, [2] = 597, [3] = 598, [4] = 599, [5] = 600},
    [605] = { mapFile = "Kezan", [6] = 196, [7] = 197, [5] = 195, [0] = 194},
    [733] = { mapFile = "CoTTheBlackMorass", [0] = 273},
    [1065] = { mapFile = "NeltharionsLair", [0] = 731},
    [495] = { mapFile = "TheStormPeaks", [0] = 120},
    [606] = { mapFile = "Hyjal", [0] = 198},
    [734] = { mapFile = "CoTHillsbradFoothills", [0] = 274},
    [862] = { mapFile = "Pandaria", [0] = 424},
    [1060] = { mapFile = "DeepholmShamanAcquisition", [1] = 729},
    [607] = { mapFile = "SouthernBarrens", [0] = 199},
    [1056] = { mapFile = "MaelstromShamanHubIntro", [0] = 725},
    [1213] = {[0] = 942},
    [496] = { mapFile = "ZulDrak", [0] = 121},
    [1214] = {[0] = 943},
    [736] = { mapFile = "GilneasBattleground2", [0] = 275},
    [864] = { mapFile = "Northshire", [0] = 425, [3] = 426},
    [1051] = { mapFile = "DreadscarRift", [0] = 718},
    [609] = { mapFile = "TheRubySanctum", [0] = 200},
    [737] = { mapFile = "TheMaelstrom", [0] = 276},
    [1217] = { mapFile = "TheSunwellUnlockScenario", [1] = 973},
    [993] = { mapFile = "BlackrockTrainDepotDungeon", [1] = 606, [2] = 607, [3] = 608, [4] = 609},
    [610] = { mapFile = "VashjirKelpForest", [0] = 201},
    [1049] = { mapFile = "ArtifactSkywall", [1] = 716},
    [866] = { mapFile = "ColdridgeValley", [0] = 427, [9] = 428},
    [994] = { mapFile = "HighmaulRaid", [1] = 611, [2] = 612, [3] = 613, [4] = 614, [5] = 615, [0] = 610},
    [611] = { mapFile = "GilneasCity", [0] = 202},
    [1048] = { mapFile = "EmeraldDreamway", [0] = 715},
    [867] = { mapFile = "EastTemple", [1] = 429, [2] = 430},
    [995] = { mapFile = "UpperBlackrockSpire", [1] = 616, [2] = 617, [3] = 618},
    [1047] = { mapFile = "Niskara", [0] = 714},
    [1046] = { mapFile = "AszunaDungeon", [0] = 713},
    [1045] = { mapFile = "VaultOfTheWardens", [1] = 710, [2] = 711, [3] = 712},
    [1044] = { mapFile = "MonkOrderHallTheWanderingIsle", [0] = 709},
    [613] = { mapFile = "Vashjir", [0] = 203},
    [1042] = { mapFile = "HelheimDungeonDock", [1] = 707, [2] = 708, [0] = 706},
    [1040] = { mapFile = "NetherlightTemple", [1] = 702},
    [499] = { mapFile = "Sunwell", [0] = 122},
    [614] = { mapFile = "VashjirDepths", [0] = 204},
    [1039] = { mapFile = "IcecrownCitadelDeathKnight", [1] = 698, [2] = 699, [3] = 700, [4] = 701},
    [1038] = { mapFile = "HulnFlashback", [0] = 697},
    [1037] = { mapFile = "StormheimArtifactProtWarrior", [0] = 696},
    [615] = { mapFile = "VashjirRuins", [0] = 205},
    [1033] = { mapFile = "Suramar", [24] = 683, [33] = 685, [35] = 687, [39] = 691, [41] = 692, [42] = 693, [32] = 684, [34] = 686, [36] = 688, [38] = 690, [37] = 689, [22] = 681, [23] = 682, [0] = 680},
    [871] = { mapFile = "ScarletHalls", [1] = 431, [2] = 432},
    [1031] = { mapFile = "BrokenShorePaladin", [0] = 676},
    [301] = { mapFile = "StormwindCity", [0] = 84},
    [475] = { mapFile = "BladesEdgeMountains", [0] = 105},
    [382] = { mapFile = "Undercity", [0] = 998},
    [953] = { mapFile = "OrgrimmarRaid", [1] = 557, [2] = 558, [3] = 559, [4] = 560, [5] = 561, [6] = 562, [7] = 563, [8] = 564, [9] = 565, [10] = 566, [11] = 567, [12] = 568, [13] = 569, [14] = 570, [0] = 556},
    [1007] = { mapFile = "BrokenIsles", [0] = 619},
    [989] = { mapFile = "SpiresofArakDungeon", [1] = 601, [2] = 602},
    [873] = { mapFile = "TheHiddenPass", [0] = 433, [5] = 434},
    [501] = { mapFile = "LakeWintergrasp", [0] = 123},
    [983] = { mapFile = "DefenseofKarabor", [0] = 592},
    [971] = { mapFile = "garrisonsmvalliance", [24] = 580, [25] = 581, [23] = 579},
    [874] = { mapFile = "ScarletCathedral", [1] = 435, [2] = 436},
    [969] = { mapFile = "ShadowmoonDungeon", [1] = 574, [2] = 575, [3] = 576},
    [261] = { mapFile = "Silithus", [0] = 81, [13] = 82},
    [747] = { mapFile = "LostCityofTolvir", [0] = 277},
    [875] = { mapFile = "TheGreatWall", [1] = 437, [2] = 438},
    [502] = { mapFile = "ScarletEnclave", [0] = 124},
    [39] = { mapFile = "Westfall", [0] = 52, [17] = 55, [4] = 53, [5] = 54},
    [962] = { mapFile = "Draenor", [0] = 572},
    [876] = { mapFile = "StormstoutBrewery", [1] = 439, [2] = 440, [3] = 441, [4] = 442},
    [955] = { mapFile = "CelestialChallenge", [0] = 571},
    [951] = { mapFile = "TimelessIsle", [0] = 554, [22] = 555},
    [749] = { mapFile = "WailingCaverns", [1] = 279},
    [877] = { mapFile = "ShadowpanHideout", [1] = 444, [2] = 445, [3] = 446, [0] = 443},
    [945] = { mapFile = "TanaanJungle", [0] = 534},
    [941] = { mapFile = "FrostfireRidge", [1] = 526, [2] = 527, [3] = 528, [4] = 529, [6] = 530, [7] = 531, [8] = 532, [0] = 525, [9] = 533},
    [750] = { mapFile = "Maraudon", [1] = 280, [2] = 281},
    [878] = { mapFile = "BrewmasterScenario01", [0] = 447},
    [684] = { mapFile = "RuinsofGilneas", [0] = 217},
    [362] = { mapFile = "ThunderBluff", [0] = 88},
    [751] = { mapFile = "TheMaelstromContinent", [0] = 948},
    [182] = { mapFile = "Felwood", [0] = 77},
    [504] = { mapFile = "Dalaran", [1] = 125, [2] = 126},
    [465] = { mapFile = "Hellfire", [0] = 100},
    [752] = { mapFile = "BaradinHold", [1] = 282},
    [880] = { mapFile = "TheJadeForestScenario", [0] = 448},
    [1008] = { mapFile = "OvergrownOutpost", [1] = 621, [0] = 620},
    [443] = { mapFile = "WarsongGulch", [0] = 92},
    [753] = { mapFile = "BlackrockCaverns", [1] = 283, [2] = 284},
    [881] = { mapFile = "ValleyOfPowerScenario", [0] = 449},
    [1009] = { mapFile = "AshranAllianceFactionHub", [0] = 622},
    [626] = { mapFile = "TwinPeaks", [0] = 206},
    [754] = { mapFile = "BlackwingDescent", [1] = 285, [2] = 286},
    [882] = { mapFile = "BrewmasterScenario03", [0] = 450},
    [1010] = { mapFile = "HillsbradFoothillsBG", [0] = 623},
    [463] = { mapFile = "Ghostlands", [1] = 96, [0] = 95},
    [755] = { mapFile = "BlackwingLair", [1] = 287, [2] = 288, [3] = 289, [4] = 290},
    [883] = { mapFile = "Tyrivess", [0] = 451},
    [1011] = { mapFile = "AshranHordeFactionHub", [0] = 624},
    [381] = { mapFile = "Darnassus", [0] = 89},
    [756] = { mapFile = "TheDeadmines", [1] = 291, [2] = 292},
    [884] = { mapFile = "KunLaiPassScenario", [0] = 452},
    [540] = { mapFile = "IsleofConquest", [0] = 169},
    [604] = { mapFile = "IcecrownCitadel", [1] = 186, [2] = 187, [3] = 188, [4] = 189, [5] = 190, [6] = 191, [7] = 192, [8] = 193},
    [757] = { mapFile = "GrimBatol", [1] = 293},
    [885] = { mapFile = "MogushanPalace", [1] = 453, [2] = 454, [3] = 455},
    [467] = { mapFile = "Zangarmarsh", [0] = 102},
}
function SetupMigrationData()
    mapFileToIdMap = {}
    for id, t in pairs(MapMigrationData) do
        if t.mapFile then
            mapFileToIdMap[t.mapFile] = id
        end
    end

    uiMapIdToIdMap = {}
    for id, t in pairs(MapMigrationData) do
        for floor, uiMapId in pairs(t) do
            if floor ~= "mapFile" and floor ~= "defaultFloor" then
                uiMapIdToIdMap[uiMapId] = id * 10000 + floor
            end
        end
    end
end
-------------------------------------------------------------------------------
-- EOF
